! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Fri Mar  2 14:29:24 2018
! Working directory    : /n/home05/msulprizio/GC/Code.v11-02e/KPP/Tropchem
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(55) = X(55)-JVS(383)*X(48)
  X(56) = X(56)-JVS(388)*X(43)
  X(59) = X(59)-JVS(403)*X(39)
  X(70) = X(70)-JVS(455)*X(36)-JVS(456)*X(41)-JVS(457)*X(45)
  X(79) = X(79)-JVS(490)*X(62)
  X(98) = X(98)-JVS(586)*X(89)
  X(103) = X(103)-JVS(613)*X(79)
  X(106) = X(106)-JVS(635)*X(101)
  X(122) = X(122)-JVS(721)*X(104)
  X(125) = X(125)-JVS(741)*X(64)
  X(129) = X(129)-JVS(766)*X(54)-JVS(767)*X(78)-JVS(768)*X(121)
  X(131) = X(131)-JVS(784)*X(46)
  X(137) = X(137)-JVS(840)*X(117)-JVS(841)*X(118)-JVS(842)*X(123)-JVS(843)*X(126)-JVS(844)*X(127)-JVS(845)*X(128)&
             &-JVS(846)*X(130)-JVS(847)*X(134)-JVS(848)*X(135)
  X(140) = X(140)-JVS(877)*X(102)-JVS(878)*X(109)-JVS(879)*X(111)-JVS(880)*X(120)
  X(141) = X(141)-JVS(891)*X(62)-JVS(892)*X(75)-JVS(893)*X(80)-JVS(894)*X(92)-JVS(895)*X(103)
  X(142) = X(142)-JVS(909)*X(136)
  X(143) = X(143)-JVS(919)*X(53)-JVS(920)*X(57)-JVS(921)*X(58)-JVS(922)*X(99)-JVS(923)*X(107)-JVS(924)*X(108)-JVS(925)&
             &*X(136)
  X(144) = X(144)-JVS(933)*X(40)-JVS(934)*X(43)-JVS(935)*X(48)-JVS(936)*X(74)-JVS(937)*X(89)-JVS(938)*X(94)-JVS(939)&
             &*X(98)-JVS(940)*X(124)-JVS(941)*X(138)-JVS(942)*X(139)-JVS(943)*X(143)
  X(145) = X(145)-JVS(957)*X(84)
  X(148) = X(148)-JVS(985)*X(72)-JVS(986)*X(93)
  X(149) = X(149)-JVS(997)*X(84)-JVS(998)*X(136)-JVS(999)*X(138)-JVS(1000)*X(139)-JVS(1001)*X(145)
  X(151) = X(151)-JVS(1024)*X(126)-JVS(1025)*X(131)-JVS(1026)*X(135)-JVS(1027)*X(136)-JVS(1028)*X(142)-JVS(1029)*X(143)
  X(154) = X(154)-JVS(1064)*X(83)
  X(155) = X(155)-JVS(1074)*X(90)
  X(156) = X(156)-JVS(1085)*X(73)-JVS(1086)*X(93)
  X(157) = X(157)-JVS(1097)*X(110)
  X(158) = X(158)-JVS(1104)*X(110)-JVS(1105)*X(157)
  X(159) = X(159)-JVS(1115)*X(112)-JVS(1116)*X(153)
  X(160) = X(160)-JVS(1126)*X(1)-JVS(1127)*X(2)-JVS(1128)*X(3)-JVS(1129)*X(41)-JVS(1130)*X(44)-JVS(1131)*X(51)-JVS(1132)&
             &*X(52)-JVS(1133)*X(54)-JVS(1134)*X(63)-JVS(1135)*X(70)-JVS(1136)*X(78)-JVS(1137)*X(86)-JVS(1138)*X(121)&
             &-JVS(1139)*X(129)
  X(161) = X(161)-JVS(1150)*X(109)-JVS(1151)*X(111)-JVS(1152)*X(140)
  X(162) = X(162)-JVS(1164)*X(136)-JVS(1165)*X(157)
  X(163) = X(163)-JVS(1175)*X(41)-JVS(1176)*X(45)-JVS(1177)*X(70)-JVS(1178)*X(86)-JVS(1179)*X(121)-JVS(1180)*X(129)&
             &-JVS(1181)*X(160)
  X(164) = X(164)-JVS(1191)*X(42)-JVS(1192)*X(59)-JVS(1193)*X(71)-JVS(1194)*X(85)-JVS(1195)*X(92)-JVS(1196)*X(105)&
             &-JVS(1197)*X(109)-JVS(1198)*X(111)-JVS(1199)*X(115)-JVS(1200)*X(120)-JVS(1201)*X(121)-JVS(1202)*X(122)&
             &-JVS(1203)*X(124)-JVS(1204)*X(129)-JVS(1205)*X(133)-JVS(1206)*X(136)-JVS(1207)*X(140)-JVS(1208)*X(142)&
             &-JVS(1209)*X(144)-JVS(1210)*X(146)-JVS(1211)*X(157)-JVS(1212)*X(159)-JVS(1213)*X(160)-JVS(1214)*X(161)&
             &-JVS(1215)*X(162)-JVS(1216)*X(163)
  X(165) = X(165)-JVS(1252)*X(120)-JVS(1253)*X(160)-JVS(1254)*X(163)
  X(166) = X(166)-JVS(1265)*X(117)-JVS(1266)*X(118)-JVS(1267)*X(126)
  X(167) = X(167)-JVS(1277)*X(117)-JVS(1278)*X(118)-JVS(1279)*X(126)-JVS(1280)*X(166)
  X(168) = X(168)-JVS(1289)*X(126)
  X(169) = X(169)-JVS(1298)*X(47)-JVS(1299)*X(82)-JVS(1300)*X(150)
  X(170) = X(170)-JVS(1313)*X(117)-JVS(1314)*X(118)-JVS(1315)*X(126)
  X(171) = X(171)-JVS(1325)*X(117)-JVS(1326)*X(118)
  X(172) = X(172)-JVS(1335)*X(128)-JVS(1336)*X(131)-JVS(1337)*X(145)-JVS(1338)*X(148)-JVS(1339)*X(153)-JVS(1340)*X(154)&
             &-JVS(1341)*X(155)-JVS(1342)*X(156)-JVS(1343)*X(158)-JVS(1344)*X(159)-JVS(1345)*X(162)-JVS(1346)*X(170)
  X(173) = X(173)-JVS(1376)*X(110)-JVS(1377)*X(136)-JVS(1378)*X(157)
  X(174) = X(174)-JVS(1386)*X(93)-JVS(1387)*X(115)-JVS(1388)*X(140)-JVS(1389)*X(141)-JVS(1390)*X(161)-JVS(1391)*X(163)&
             &-JVS(1392)*X(165)
  X(175) = X(175)-JVS(1409)*X(89)-JVS(1410)*X(100)-JVS(1411)*X(101)-JVS(1412)*X(124)-JVS(1413)*X(127)-JVS(1414)*X(142)&
             &-JVS(1415)*X(143)-JVS(1416)*X(157)-JVS(1417)*X(173)
  X(177) = X(177)-JVS(1441)*X(101)-JVS(1442)*X(107)-JVS(1443)*X(108)
  X(178) = X(178)-JVS(1452)*X(100)-JVS(1453)*X(152)
  X(179) = X(179)-JVS(1464)*X(112)-JVS(1465)*X(119)-JVS(1466)*X(153)
  X(180) = X(180)-JVS(1477)*X(40)-JVS(1478)*X(48)-JVS(1479)*X(74)-JVS(1480)*X(89)-JVS(1481)*X(90)-JVS(1482)*X(94)&
             &-JVS(1483)*X(97)-JVS(1484)*X(98)-JVS(1485)*X(100)-JVS(1486)*X(101)-JVS(1487)*X(124)-JVS(1488)*X(130)-JVS(1489)&
             &*X(131)-JVS(1490)*X(134)-JVS(1491)*X(142)-JVS(1492)*X(143)-JVS(1493)*X(149)-JVS(1494)*X(150)-JVS(1495)*X(153)&
             &-JVS(1496)*X(155)-JVS(1497)*X(157)-JVS(1498)*X(162)-JVS(1499)*X(170)-JVS(1500)*X(173)-JVS(1501)*X(176)&
             &-JVS(1502)*X(177)-JVS(1503)*X(178)
  X(182) = X(182)-JVS(1536)*X(99)-JVS(1537)*X(107)-JVS(1538)*X(108)-JVS(1539)*X(136)-JVS(1540)*X(176)
  X(183) = X(183)-JVS(1551)*X(62)-JVS(1552)*X(79)-JVS(1553)*X(80)-JVS(1554)*X(141)-JVS(1555)*X(161)-JVS(1556)*X(163)&
             &-JVS(1557)*X(165)-JVS(1558)*X(174)
  X(184) = X(184)-JVS(1575)*X(73)-JVS(1576)*X(156)-JVS(1577)*X(171)
  X(185) = X(185)-JVS(1590)*X(99)-JVS(1591)*X(107)-JVS(1592)*X(108)-JVS(1593)*X(152)
  X(186) = X(186)-JVS(1603)*X(96)-JVS(1604)*X(147)-JVS(1605)*X(152)
  X(187) = X(187)-JVS(1619)*X(126)-JVS(1620)*X(152)-JVS(1621)*X(168)
  X(188) = X(188)-JVS(1633)*X(116)-JVS(1634)*X(138)-JVS(1635)*X(139)-JVS(1636)*X(152)-JVS(1637)*X(181)
  X(189) = X(189)-JVS(1647)*X(83)-JVS(1648)*X(89)-JVS(1649)*X(96)-JVS(1650)*X(101)-JVS(1651)*X(105)-JVS(1652)*X(106)&
             &-JVS(1653)*X(119)-JVS(1654)*X(124)-JVS(1655)*X(125)-JVS(1656)*X(127)-JVS(1657)*X(131)-JVS(1658)*X(133)&
             &-JVS(1659)*X(143)-JVS(1660)*X(146)-JVS(1661)*X(147)-JVS(1662)*X(150)-JVS(1663)*X(152)-JVS(1664)*X(154)&
             &-JVS(1665)*X(155)-JVS(1666)*X(157)-JVS(1667)*X(159)-JVS(1668)*X(162)-JVS(1669)*X(166)-JVS(1670)*X(167)&
             &-JVS(1671)*X(168)-JVS(1672)*X(170)-JVS(1673)*X(171)-JVS(1674)*X(173)-JVS(1675)*X(176)-JVS(1676)*X(177)&
             &-JVS(1677)*X(179)-JVS(1678)*X(181)-JVS(1679)*X(182)-JVS(1680)*X(184)-JVS(1681)*X(185)-JVS(1682)*X(186)&
             &-JVS(1683)*X(187)-JVS(1684)*X(188)
  X(190) = X(190)-JVS(1703)*X(85)-JVS(1704)*X(87)-JVS(1705)*X(88)-JVS(1706)*X(122)-JVS(1707)*X(124)-JVS(1708)*X(158)&
             &-JVS(1709)*X(168)-JVS(1710)*X(171)-JVS(1711)*X(173)-JVS(1712)*X(176)-JVS(1713)*X(177)-JVS(1714)*X(182)&
             &-JVS(1715)*X(185)-JVS(1716)*X(188)
  X(191) = X(191)-JVS(1727)*X(116)-JVS(1728)*X(138)-JVS(1729)*X(139)-JVS(1730)*X(153)-JVS(1731)*X(158)-JVS(1732)*X(170)&
             &-JVS(1733)*X(173)-JVS(1734)*X(176)-JVS(1735)*X(181)-JVS(1736)*X(185)-JVS(1737)*X(188)-JVS(1738)*X(190)
  X(192) = X(192)-JVS(1750)*X(66)-JVS(1751)*X(67)-JVS(1752)*X(77)-JVS(1753)*X(85)-JVS(1754)*X(92)-JVS(1755)*X(93)&
             &-JVS(1756)*X(95)-JVS(1757)*X(113)-JVS(1758)*X(115)-JVS(1759)*X(120)-JVS(1760)*X(137)-JVS(1761)*X(140)&
             &-JVS(1762)*X(141)-JVS(1763)*X(147)-JVS(1764)*X(151)-JVS(1765)*X(152)-JVS(1766)*X(157)-JVS(1767)*X(161)&
             &-JVS(1768)*X(162)-JVS(1769)*X(163)-JVS(1770)*X(165)-JVS(1771)*X(171)-JVS(1772)*X(172)-JVS(1773)*X(173)&
             &-JVS(1774)*X(174)-JVS(1775)*X(175)-JVS(1776)*X(176)-JVS(1777)*X(177)-JVS(1778)*X(178)-JVS(1779)*X(179)&
             &-JVS(1780)*X(181)-JVS(1781)*X(182)-JVS(1782)*X(183)-JVS(1783)*X(184)-JVS(1784)*X(185)-JVS(1785)*X(186)&
             &-JVS(1786)*X(187)-JVS(1787)*X(188)-JVS(1788)*X(189)-JVS(1789)*X(190)-JVS(1790)*X(191)
  X(193) = X(193)-JVS(1810)*X(68)-JVS(1811)*X(115)-JVS(1812)*X(126)-JVS(1813)*X(169)-JVS(1814)*X(181)-JVS(1815)*X(188)&
             &-JVS(1816)*X(190)-JVS(1817)*X(191)
  X(194) = X(194)-JVS(1833)*X(43)-JVS(1834)*X(48)-JVS(1835)*X(65)-JVS(1836)*X(71)-JVS(1837)*X(74)-JVS(1838)*X(83)&
             &-JVS(1839)*X(89)-JVS(1840)*X(90)-JVS(1841)*X(95)-JVS(1842)*X(96)-JVS(1843)*X(97)-JVS(1844)*X(99)-JVS(1845)&
             &*X(100)-JVS(1846)*X(107)-JVS(1847)*X(108)-JVS(1848)*X(112)-JVS(1849)*X(114)-JVS(1850)*X(119)-JVS(1851)*X(125)&
             &-JVS(1852)*X(126)-JVS(1853)*X(131)-JVS(1854)*X(135)-JVS(1855)*X(136)-JVS(1856)*X(138)-JVS(1857)*X(139)&
             &-JVS(1858)*X(142)-JVS(1859)*X(143)-JVS(1860)*X(144)-JVS(1861)*X(145)-JVS(1862)*X(147)-JVS(1863)*X(148)&
             &-JVS(1864)*X(149)-JVS(1865)*X(150)-JVS(1866)*X(152)-JVS(1867)*X(153)-JVS(1868)*X(154)-JVS(1869)*X(155)&
             &-JVS(1870)*X(156)-JVS(1871)*X(157)-JVS(1872)*X(158)-JVS(1873)*X(159)-JVS(1874)*X(162)-JVS(1875)*X(166)&
             &-JVS(1876)*X(167)-JVS(1877)*X(168)-JVS(1878)*X(169)-JVS(1879)*X(170)-JVS(1880)*X(171)-JVS(1881)*X(173)&
             &-JVS(1882)*X(175)-JVS(1883)*X(176)-JVS(1884)*X(177)-JVS(1885)*X(178)-JVS(1886)*X(179)-JVS(1887)*X(181)&
             &-JVS(1888)*X(182)-JVS(1889)*X(183)-JVS(1890)*X(184)-JVS(1891)*X(185)-JVS(1892)*X(186)-JVS(1893)*X(187)&
             &-JVS(1894)*X(188)-JVS(1895)*X(189)-JVS(1896)*X(190)-JVS(1897)*X(191)-JVS(1898)*X(192)-JVS(1899)*X(193)
  X(195) = X(195)-JVS(1918)*X(99)-JVS(1919)*X(107)-JVS(1920)*X(108)-JVS(1921)*X(126)-JVS(1922)*X(147)-JVS(1923)*X(152)&
             &-JVS(1924)*X(168)-JVS(1925)*X(185)-JVS(1926)*X(188)
  X(196) = X(196)-JVS(1939)*X(87)-JVS(1940)*X(100)-JVS(1941)*X(104)-JVS(1942)*X(106)-JVS(1943)*X(116)-JVS(1944)*X(117)&
             &-JVS(1945)*X(118)-JVS(1946)*X(133)-JVS(1947)*X(138)-JVS(1948)*X(139)-JVS(1949)*X(159)-JVS(1950)*X(166)&
             &-JVS(1951)*X(167)-JVS(1952)*X(168)-JVS(1953)*X(170)-JVS(1954)*X(171)-JVS(1955)*X(177)-JVS(1956)*X(178)&
             &-JVS(1957)*X(179)-JVS(1958)*X(181)-JVS(1959)*X(182)-JVS(1960)*X(185)-JVS(1961)*X(186)-JVS(1962)*X(188)&
             &-JVS(1963)*X(190)-JVS(1964)*X(191)-JVS(1965)*X(195)
  X(197) = X(197)-JVS(1979)*X(68)-JVS(1980)*X(82)-JVS(1981)*X(83)-JVS(1982)*X(113)-JVS(1983)*X(128)-JVS(1984)*X(145)&
             &-JVS(1985)*X(150)-JVS(1986)*X(154)-JVS(1987)*X(158)-JVS(1988)*X(169)-JVS(1989)*X(170)-JVS(1990)*X(173)&
             &-JVS(1991)*X(176)-JVS(1992)*X(181)-JVS(1993)*X(185)-JVS(1994)*X(187)-JVS(1995)*X(188)-JVS(1996)*X(190)&
             &-JVS(1997)*X(191)-JVS(1998)*X(193)-JVS(1999)*X(195)-JVS(2000)*X(196)
  X(198) = X(198)-JVS(2016)*X(72)-JVS(2017)*X(84)-JVS(2018)*X(87)-JVS(2019)*X(88)-JVS(2020)*X(110)-JVS(2021)*X(116)&
             &-JVS(2022)*X(117)-JVS(2023)*X(118)-JVS(2024)*X(122)-JVS(2025)*X(124)-JVS(2026)*X(132)-JVS(2027)*X(138)&
             &-JVS(2028)*X(139)-JVS(2029)*X(145)-JVS(2030)*X(146)-JVS(2031)*X(148)-JVS(2032)*X(153)-JVS(2033)*X(154)&
             &-JVS(2034)*X(156)-JVS(2035)*X(157)-JVS(2036)*X(158)-JVS(2037)*X(159)-JVS(2038)*X(166)-JVS(2039)*X(167)&
             &-JVS(2040)*X(168)-JVS(2041)*X(170)-JVS(2042)*X(171)-JVS(2043)*X(173)-JVS(2044)*X(176)-JVS(2045)*X(177)&
             &-JVS(2046)*X(178)-JVS(2047)*X(179)-JVS(2048)*X(181)-JVS(2049)*X(182)-JVS(2050)*X(185)-JVS(2051)*X(186)&
             &-JVS(2052)*X(187)-JVS(2053)*X(188)-JVS(2054)*X(190)-JVS(2055)*X(191)-JVS(2056)*X(195)-JVS(2057)*X(196)
  X(199) = X(199)-JVS(2072)*X(3)-JVS(2073)*X(37)-JVS(2074)*X(38)-JVS(2075)*X(49)-JVS(2076)*X(50)-JVS(2077)*X(52)&
             &-JVS(2078)*X(78)-JVS(2079)*X(86)-JVS(2080)*X(91)-JVS(2081)*X(93)-JVS(2082)*X(102)-JVS(2083)*X(109)-JVS(2084)&
             &*X(111)-JVS(2085)*X(115)-JVS(2086)*X(120)-JVS(2087)*X(121)-JVS(2088)*X(129)-JVS(2089)*X(140)-JVS(2090)*X(141)&
             &-JVS(2091)*X(160)-JVS(2092)*X(161)-JVS(2093)*X(163)-JVS(2094)*X(165)-JVS(2095)*X(174)-JVS(2096)*X(183)&
             &-JVS(2097)*X(184)-JVS(2098)*X(187)-JVS(2099)*X(190)-JVS(2100)*X(191)-JVS(2101)*X(192)-JVS(2102)*X(193)&
             &-JVS(2103)*X(194)-JVS(2104)*X(195)-JVS(2105)*X(196)-JVS(2106)*X(197)-JVS(2107)*X(198)
  X(200) = X(200)-JVS(2121)*X(61)-JVS(2122)*X(81)-JVS(2123)*X(89)-JVS(2124)*X(90)-JVS(2125)*X(97)-JVS(2126)*X(100)&
             &-JVS(2127)*X(112)-JVS(2128)*X(119)-JVS(2129)*X(125)-JVS(2130)*X(134)-JVS(2131)*X(142)-JVS(2132)*X(143)&
             &-JVS(2133)*X(145)-JVS(2134)*X(148)-JVS(2135)*X(150)-JVS(2136)*X(152)-JVS(2137)*X(153)-JVS(2138)*X(154)&
             &-JVS(2139)*X(155)-JVS(2140)*X(156)-JVS(2141)*X(157)-JVS(2142)*X(158)-JVS(2143)*X(159)-JVS(2144)*X(166)&
             &-JVS(2145)*X(167)-JVS(2146)*X(168)-JVS(2147)*X(169)-JVS(2148)*X(170)-JVS(2149)*X(171)-JVS(2150)*X(173)&
             &-JVS(2151)*X(176)-JVS(2152)*X(177)-JVS(2153)*X(178)-JVS(2154)*X(179)-JVS(2155)*X(180)-JVS(2156)*X(181)&
             &-JVS(2157)*X(182)-JVS(2158)*X(184)-JVS(2159)*X(185)-JVS(2160)*X(186)-JVS(2161)*X(187)-JVS(2162)*X(188)&
             &-JVS(2163)*X(189)-JVS(2164)*X(190)-JVS(2165)*X(191)-JVS(2166)*X(193)-JVS(2167)*X(195)-JVS(2168)*X(196)&
             &-JVS(2169)*X(197)-JVS(2170)*X(198)-JVS(2171)*X(199)
  X(201) = X(201)-JVS(2184)*X(65)-JVS(2185)*X(71)-JVS(2186)*X(74)-JVS(2187)*X(76)-JVS(2188)*X(81)-JVS(2189)*X(85)&
             &-JVS(2190)*X(92)-JVS(2191)*X(105)-JVS(2192)*X(115)-JVS(2193)*X(117)-JVS(2194)*X(118)-JVS(2195)*X(119)&
             &-JVS(2196)*X(120)-JVS(2197)*X(121)-JVS(2198)*X(123)-JVS(2199)*X(125)-JVS(2200)*X(126)-JVS(2201)*X(127)&
             &-JVS(2202)*X(128)-JVS(2203)*X(129)-JVS(2204)*X(130)-JVS(2205)*X(131)-JVS(2206)*X(133)-JVS(2207)*X(134)&
             &-JVS(2208)*X(135)-JVS(2209)*X(139)-JVS(2210)*X(142)-JVS(2211)*X(144)-JVS(2212)*X(146)-JVS(2213)*X(147)&
             &-JVS(2214)*X(150)-JVS(2215)*X(152)-JVS(2216)*X(157)-JVS(2217)*X(160)-JVS(2218)*X(161)-JVS(2219)*X(162)&
             &-JVS(2220)*X(163)-JVS(2221)*X(164)-JVS(2222)*X(165)-JVS(2223)*X(166)-JVS(2224)*X(167)-JVS(2225)*X(168)&
             &-JVS(2226)*X(171)-JVS(2227)*X(173)-JVS(2228)*X(174)-JVS(2229)*X(175)-JVS(2230)*X(176)-JVS(2231)*X(177)&
             &-JVS(2232)*X(178)-JVS(2233)*X(179)-JVS(2234)*X(180)-JVS(2235)*X(181)-JVS(2236)*X(182)-JVS(2237)*X(183)&
             &-JVS(2238)*X(184)-JVS(2239)*X(185)-JVS(2240)*X(186)-JVS(2241)*X(187)-JVS(2242)*X(188)-JVS(2243)*X(189)&
             &-JVS(2244)*X(190)-JVS(2245)*X(191)-JVS(2246)*X(192)-JVS(2247)*X(193)-JVS(2248)*X(194)-JVS(2249)*X(195)&
             &-JVS(2250)*X(196)-JVS(2251)*X(197)-JVS(2252)*X(198)-JVS(2253)*X(199)-JVS(2254)*X(200)
  X(202) = X(202)-JVS(2266)*X(46)-JVS(2267)*X(47)-JVS(2268)*X(49)-JVS(2269)*X(64)-JVS(2270)*X(65)-JVS(2271)*X(69)&
             &-JVS(2272)*X(70)-JVS(2273)*X(75)-JVS(2274)*X(76)-JVS(2275)*X(78)-JVS(2276)*X(81)-JVS(2277)*X(84)-JVS(2278)&
             &*X(92)-JVS(2279)*X(94)-JVS(2280)*X(98)-JVS(2281)*X(105)-JVS(2282)*X(110)-JVS(2283)*X(114)-JVS(2284)*X(116)&
             &-JVS(2285)*X(119)-JVS(2286)*X(120)-JVS(2287)*X(121)-JVS(2288)*X(122)-JVS(2289)*X(123)-JVS(2290)*X(124)&
             &-JVS(2291)*X(125)-JVS(2292)*X(127)-JVS(2293)*X(128)-JVS(2294)*X(129)-JVS(2295)*X(130)-JVS(2296)*X(131)&
             &-JVS(2297)*X(133)-JVS(2298)*X(134)-JVS(2299)*X(135)-JVS(2300)*X(136)-JVS(2301)*X(138)-JVS(2302)*X(139)&
             &-JVS(2303)*X(142)-JVS(2304)*X(143)-JVS(2305)*X(145)-JVS(2306)*X(146)-JVS(2307)*X(147)-JVS(2308)*X(148)&
             &-JVS(2309)*X(149)-JVS(2310)*X(150)-JVS(2311)*X(152)-JVS(2312)*X(153)-JVS(2313)*X(154)-JVS(2314)*X(155)&
             &-JVS(2315)*X(156)-JVS(2316)*X(157)-JVS(2317)*X(158)-JVS(2318)*X(159)-JVS(2319)*X(160)-JVS(2320)*X(161)&
             &-JVS(2321)*X(162)-JVS(2322)*X(163)-JVS(2323)*X(164)-JVS(2324)*X(165)-JVS(2325)*X(166)-JVS(2326)*X(167)&
             &-JVS(2327)*X(168)-JVS(2328)*X(169)-JVS(2329)*X(170)-JVS(2330)*X(171)-JVS(2331)*X(173)-JVS(2332)*X(174)&
             &-JVS(2333)*X(175)-JVS(2334)*X(176)-JVS(2335)*X(177)-JVS(2336)*X(178)-JVS(2337)*X(179)-JVS(2338)*X(180)&
             &-JVS(2339)*X(181)-JVS(2340)*X(182)-JVS(2341)*X(183)-JVS(2342)*X(184)-JVS(2343)*X(185)-JVS(2344)*X(186)&
             &-JVS(2345)*X(187)-JVS(2346)*X(188)-JVS(2347)*X(189)-JVS(2348)*X(190)-JVS(2349)*X(191)-JVS(2350)*X(192)&
             &-JVS(2351)*X(193)-JVS(2352)*X(194)-JVS(2353)*X(195)-JVS(2354)*X(196)-JVS(2355)*X(197)-JVS(2356)*X(198)&
             &-JVS(2357)*X(199)-JVS(2358)*X(200)-JVS(2359)*X(201)
  X(203) = X(203)-JVS(2370)*X(54)-JVS(2371)*X(55)-JVS(2372)*X(56)-JVS(2373)*X(60)-JVS(2374)*X(69)-JVS(2375)*X(70)&
             &-JVS(2376)*X(74)-JVS(2377)*X(78)-JVS(2378)*X(94)-JVS(2379)*X(98)-JVS(2380)*X(122)-JVS(2381)*X(123)-JVS(2382)&
             &*X(124)-JVS(2383)*X(127)-JVS(2384)*X(128)-JVS(2385)*X(130)-JVS(2386)*X(131)-JVS(2387)*X(134)-JVS(2388)*X(135)&
             &-JVS(2389)*X(138)-JVS(2390)*X(139)-JVS(2391)*X(143)-JVS(2392)*X(145)-JVS(2393)*X(147)-JVS(2394)*X(148)&
             &-JVS(2395)*X(150)-JVS(2396)*X(152)-JVS(2397)*X(153)-JVS(2398)*X(154)-JVS(2399)*X(155)-JVS(2400)*X(156)&
             &-JVS(2401)*X(157)-JVS(2402)*X(158)-JVS(2403)*X(159)-JVS(2404)*X(160)-JVS(2405)*X(162)-JVS(2406)*X(163)&
             &-JVS(2407)*X(165)-JVS(2408)*X(166)-JVS(2409)*X(167)-JVS(2410)*X(168)-JVS(2411)*X(169)-JVS(2412)*X(170)&
             &-JVS(2413)*X(171)-JVS(2414)*X(173)-JVS(2415)*X(176)-JVS(2416)*X(177)-JVS(2417)*X(178)-JVS(2418)*X(179)&
             &-JVS(2419)*X(181)-JVS(2420)*X(182)-JVS(2421)*X(183)-JVS(2422)*X(184)-JVS(2423)*X(185)-JVS(2424)*X(186)&
             &-JVS(2425)*X(187)-JVS(2426)*X(188)-JVS(2427)*X(190)-JVS(2428)*X(191)-JVS(2429)*X(192)-JVS(2430)*X(193)&
             &-JVS(2431)*X(194)-JVS(2432)*X(195)-JVS(2433)*X(196)-JVS(2434)*X(197)-JVS(2435)*X(198)-JVS(2436)*X(199)&
             &-JVS(2437)*X(200)-JVS(2438)*X(201)-JVS(2439)*X(202)
  X(204) = X(204)-JVS(2449)*X(44)-JVS(2450)*X(50)-JVS(2451)*X(61)-JVS(2452)*X(65)-JVS(2453)*X(71)-JVS(2454)*X(77)&
             &-JVS(2455)*X(81)-JVS(2456)*X(95)-JVS(2457)*X(125)-JVS(2458)*X(134)-JVS(2459)*X(138)-JVS(2460)*X(139)-JVS(2461)&
             &*X(145)-JVS(2462)*X(148)-JVS(2463)*X(149)-JVS(2464)*X(150)-JVS(2465)*X(152)-JVS(2466)*X(153)-JVS(2467)*X(154)&
             &-JVS(2468)*X(155)-JVS(2469)*X(156)-JVS(2470)*X(157)-JVS(2471)*X(158)-JVS(2472)*X(159)-JVS(2473)*X(166)&
             &-JVS(2474)*X(167)-JVS(2475)*X(168)-JVS(2476)*X(169)-JVS(2477)*X(170)-JVS(2478)*X(171)-JVS(2479)*X(172)&
             &-JVS(2480)*X(173)-JVS(2481)*X(176)-JVS(2482)*X(177)-JVS(2483)*X(178)-JVS(2484)*X(179)-JVS(2485)*X(181)&
             &-JVS(2486)*X(182)-JVS(2487)*X(183)-JVS(2488)*X(184)-JVS(2489)*X(185)-JVS(2490)*X(186)-JVS(2491)*X(187)&
             &-JVS(2492)*X(188)-JVS(2493)*X(189)-JVS(2494)*X(190)-JVS(2495)*X(191)-JVS(2496)*X(192)-JVS(2497)*X(193)&
             &-JVS(2498)*X(194)-JVS(2499)*X(195)-JVS(2500)*X(196)-JVS(2501)*X(197)-JVS(2502)*X(198)-JVS(2503)*X(199)&
             &-JVS(2504)*X(200)-JVS(2505)*X(201)-JVS(2506)*X(202)-JVS(2507)*X(203)
  X(205) = X(205)-JVS(2516)*X(37)-JVS(2517)*X(38)-JVS(2518)*X(40)-JVS(2519)*X(44)-JVS(2520)*X(50)-JVS(2521)*X(51)&
             &-JVS(2522)*X(53)-JVS(2523)*X(57)-JVS(2524)*X(58)-JVS(2525)*X(61)-JVS(2526)*X(62)-JVS(2527)*X(66)-JVS(2528)&
             &*X(67)-JVS(2529)*X(68)-JVS(2530)*X(69)-JVS(2531)*X(71)-JVS(2532)*X(72)-JVS(2533)*X(73)-JVS(2534)*X(75)&
             &-JVS(2535)*X(76)-JVS(2536)*X(77)-JVS(2537)*X(78)-JVS(2538)*X(80)-JVS(2539)*X(82)-JVS(2540)*X(83)-JVS(2541)&
             &*X(84)-JVS(2542)*X(85)-JVS(2543)*X(86)-JVS(2544)*X(87)-JVS(2545)*X(88)-JVS(2546)*X(89)-JVS(2547)*X(90)&
             &-JVS(2548)*X(92)-JVS(2549)*X(93)-JVS(2550)*X(94)-JVS(2551)*X(95)-JVS(2552)*X(96)-JVS(2553)*X(97)-JVS(2554)&
             &*X(98)-JVS(2555)*X(99)-JVS(2556)*X(100)-JVS(2557)*X(101)-JVS(2558)*X(102)-JVS(2559)*X(103)-JVS(2560)*X(104)&
             &-JVS(2561)*X(105)-JVS(2562)*X(106)-JVS(2563)*X(107)-JVS(2564)*X(108)-JVS(2565)*X(109)-JVS(2566)*X(110)&
             &-JVS(2567)*X(111)-JVS(2568)*X(112)-JVS(2569)*X(113)-JVS(2570)*X(114)-JVS(2571)*X(115)-JVS(2572)*X(116)&
             &-JVS(2573)*X(117)-JVS(2574)*X(118)-JVS(2575)*X(119)-JVS(2576)*X(120)-JVS(2577)*X(122)-JVS(2578)*X(124)&
             &-JVS(2579)*X(125)-JVS(2580)*X(126)-JVS(2581)*X(129)-JVS(2582)*X(131)-JVS(2583)*X(132)-JVS(2584)*X(133)&
             &-JVS(2585)*X(136)-JVS(2586)*X(137)-JVS(2587)*X(138)-JVS(2588)*X(139)-JVS(2589)*X(140)-JVS(2590)*X(141)&
             &-JVS(2591)*X(142)-JVS(2592)*X(143)-JVS(2593)*X(144)-JVS(2594)*X(145)-JVS(2595)*X(146)-JVS(2596)*X(147)&
             &-JVS(2597)*X(148)-JVS(2598)*X(149)-JVS(2599)*X(150)-JVS(2600)*X(151)-JVS(2601)*X(152)-JVS(2602)*X(153)&
             &-JVS(2603)*X(154)-JVS(2604)*X(155)-JVS(2605)*X(156)-JVS(2606)*X(157)-JVS(2607)*X(158)-JVS(2608)*X(159)&
             &-JVS(2609)*X(160)-JVS(2610)*X(161)-JVS(2611)*X(162)-JVS(2612)*X(163)-JVS(2613)*X(164)-JVS(2614)*X(165)&
             &-JVS(2615)*X(166)-JVS(2616)*X(167)-JVS(2617)*X(168)-JVS(2618)*X(169)-JVS(2619)*X(170)-JVS(2620)*X(171)&
             &-JVS(2621)*X(172)-JVS(2622)*X(173)-JVS(2623)*X(174)-JVS(2624)*X(175)-JVS(2625)*X(176)-JVS(2626)*X(177)&
             &-JVS(2627)*X(178)-JVS(2628)*X(179)-JVS(2629)*X(180)-JVS(2630)*X(181)-JVS(2631)*X(182)-JVS(2632)*X(183)&
             &-JVS(2633)*X(184)-JVS(2634)*X(185)-JVS(2635)*X(186)-JVS(2636)*X(187)-JVS(2637)*X(188)-JVS(2638)*X(189)&
             &-JVS(2639)*X(190)-JVS(2640)*X(191)-JVS(2641)*X(192)-JVS(2642)*X(193)-JVS(2643)*X(194)-JVS(2644)*X(195)&
             &-JVS(2645)*X(196)-JVS(2646)*X(197)-JVS(2647)*X(198)-JVS(2648)*X(199)-JVS(2649)*X(200)-JVS(2650)*X(201)&
             &-JVS(2651)*X(202)-JVS(2652)*X(203)-JVS(2653)*X(204)
  X(206) = X(206)-JVS(2661)*X(66)-JVS(2662)*X(67)-JVS(2663)*X(77)-JVS(2664)*X(89)-JVS(2665)*X(94)-JVS(2666)*X(96)&
             &-JVS(2667)*X(97)-JVS(2668)*X(101)-JVS(2669)*X(106)-JVS(2670)*X(114)-JVS(2671)*X(117)-JVS(2672)*X(118)&
             &-JVS(2673)*X(119)-JVS(2674)*X(123)-JVS(2675)*X(125)-JVS(2676)*X(126)-JVS(2677)*X(127)-JVS(2678)*X(128)&
             &-JVS(2679)*X(130)-JVS(2680)*X(134)-JVS(2681)*X(136)-JVS(2682)*X(143)-JVS(2683)*X(144)-JVS(2684)*X(147)&
             &-JVS(2685)*X(149)-JVS(2686)*X(150)-JVS(2687)*X(152)-JVS(2688)*X(153)-JVS(2689)*X(157)-JVS(2690)*X(162)&
             &-JVS(2691)*X(173)-JVS(2692)*X(175)-JVS(2693)*X(176)-JVS(2694)*X(177)-JVS(2695)*X(178)-JVS(2696)*X(179)&
             &-JVS(2697)*X(180)-JVS(2698)*X(181)-JVS(2699)*X(182)-JVS(2700)*X(184)-JVS(2701)*X(185)-JVS(2702)*X(186)&
             &-JVS(2703)*X(187)-JVS(2704)*X(188)-JVS(2705)*X(189)-JVS(2706)*X(190)-JVS(2707)*X(191)-JVS(2708)*X(194)&
             &-JVS(2709)*X(195)-JVS(2710)*X(196)-JVS(2711)*X(197)-JVS(2712)*X(198)-JVS(2713)*X(199)-JVS(2714)*X(200)&
             &-JVS(2715)*X(201)-JVS(2716)*X(202)-JVS(2717)*X(203)-JVS(2718)*X(204)-JVS(2719)*X(205)
  X(207) = X(207)-JVS(2726)*X(71)-JVS(2727)*X(123)-JVS(2728)*X(127)-JVS(2729)*X(128)-JVS(2730)*X(130)-JVS(2731)*X(134)&
             &-JVS(2732)*X(135)-JVS(2733)*X(147)-JVS(2734)*X(152)-JVS(2735)*X(182)-JVS(2736)*X(185)-JVS(2737)*X(187)&
             &-JVS(2738)*X(188)-JVS(2739)*X(195)-JVS(2740)*X(199)-JVS(2741)*X(200)-JVS(2742)*X(201)-JVS(2743)*X(202)&
             &-JVS(2744)*X(203)-JVS(2745)*X(204)-JVS(2746)*X(205)-JVS(2747)*X(206)
  X(208) = X(208)-JVS(2753)*X(80)-JVS(2754)*X(104)-JVS(2755)*X(109)-JVS(2756)*X(111)-JVS(2757)*X(117)-JVS(2758)*X(118)&
             &-JVS(2759)*X(119)-JVS(2760)*X(126)-JVS(2761)*X(136)-JVS(2762)*X(140)-JVS(2763)*X(146)-JVS(2764)*X(150)&
             &-JVS(2765)*X(152)-JVS(2766)*X(160)-JVS(2767)*X(161)-JVS(2768)*X(163)-JVS(2769)*X(165)-JVS(2770)*X(166)&
             &-JVS(2771)*X(167)-JVS(2772)*X(168)-JVS(2773)*X(169)-JVS(2774)*X(171)-JVS(2775)*X(174)-JVS(2776)*X(176)&
             &-JVS(2777)*X(177)-JVS(2778)*X(179)-JVS(2779)*X(181)-JVS(2780)*X(182)-JVS(2781)*X(183)-JVS(2782)*X(184)&
             &-JVS(2783)*X(185)-JVS(2784)*X(187)-JVS(2785)*X(188)-JVS(2786)*X(190)-JVS(2787)*X(191)-JVS(2788)*X(192)&
             &-JVS(2789)*X(193)-JVS(2790)*X(194)-JVS(2791)*X(195)-JVS(2792)*X(196)-JVS(2793)*X(197)-JVS(2794)*X(198)&
             &-JVS(2795)*X(199)-JVS(2796)*X(200)-JVS(2797)*X(201)-JVS(2798)*X(202)-JVS(2799)*X(203)-JVS(2800)*X(204)&
             &-JVS(2801)*X(205)-JVS(2802)*X(206)-JVS(2803)*X(207)
  X(209) = X(209)-JVS(2808)*X(50)-JVS(2809)*X(55)-JVS(2810)*X(56)-JVS(2811)*X(60)-JVS(2812)*X(65)-JVS(2813)*X(66)&
             &-JVS(2814)*X(67)-JVS(2815)*X(68)-JVS(2816)*X(72)-JVS(2817)*X(73)-JVS(2818)*X(74)-JVS(2819)*X(76)-JVS(2820)&
             &*X(77)-JVS(2821)*X(82)-JVS(2822)*X(83)-JVS(2823)*X(84)-JVS(2824)*X(87)-JVS(2825)*X(88)-JVS(2826)*X(89)&
             &-JVS(2827)*X(94)-JVS(2828)*X(95)-JVS(2829)*X(96)-JVS(2830)*X(97)-JVS(2831)*X(98)-JVS(2832)*X(99)-JVS(2833)&
             &*X(100)-JVS(2834)*X(101)-JVS(2835)*X(104)-JVS(2836)*X(106)-JVS(2837)*X(107)-JVS(2838)*X(108)-JVS(2839)*X(110)&
             &-JVS(2840)*X(113)-JVS(2841)*X(114)-JVS(2842)*X(116)-JVS(2843)*X(117)-JVS(2844)*X(118)-JVS(2845)*X(122)&
             &-JVS(2846)*X(124)-JVS(2847)*X(125)-JVS(2848)*X(126)-JVS(2849)*X(131)-JVS(2850)*X(132)-JVS(2851)*X(136)&
             &-JVS(2852)*X(137)-JVS(2853)*X(138)-JVS(2854)*X(139)-JVS(2855)*X(143)-JVS(2856)*X(144)-JVS(2857)*X(145)&
             &-JVS(2858)*X(147)-JVS(2859)*X(148)-JVS(2860)*X(150)-JVS(2861)*X(151)-JVS(2862)*X(152)-JVS(2863)*X(153)&
             &-JVS(2864)*X(154)-JVS(2865)*X(155)-JVS(2866)*X(156)-JVS(2867)*X(157)-JVS(2868)*X(158)-JVS(2869)*X(159)&
             &-JVS(2870)*X(160)-JVS(2871)*X(162)-JVS(2872)*X(163)-JVS(2873)*X(165)-JVS(2874)*X(166)-JVS(2875)*X(167)&
             &-JVS(2876)*X(168)-JVS(2877)*X(169)-JVS(2878)*X(170)-JVS(2879)*X(171)-JVS(2880)*X(173)-JVS(2881)*X(175)&
             &-JVS(2882)*X(176)-JVS(2883)*X(177)-JVS(2884)*X(178)-JVS(2885)*X(179)-JVS(2886)*X(180)-JVS(2887)*X(181)&
             &-JVS(2888)*X(182)-JVS(2889)*X(183)-JVS(2890)*X(184)-JVS(2891)*X(185)-JVS(2892)*X(186)-JVS(2893)*X(187)&
             &-JVS(2894)*X(188)-JVS(2895)*X(189)-JVS(2896)*X(190)-JVS(2897)*X(191)-JVS(2898)*X(192)-JVS(2899)*X(193)&
             &-JVS(2900)*X(194)-JVS(2901)*X(195)-JVS(2902)*X(196)-JVS(2903)*X(197)-JVS(2904)*X(198)-JVS(2905)*X(199)&
             &-JVS(2906)*X(200)-JVS(2907)*X(201)-JVS(2908)*X(202)-JVS(2909)*X(203)-JVS(2910)*X(204)-JVS(2911)*X(205)&
             &-JVS(2912)*X(206)-JVS(2913)*X(207)-JVS(2914)*X(208)
  X(210) = X(210)-JVS(2918)*X(2)-JVS(2919)*X(62)-JVS(2920)*X(63)-JVS(2921)*X(66)-JVS(2922)*X(67)-JVS(2923)*X(75)&
             &-JVS(2924)*X(77)-JVS(2925)*X(78)-JVS(2926)*X(79)-JVS(2927)*X(85)-JVS(2928)*X(86)-JVS(2929)*X(91)-JVS(2930)&
             &*X(92)-JVS(2931)*X(93)-JVS(2932)*X(95)-JVS(2933)*X(103)-JVS(2934)*X(109)-JVS(2935)*X(111)-JVS(2936)*X(113)&
             &-JVS(2937)*X(115)-JVS(2938)*X(120)-JVS(2939)*X(121)-JVS(2940)*X(129)-JVS(2941)*X(137)-JVS(2942)*X(140)&
             &-JVS(2943)*X(141)-JVS(2944)*X(147)-JVS(2945)*X(151)-JVS(2946)*X(152)-JVS(2947)*X(157)-JVS(2948)*X(160)&
             &-JVS(2949)*X(161)-JVS(2950)*X(162)-JVS(2951)*X(163)-JVS(2952)*X(165)-JVS(2953)*X(171)-JVS(2954)*X(172)&
             &-JVS(2955)*X(173)-JVS(2956)*X(174)-JVS(2957)*X(175)-JVS(2958)*X(176)-JVS(2959)*X(177)-JVS(2960)*X(178)&
             &-JVS(2961)*X(179)-JVS(2962)*X(181)-JVS(2963)*X(182)-JVS(2964)*X(183)-JVS(2965)*X(184)-JVS(2966)*X(185)&
             &-JVS(2967)*X(186)-JVS(2968)*X(187)-JVS(2969)*X(188)-JVS(2970)*X(189)-JVS(2971)*X(190)-JVS(2972)*X(191)&
             &-JVS(2973)*X(192)-JVS(2974)*X(193)-JVS(2975)*X(194)-JVS(2976)*X(195)-JVS(2977)*X(196)-JVS(2978)*X(197)&
             &-JVS(2979)*X(198)-JVS(2980)*X(199)-JVS(2981)*X(200)-JVS(2982)*X(201)-JVS(2983)*X(202)-JVS(2984)*X(203)&
             &-JVS(2985)*X(204)-JVS(2986)*X(205)-JVS(2987)*X(206)-JVS(2988)*X(207)-JVS(2989)*X(208)-JVS(2990)*X(209)
  X(211) = X(211)-JVS(2993)*X(99)-JVS(2994)*X(107)-JVS(2995)*X(108)-JVS(2996)*X(123)-JVS(2997)*X(152)-JVS(2998)*X(185)&
             &-JVS(2999)*X(188)-JVS(3000)*X(200)-JVS(3001)*X(201)-JVS(3002)*X(202)-JVS(3003)*X(203)-JVS(3004)*X(204)&
             &-JVS(3005)*X(205)-JVS(3006)*X(206)-JVS(3007)*X(207)-JVS(3008)*X(208)-JVS(3009)*X(209)-JVS(3010)*X(210)
  X(211) = X(211)/JVS(3011)
  X(210) = (X(210)-JVS(2992)*X(211))/(JVS(2991))
  X(209) = (X(209)-JVS(2916)*X(210)-JVS(2917)*X(211))/(JVS(2915))
  X(208) = (X(208)-JVS(2805)*X(209)-JVS(2806)*X(210)-JVS(2807)*X(211))/(JVS(2804))
  X(207) = (X(207)-JVS(2749)*X(208)-JVS(2750)*X(209)-JVS(2751)*X(210)-JVS(2752)*X(211))/(JVS(2748))
  X(206) = (X(206)-JVS(2721)*X(207)-JVS(2722)*X(208)-JVS(2723)*X(209)-JVS(2724)*X(210)-JVS(2725)*X(211))/(JVS(2720))
  X(205) = (X(205)-JVS(2655)*X(206)-JVS(2656)*X(207)-JVS(2657)*X(208)-JVS(2658)*X(209)-JVS(2659)*X(210)-JVS(2660)&
             &*X(211))/(JVS(2654))
  X(204) = (X(204)-JVS(2509)*X(205)-JVS(2510)*X(206)-JVS(2511)*X(207)-JVS(2512)*X(208)-JVS(2513)*X(209)-JVS(2514)*X(210)&
             &-JVS(2515)*X(211))/(JVS(2508))
  X(203) = (X(203)-JVS(2441)*X(204)-JVS(2442)*X(205)-JVS(2443)*X(206)-JVS(2444)*X(207)-JVS(2445)*X(208)-JVS(2446)*X(209)&
             &-JVS(2447)*X(210)-JVS(2448)*X(211))/(JVS(2440))
  X(202) = (X(202)-JVS(2361)*X(203)-JVS(2362)*X(204)-JVS(2363)*X(205)-JVS(2364)*X(206)-JVS(2365)*X(207)-JVS(2366)*X(208)&
             &-JVS(2367)*X(209)-JVS(2368)*X(210)-JVS(2369)*X(211))/(JVS(2360))
  X(201) = (X(201)-JVS(2256)*X(202)-JVS(2257)*X(203)-JVS(2258)*X(204)-JVS(2259)*X(205)-JVS(2260)*X(206)-JVS(2261)*X(207)&
             &-JVS(2262)*X(208)-JVS(2263)*X(209)-JVS(2264)*X(210)-JVS(2265)*X(211))/(JVS(2255))
  X(200) = (X(200)-JVS(2173)*X(201)-JVS(2174)*X(202)-JVS(2175)*X(203)-JVS(2176)*X(204)-JVS(2177)*X(205)-JVS(2178)*X(206)&
             &-JVS(2179)*X(207)-JVS(2180)*X(208)-JVS(2181)*X(209)-JVS(2182)*X(210)-JVS(2183)*X(211))/(JVS(2172))
  X(199) = (X(199)-JVS(2109)*X(200)-JVS(2110)*X(201)-JVS(2111)*X(202)-JVS(2112)*X(203)-JVS(2113)*X(204)-JVS(2114)*X(205)&
             &-JVS(2115)*X(206)-JVS(2116)*X(207)-JVS(2117)*X(208)-JVS(2118)*X(209)-JVS(2119)*X(210)-JVS(2120)*X(211))&
             &/(JVS(2108))
  X(198) = (X(198)-JVS(2059)*X(199)-JVS(2060)*X(200)-JVS(2061)*X(201)-JVS(2062)*X(202)-JVS(2063)*X(203)-JVS(2064)*X(204)&
             &-JVS(2065)*X(205)-JVS(2066)*X(206)-JVS(2067)*X(207)-JVS(2068)*X(208)-JVS(2069)*X(209)-JVS(2070)*X(210)&
             &-JVS(2071)*X(211))/(JVS(2058))
  X(197) = (X(197)-JVS(2002)*X(198)-JVS(2003)*X(199)-JVS(2004)*X(200)-JVS(2005)*X(201)-JVS(2006)*X(202)-JVS(2007)*X(203)&
             &-JVS(2008)*X(204)-JVS(2009)*X(205)-JVS(2010)*X(206)-JVS(2011)*X(207)-JVS(2012)*X(208)-JVS(2013)*X(209)&
             &-JVS(2014)*X(210)-JVS(2015)*X(211))/(JVS(2001))
  X(196) = (X(196)-JVS(1967)*X(200)-JVS(1968)*X(201)-JVS(1969)*X(202)-JVS(1970)*X(203)-JVS(1971)*X(204)-JVS(1972)*X(205)&
             &-JVS(1973)*X(206)-JVS(1974)*X(207)-JVS(1975)*X(208)-JVS(1976)*X(209)-JVS(1977)*X(210)-JVS(1978)*X(211))&
             &/(JVS(1966))
  X(195) = (X(195)-JVS(1928)*X(200)-JVS(1929)*X(201)-JVS(1930)*X(202)-JVS(1931)*X(203)-JVS(1932)*X(204)-JVS(1933)*X(205)&
             &-JVS(1934)*X(206)-JVS(1935)*X(207)-JVS(1936)*X(208)-JVS(1937)*X(209)-JVS(1938)*X(210))/(JVS(1927))
  X(194) = (X(194)-JVS(1901)*X(195)-JVS(1902)*X(196)-JVS(1903)*X(197)-JVS(1904)*X(198)-JVS(1905)*X(199)-JVS(1906)*X(200)&
             &-JVS(1907)*X(201)-JVS(1908)*X(202)-JVS(1909)*X(203)-JVS(1910)*X(204)-JVS(1911)*X(205)-JVS(1912)*X(206)&
             &-JVS(1913)*X(207)-JVS(1914)*X(208)-JVS(1915)*X(209)-JVS(1916)*X(210)-JVS(1917)*X(211))/(JVS(1900))
  X(193) = (X(193)-JVS(1819)*X(195)-JVS(1820)*X(196)-JVS(1821)*X(198)-JVS(1822)*X(199)-JVS(1823)*X(200)-JVS(1824)*X(201)&
             &-JVS(1825)*X(202)-JVS(1826)*X(203)-JVS(1827)*X(204)-JVS(1828)*X(205)-JVS(1829)*X(208)-JVS(1830)*X(209)&
             &-JVS(1831)*X(210)-JVS(1832)*X(211))/(JVS(1818))
  X(192) = (X(192)-JVS(1792)*X(193)-JVS(1793)*X(194)-JVS(1794)*X(195)-JVS(1795)*X(196)-JVS(1796)*X(197)-JVS(1797)*X(199)&
             &-JVS(1798)*X(200)-JVS(1799)*X(201)-JVS(1800)*X(202)-JVS(1801)*X(203)-JVS(1802)*X(204)-JVS(1803)*X(205)&
             &-JVS(1804)*X(206)-JVS(1805)*X(207)-JVS(1806)*X(208)-JVS(1807)*X(209)-JVS(1808)*X(210)-JVS(1809)*X(211))&
             &/(JVS(1791))
  X(191) = (X(191)-JVS(1740)*X(195)-JVS(1741)*X(196)-JVS(1742)*X(200)-JVS(1743)*X(201)-JVS(1744)*X(203)-JVS(1745)*X(204)&
             &-JVS(1746)*X(205)-JVS(1747)*X(208)-JVS(1748)*X(209)-JVS(1749)*X(210))/(JVS(1739))
  X(190) = (X(190)-JVS(1718)*X(191)-JVS(1719)*X(200)-JVS(1720)*X(201)-JVS(1721)*X(203)-JVS(1722)*X(204)-JVS(1723)*X(205)&
             &-JVS(1724)*X(208)-JVS(1725)*X(209)-JVS(1726)*X(210))/(JVS(1717))
  X(189) = (X(189)-JVS(1686)*X(190)-JVS(1687)*X(191)-JVS(1688)*X(195)-JVS(1689)*X(196)-JVS(1690)*X(199)-JVS(1691)*X(200)&
             &-JVS(1692)*X(201)-JVS(1693)*X(202)-JVS(1694)*X(203)-JVS(1695)*X(204)-JVS(1696)*X(205)-JVS(1697)*X(206)&
             &-JVS(1698)*X(207)-JVS(1699)*X(208)-JVS(1700)*X(209)-JVS(1701)*X(210)-JVS(1702)*X(211))/(JVS(1685))
  X(188) = (X(188)-JVS(1639)*X(200)-JVS(1640)*X(201)-JVS(1641)*X(203)-JVS(1642)*X(204)-JVS(1643)*X(205)-JVS(1644)*X(208)&
             &-JVS(1645)*X(209)-JVS(1646)*X(210))/(JVS(1638))
  X(187) = (X(187)-JVS(1623)*X(199)-JVS(1624)*X(200)-JVS(1625)*X(201)-JVS(1626)*X(203)-JVS(1627)*X(204)-JVS(1628)*X(205)&
             &-JVS(1629)*X(208)-JVS(1630)*X(209)-JVS(1631)*X(210)-JVS(1632)*X(211))/(JVS(1622))
  X(186) = (X(186)-JVS(1607)*X(195)-JVS(1608)*X(200)-JVS(1609)*X(201)-JVS(1610)*X(202)-JVS(1611)*X(203)-JVS(1612)*X(204)&
             &-JVS(1613)*X(205)-JVS(1614)*X(206)-JVS(1615)*X(207)-JVS(1616)*X(208)-JVS(1617)*X(209)-JVS(1618)*X(210))&
             &/(JVS(1606))
  X(185) = (X(185)-JVS(1595)*X(200)-JVS(1596)*X(201)-JVS(1597)*X(203)-JVS(1598)*X(204)-JVS(1599)*X(205)-JVS(1600)*X(208)&
             &-JVS(1601)*X(209)-JVS(1602)*X(210))/(JVS(1594))
  X(184) = (X(184)-JVS(1579)*X(190)-JVS(1580)*X(191)-JVS(1581)*X(199)-JVS(1582)*X(200)-JVS(1583)*X(201)-JVS(1584)*X(203)&
             &-JVS(1585)*X(204)-JVS(1586)*X(205)-JVS(1587)*X(208)-JVS(1588)*X(209)-JVS(1589)*X(210))/(JVS(1578))
  X(183) = (X(183)-JVS(1560)*X(184)-JVS(1561)*X(187)-JVS(1562)*X(192)-JVS(1563)*X(193)-JVS(1564)*X(194)-JVS(1565)*X(197)&
             &-JVS(1566)*X(199)-JVS(1567)*X(201)-JVS(1568)*X(202)-JVS(1569)*X(203)-JVS(1570)*X(204)-JVS(1571)*X(205)&
             &-JVS(1572)*X(208)-JVS(1573)*X(209)-JVS(1574)*X(210))/(JVS(1559))
  X(182) = (X(182)-JVS(1542)*X(185)-JVS(1543)*X(188)-JVS(1544)*X(200)-JVS(1545)*X(201)-JVS(1546)*X(203)-JVS(1547)*X(204)&
             &-JVS(1548)*X(205)-JVS(1549)*X(208)-JVS(1550)*X(209))/(JVS(1541))
  X(181) = (X(181)-JVS(1529)*X(188)-JVS(1530)*X(200)-JVS(1531)*X(201)-JVS(1532)*X(203)-JVS(1533)*X(204)-JVS(1534)*X(205)&
             &-JVS(1535)*X(208))/(JVS(1528))
  X(180) = (X(180)-JVS(1505)*X(181)-JVS(1506)*X(182)-JVS(1507)*X(184)-JVS(1508)*X(185)-JVS(1509)*X(186)-JVS(1510)*X(187)&
             &-JVS(1511)*X(188)-JVS(1512)*X(189)-JVS(1513)*X(195)-JVS(1514)*X(196)-JVS(1515)*X(199)-JVS(1516)*X(200)&
             &-JVS(1517)*X(201)-JVS(1518)*X(202)-JVS(1519)*X(203)-JVS(1520)*X(204)-JVS(1521)*X(205)-JVS(1522)*X(206)&
             &-JVS(1523)*X(207)-JVS(1524)*X(208)-JVS(1525)*X(209)-JVS(1526)*X(210)-JVS(1527)*X(211))/(JVS(1504))
  X(179) = (X(179)-JVS(1468)*X(195)-JVS(1469)*X(200)-JVS(1470)*X(201)-JVS(1471)*X(202)-JVS(1472)*X(203)-JVS(1473)*X(204)&
             &-JVS(1474)*X(205)-JVS(1475)*X(208)-JVS(1476)*X(209))/(JVS(1467))
  X(178) = (X(178)-JVS(1455)*X(200)-JVS(1456)*X(201)-JVS(1457)*X(203)-JVS(1458)*X(204)-JVS(1459)*X(205)-JVS(1460)*X(208)&
             &-JVS(1461)*X(209)-JVS(1462)*X(210)-JVS(1463)*X(211))/(JVS(1454))
  X(177) = (X(177)-JVS(1445)*X(182)-JVS(1446)*X(185)-JVS(1447)*X(200)-JVS(1448)*X(203)-JVS(1449)*X(204)-JVS(1450)*X(205)&
             &-JVS(1451)*X(209))/(JVS(1444))
  X(176) = (X(176)-JVS(1435)*X(185)-JVS(1436)*X(188)-JVS(1437)*X(203)-JVS(1438)*X(204)-JVS(1439)*X(205)-JVS(1440)&
             &*X(208))/(JVS(1434))
  X(175) = (X(175)-JVS(1419)*X(176)-JVS(1420)*X(177)-JVS(1421)*X(178)-JVS(1422)*X(181)-JVS(1423)*X(182)-JVS(1424)*X(185)&
             &-JVS(1425)*X(200)-JVS(1426)*X(202)-JVS(1427)*X(203)-JVS(1428)*X(204)-JVS(1429)*X(205)-JVS(1430)*X(206)&
             &-JVS(1431)*X(207)-JVS(1432)*X(208)-JVS(1433)*X(209))/(JVS(1418))
  X(174) = (X(174)-JVS(1394)*X(183)-JVS(1395)*X(184)-JVS(1396)*X(187)-JVS(1397)*X(192)-JVS(1398)*X(194)-JVS(1399)*X(197)&
             &-JVS(1400)*X(199)-JVS(1401)*X(201)-JVS(1402)*X(202)-JVS(1403)*X(203)-JVS(1404)*X(204)-JVS(1405)*X(205)&
             &-JVS(1406)*X(208)-JVS(1407)*X(209)-JVS(1408)*X(210))/(JVS(1393))
  X(173) = (X(173)-JVS(1380)*X(176)-JVS(1381)*X(185)-JVS(1382)*X(203)-JVS(1383)*X(205)-JVS(1384)*X(208)-JVS(1385)&
             &*X(209))/(JVS(1379))
  X(172) = (X(172)-JVS(1348)*X(173)-JVS(1349)*X(176)-JVS(1350)*X(177)-JVS(1351)*X(178)-JVS(1352)*X(179)-JVS(1353)*X(184)&
             &-JVS(1354)*X(185)-JVS(1355)*X(186)-JVS(1356)*X(187)-JVS(1357)*X(188)-JVS(1358)*X(189)-JVS(1359)*X(190)&
             &-JVS(1360)*X(191)-JVS(1361)*X(193)-JVS(1362)*X(195)-JVS(1363)*X(196)-JVS(1364)*X(199)-JVS(1365)*X(200)&
             &-JVS(1366)*X(201)-JVS(1367)*X(202)-JVS(1368)*X(203)-JVS(1369)*X(204)-JVS(1370)*X(205)-JVS(1371)*X(206)&
             &-JVS(1372)*X(207)-JVS(1373)*X(208)-JVS(1374)*X(209)-JVS(1375)*X(210))/(JVS(1347))
  X(171) = (X(171)-JVS(1328)*X(200)-JVS(1329)*X(201)-JVS(1330)*X(203)-JVS(1331)*X(204)-JVS(1332)*X(205)-JVS(1333)*X(208)&
             &-JVS(1334)*X(209))/(JVS(1327))
  X(170) = (X(170)-JVS(1317)*X(196)-JVS(1318)*X(200)-JVS(1319)*X(201)-JVS(1320)*X(203)-JVS(1321)*X(204)-JVS(1322)*X(205)&
             &-JVS(1323)*X(208)-JVS(1324)*X(209))/(JVS(1316))
  X(169) = (X(169)-JVS(1302)*X(181)-JVS(1303)*X(196)-JVS(1304)*X(198)-JVS(1305)*X(200)-JVS(1306)*X(201)-JVS(1307)*X(202)&
             &-JVS(1308)*X(203)-JVS(1309)*X(204)-JVS(1310)*X(205)-JVS(1311)*X(209)-JVS(1312)*X(211))/(JVS(1301))
  X(168) = (X(168)-JVS(1291)*X(200)-JVS(1292)*X(201)-JVS(1293)*X(203)-JVS(1294)*X(204)-JVS(1295)*X(205)-JVS(1296)*X(208)&
             &-JVS(1297)*X(209))/(JVS(1290))
  X(167) = (X(167)-JVS(1282)*X(200)-JVS(1283)*X(201)-JVS(1284)*X(203)-JVS(1285)*X(204)-JVS(1286)*X(205)-JVS(1287)*X(208)&
             &-JVS(1288)*X(209))/(JVS(1281))
  X(166) = (X(166)-JVS(1269)*X(167)-JVS(1270)*X(200)-JVS(1271)*X(201)-JVS(1272)*X(203)-JVS(1273)*X(204)-JVS(1274)*X(205)&
             &-JVS(1275)*X(208)-JVS(1276)*X(209))/(JVS(1268))
  X(165) = (X(165)-JVS(1256)*X(183)-JVS(1257)*X(192)-JVS(1258)*X(199)-JVS(1259)*X(201)-JVS(1260)*X(202)-JVS(1261)*X(203)&
             &-JVS(1262)*X(205)-JVS(1263)*X(208)-JVS(1264)*X(209))/(JVS(1255))
  X(164) = (X(164)-JVS(1218)*X(165)-JVS(1219)*X(166)-JVS(1220)*X(167)-JVS(1221)*X(168)-JVS(1222)*X(171)-JVS(1223)*X(173)&
             &-JVS(1224)*X(174)-JVS(1225)*X(175)-JVS(1226)*X(176)-JVS(1227)*X(177)-JVS(1228)*X(178)-JVS(1229)*X(179)&
             &-JVS(1230)*X(180)-JVS(1231)*X(181)-JVS(1232)*X(183)-JVS(1233)*X(185)-JVS(1234)*X(186)-JVS(1235)*X(191)&
             &-JVS(1236)*X(192)-JVS(1237)*X(194)-JVS(1238)*X(195)-JVS(1239)*X(196)-JVS(1240)*X(197)-JVS(1241)*X(198)&
             &-JVS(1242)*X(199)-JVS(1243)*X(200)-JVS(1244)*X(201)-JVS(1245)*X(202)-JVS(1246)*X(203)-JVS(1247)*X(204)&
             &-JVS(1248)*X(205)-JVS(1249)*X(208)-JVS(1250)*X(209)-JVS(1251)*X(210))/(JVS(1217))
  X(163) = (X(163)-JVS(1183)*X(165)-JVS(1184)*X(183)-JVS(1185)*X(201)-JVS(1186)*X(202)-JVS(1187)*X(203)-JVS(1188)*X(205)&
             &-JVS(1189)*X(208)-JVS(1190)*X(209))/(JVS(1182))
  X(162) = (X(162)-JVS(1167)*X(173)-JVS(1168)*X(176)-JVS(1169)*X(185)-JVS(1170)*X(186)-JVS(1171)*X(203)-JVS(1172)*X(205)&
             &-JVS(1173)*X(208)-JVS(1174)*X(209))/(JVS(1166))
  X(161) = (X(161)-JVS(1154)*X(165)-JVS(1155)*X(174)-JVS(1156)*X(183)-JVS(1157)*X(192)-JVS(1158)*X(199)-JVS(1159)*X(202)&
             &-JVS(1160)*X(205)-JVS(1161)*X(208)-JVS(1162)*X(209)-JVS(1163)*X(210))/(JVS(1153))
  X(160) = (X(160)-JVS(1141)*X(163)-JVS(1142)*X(165)-JVS(1143)*X(183)-JVS(1144)*X(201)-JVS(1145)*X(202)-JVS(1146)*X(203)&
             &-JVS(1147)*X(205)-JVS(1148)*X(208)-JVS(1149)*X(209))/(JVS(1140))
  X(159) = (X(159)-JVS(1118)*X(179)-JVS(1119)*X(195)-JVS(1120)*X(200)-JVS(1121)*X(201)-JVS(1122)*X(203)-JVS(1123)*X(204)&
             &-JVS(1124)*X(205)-JVS(1125)*X(209))/(JVS(1117))
  X(158) = (X(158)-JVS(1107)*X(173)-JVS(1108)*X(176)-JVS(1109)*X(191)-JVS(1110)*X(200)-JVS(1111)*X(203)-JVS(1112)*X(204)&
             &-JVS(1113)*X(205)-JVS(1114)*X(209))/(JVS(1106))
  X(157) = (X(157)-JVS(1099)*X(173)-JVS(1100)*X(176)-JVS(1101)*X(203)-JVS(1102)*X(205)-JVS(1103)*X(209))/(JVS(1098))
  X(156) = (X(156)-JVS(1088)*X(190)-JVS(1089)*X(191)-JVS(1090)*X(199)-JVS(1091)*X(200)-JVS(1092)*X(203)-JVS(1093)*X(204)&
             &-JVS(1094)*X(205)-JVS(1095)*X(209)-JVS(1096)*X(210))/(JVS(1087))
  X(155) = (X(155)-JVS(1076)*X(170)-JVS(1077)*X(184)-JVS(1078)*X(199)-JVS(1079)*X(200)-JVS(1080)*X(203)-JVS(1081)*X(204)&
             &-JVS(1082)*X(205)-JVS(1083)*X(209)-JVS(1084)*X(210))/(JVS(1075))
  X(154) = (X(154)-JVS(1066)*X(187)-JVS(1067)*X(199)-JVS(1068)*X(200)-JVS(1069)*X(203)-JVS(1070)*X(204)-JVS(1071)*X(205)&
             &-JVS(1072)*X(209)-JVS(1073)*X(210))/(JVS(1065))
  X(153) = (X(153)-JVS(1058)*X(195)-JVS(1059)*X(200)-JVS(1060)*X(201)-JVS(1061)*X(203)-JVS(1062)*X(204)-JVS(1063)&
             &*X(209))/(JVS(1057))
  X(152) = (X(152)-JVS(1053)*X(201)-JVS(1054)*X(205)-JVS(1055)*X(208)-JVS(1056)*X(210))/(JVS(1052))
  X(151) = (X(151)-JVS(1031)*X(152)-JVS(1032)*X(157)-JVS(1033)*X(162)-JVS(1034)*X(171)-JVS(1035)*X(173)-JVS(1036)*X(175)&
             &-JVS(1037)*X(176)-JVS(1038)*X(178)-JVS(1039)*X(185)-JVS(1040)*X(187)-JVS(1041)*X(189)-JVS(1042)*X(195)&
             &-JVS(1043)*X(201)-JVS(1044)*X(202)-JVS(1045)*X(203)-JVS(1046)*X(205)-JVS(1047)*X(207)-JVS(1048)*X(208)&
             &-JVS(1049)*X(209)-JVS(1050)*X(210)-JVS(1051)*X(211))/(JVS(1030))
  X(150) = (X(150)-JVS(1018)*X(181)-JVS(1019)*X(201)-JVS(1020)*X(202)-JVS(1021)*X(203)-JVS(1022)*X(205)-JVS(1023)&
             &*X(209))/(JVS(1017))
  X(149) = (X(149)-JVS(1003)*X(150)-JVS(1004)*X(153)-JVS(1005)*X(157)-JVS(1006)*X(176)-JVS(1007)*X(181)-JVS(1008)*X(185)&
             &-JVS(1009)*X(187)-JVS(1010)*X(200)-JVS(1011)*X(201)-JVS(1012)*X(203)-JVS(1013)*X(204)-JVS(1014)*X(205)&
             &-JVS(1015)*X(208)-JVS(1016)*X(209))/(JVS(1002))
  X(148) = (X(148)-JVS(988)*X(190)-JVS(989)*X(191)-JVS(990)*X(199)-JVS(991)*X(200)-JVS(992)*X(203)-JVS(993)*X(204)&
             &-JVS(994)*X(205)-JVS(995)*X(209)-JVS(996)*X(210))/(JVS(987))
  X(147) = (X(147)-JVS(979)*X(152)-JVS(980)*X(202)-JVS(981)*X(203)-JVS(982)*X(206)-JVS(983)*X(207)-JVS(984)*X(208))&
             &/(JVS(978))
  X(146) = (X(146)-JVS(967)*X(166)-JVS(968)*X(167)-JVS(969)*X(168)-JVS(970)*X(171)-JVS(971)*X(200)-JVS(972)*X(201)&
             &-JVS(973)*X(203)-JVS(974)*X(204)-JVS(975)*X(205)-JVS(976)*X(208)-JVS(977)*X(209))/(JVS(966))
  X(145) = (X(145)-JVS(959)*X(187)-JVS(960)*X(200)-JVS(961)*X(201)-JVS(962)*X(203)-JVS(963)*X(204)-JVS(964)*X(205)&
             &-JVS(965)*X(209))/(JVS(958))
  X(144) = (X(144)-JVS(945)*X(175)-JVS(946)*X(176)-JVS(947)*X(177)-JVS(948)*X(181)-JVS(949)*X(185)-JVS(950)*X(200)&
             &-JVS(951)*X(201)-JVS(952)*X(203)-JVS(953)*X(204)-JVS(954)*X(205)-JVS(955)*X(208)-JVS(956)*X(209))/(JVS(944))
  X(143) = (X(143)-JVS(927)*X(176)-JVS(928)*X(185)-JVS(929)*X(203)-JVS(930)*X(205)-JVS(931)*X(208)-JVS(932)*X(209))&
             &/(JVS(926))
  X(142) = (X(142)-JVS(911)*X(157)-JVS(912)*X(173)-JVS(913)*X(178)-JVS(914)*X(185)-JVS(915)*X(203)-JVS(916)*X(205)&
             &-JVS(917)*X(208)-JVS(918)*X(209))/(JVS(910))
  X(141) = (X(141)-JVS(897)*X(161)-JVS(898)*X(163)-JVS(899)*X(165)-JVS(900)*X(174)-JVS(901)*X(183)-JVS(902)*X(192)&
             &-JVS(903)*X(201)-JVS(904)*X(202)-JVS(905)*X(204)-JVS(906)*X(205)-JVS(907)*X(209)-JVS(908)*X(210))/(JVS(896))
  X(140) = (X(140)-JVS(882)*X(161)-JVS(883)*X(165)-JVS(884)*X(174)-JVS(885)*X(192)-JVS(886)*X(199)-JVS(887)*X(202)&
             &-JVS(888)*X(205)-JVS(889)*X(208)-JVS(890)*X(209))/(JVS(881))
  X(139) = (X(139)-JVS(872)*X(181)-JVS(873)*X(201)-JVS(874)*X(203)-JVS(875)*X(204)-JVS(876)*X(209))/(JVS(871))
  X(138) = (X(138)-JVS(866)*X(181)-JVS(867)*X(203)-JVS(868)*X(204)-JVS(869)*X(205)-JVS(870)*X(209))/(JVS(865))
  X(137) = (X(137)-JVS(850)*X(147)-JVS(851)*X(152)-JVS(852)*X(182)-JVS(853)*X(187)-JVS(854)*X(195)-JVS(855)*X(201)&
             &-JVS(856)*X(202)-JVS(857)*X(203)-JVS(858)*X(205)-JVS(859)*X(206)-JVS(860)*X(207)-JVS(861)*X(208)-JVS(862)&
             &*X(209)-JVS(863)*X(210)-JVS(864)*X(211))/(JVS(849))
  X(136) = (X(136)-JVS(836)*X(185)-JVS(837)*X(203)-JVS(838)*X(205)-JVS(839)*X(208))/(JVS(835))
  X(135) = (X(135)-JVS(827)*X(152)-JVS(828)*X(187)-JVS(829)*X(195)-JVS(830)*X(202)-JVS(831)*X(203)-JVS(832)*X(207)&
             &-JVS(833)*X(208)-JVS(834)*X(211))/(JVS(826))
  X(134) = (X(134)-JVS(820)*X(202)-JVS(821)*X(203)-JVS(822)*X(206)-JVS(823)*X(207)-JVS(824)*X(208)-JVS(825)*X(211))&
             &/(JVS(819))
  X(133) = (X(133)-JVS(810)*X(166)-JVS(811)*X(167)-JVS(812)*X(171)-JVS(813)*X(200)-JVS(814)*X(201)-JVS(815)*X(203)&
             &-JVS(816)*X(204)-JVS(817)*X(205)-JVS(818)*X(209))/(JVS(809))
  X(132) = (X(132)-JVS(792)*X(145)-JVS(793)*X(148)-JVS(794)*X(154)-JVS(795)*X(156)-JVS(796)*X(158)-JVS(797)*X(159)&
             &-JVS(798)*X(167)-JVS(799)*X(168)-JVS(800)*X(170)-JVS(801)*X(171)-JVS(802)*X(177)-JVS(803)*X(178)-JVS(804)&
             &*X(185)-JVS(805)*X(186)-JVS(806)*X(190)-JVS(807)*X(204)-JVS(808)*X(205))/(JVS(791))
  X(131) = (X(131)-JVS(786)*X(162)-JVS(787)*X(202)-JVS(788)*X(203)-JVS(789)*X(205)-JVS(790)*X(209))/(JVS(785))
  X(130) = (X(130)-JVS(777)*X(182)-JVS(778)*X(195)-JVS(779)*X(202)-JVS(780)*X(203)-JVS(781)*X(206)-JVS(782)*X(207)&
             &-JVS(783)*X(208))/(JVS(776))
  X(129) = (X(129)-JVS(770)*X(160)-JVS(771)*X(163)-JVS(772)*X(201)-JVS(773)*X(202)-JVS(774)*X(203)-JVS(775)*X(205))&
             &/(JVS(769))
  X(128) = (X(128)-JVS(760)*X(187)-JVS(761)*X(202)-JVS(762)*X(203)-JVS(763)*X(206)-JVS(764)*X(207)-JVS(765)*X(208))&
             &/(JVS(759))
  X(127) = (X(127)-JVS(753)*X(182)-JVS(754)*X(202)-JVS(755)*X(203)-JVS(756)*X(206)-JVS(757)*X(207)-JVS(758)*X(208))&
             &/(JVS(752))
  X(126) = (X(126)-JVS(749)*X(201)-JVS(750)*X(205)-JVS(751)*X(208))/(JVS(748))
  X(125) = (X(125)-JVS(743)*X(150)-JVS(744)*X(195)-JVS(745)*X(201)-JVS(746)*X(202)-JVS(747)*X(205))/(JVS(742))
  X(124) = (X(124)-JVS(737)*X(185)-JVS(738)*X(200)-JVS(739)*X(203)-JVS(740)*X(209))/(JVS(736))
  X(123) = (X(123)-JVS(730)*X(152)-JVS(731)*X(202)-JVS(732)*X(203)-JVS(733)*X(206)-JVS(734)*X(207)-JVS(735)*X(208))&
             &/(JVS(729))
  X(122) = (X(122)-JVS(723)*X(177)-JVS(724)*X(200)-JVS(725)*X(203)-JVS(726)*X(205)-JVS(727)*X(208)-JVS(728)*X(209))&
             &/(JVS(722))
  X(121) = (X(121)-JVS(716)*X(129)-JVS(717)*X(160)-JVS(718)*X(163)-JVS(719)*X(201)-JVS(720)*X(202))/(JVS(715))
  X(120) = (X(120)-JVS(711)*X(165)-JVS(712)*X(192)-JVS(713)*X(199)-JVS(714)*X(202))/(JVS(710))
  X(119) = (X(119)-JVS(706)*X(179)-JVS(707)*X(202)-JVS(708)*X(205)-JVS(709)*X(208))/(JVS(705))
  X(118) = (X(118)-JVS(702)*X(201)-JVS(703)*X(205)-JVS(704)*X(208))/(JVS(701))
  X(117) = (X(117)-JVS(698)*X(201)-JVS(699)*X(205)-JVS(700)*X(208))/(JVS(697))
  X(116) = (X(116)-JVS(692)*X(138)-JVS(693)*X(139)-JVS(694)*X(188)-JVS(695)*X(205)-JVS(696)*X(209))/(JVS(691))
  X(115) = (X(115)-JVS(687)*X(199)-JVS(688)*X(201)-JVS(689)*X(205)-JVS(690)*X(210))/(JVS(686))
  X(114) = (X(114)-JVS(680)*X(157)-JVS(681)*X(176)-JVS(682)*X(203)-JVS(683)*X(205)-JVS(684)*X(208)-JVS(685)*X(209))&
             &/(JVS(679))
  X(113) = (X(113)-JVS(673)*X(176)-JVS(674)*X(193)-JVS(675)*X(204)-JVS(676)*X(205)-JVS(677)*X(208)-JVS(678)*X(210))&
             &/(JVS(672))
  X(112) = (X(112)-JVS(666)*X(153)-JVS(667)*X(179)-JVS(668)*X(195)-JVS(669)*X(201)-JVS(670)*X(205)-JVS(671)*X(209))&
             &/(JVS(665))
  X(111) = (X(111)-JVS(661)*X(140)-JVS(662)*X(161)-JVS(663)*X(174)-JVS(664)*X(208))/(JVS(660))
  X(110) = (X(110)-JVS(656)*X(157)-JVS(657)*X(173)-JVS(658)*X(205)-JVS(659)*X(209))/(JVS(655))
  X(109) = (X(109)-JVS(651)*X(140)-JVS(652)*X(161)-JVS(653)*X(174)-JVS(654)*X(208))/(JVS(650))
  X(108) = (X(108)-JVS(647)*X(185)-JVS(648)*X(205)-JVS(649)*X(209))/(JVS(646))
  X(107) = (X(107)-JVS(643)*X(185)-JVS(644)*X(205)-JVS(645)*X(209))/(JVS(642))
  X(106) = (X(106)-JVS(637)*X(177)-JVS(638)*X(200)-JVS(639)*X(203)-JVS(640)*X(205)-JVS(641)*X(209))/(JVS(636))
  X(105) = (X(105)-JVS(630)*X(133)-JVS(631)*X(146)-JVS(632)*X(201)-JVS(633)*X(205)-JVS(634)*X(208))/(JVS(629))
  X(104) = (X(104)-JVS(624)*X(177)-JVS(625)*X(200)-JVS(626)*X(203)-JVS(627)*X(205)-JVS(628)*X(208))/(JVS(623))
  X(103) = (X(103)-JVS(615)*X(141)-JVS(616)*X(161)-JVS(617)*X(165)-JVS(618)*X(183)-JVS(619)*X(192)-JVS(620)*X(204)&
             &-JVS(621)*X(205)-JVS(622)*X(210))/(JVS(614))
  X(102) = (X(102)-JVS(605)*X(109)-JVS(606)*X(111)-JVS(607)*X(120)-JVS(608)*X(140)-JVS(609)*X(165)-JVS(610)*X(174)&
             &-JVS(611)*X(199)-JVS(612)*X(205))/(JVS(604))
  X(101) = (X(101)-JVS(601)*X(177)-JVS(602)*X(205)-JVS(603)*X(209))/(JVS(600))
  X(100) = (X(100)-JVS(597)*X(178)-JVS(598)*X(205)-JVS(599)*X(209))/(JVS(596))
  X(99) = (X(99)-JVS(593)*X(185)-JVS(594)*X(205)-JVS(595)*X(209))/(JVS(592))
  X(98) = (X(98)-JVS(588)*X(185)-JVS(589)*X(203)-JVS(590)*X(205)-JVS(591)*X(209))/(JVS(587))
  X(97) = (X(97)-JVS(582)*X(143)-JVS(583)*X(203)-JVS(584)*X(205)-JVS(585)*X(209))/(JVS(581))
  X(96) = (X(96)-JVS(577)*X(147)-JVS(578)*X(186)-JVS(579)*X(205)-JVS(580)*X(209))/(JVS(576))
  X(95) = (X(95)-JVS(572)*X(204)-JVS(573)*X(205)-JVS(574)*X(209)-JVS(575)*X(210))/(JVS(571))
  X(94) = (X(94)-JVS(568)*X(185)-JVS(569)*X(203)-JVS(570)*X(209))/(JVS(567))
  X(93) = (X(93)-JVS(564)*X(199)-JVS(565)*X(205)-JVS(566)*X(210))/(JVS(563))
  X(92) = (X(92)-JVS(560)*X(192)-JVS(561)*X(201)-JVS(562)*X(202))/(JVS(559))
  X(91) = (X(91)-JVS(549)*X(109)-JVS(550)*X(111)-JVS(551)*X(120)-JVS(552)*X(140)-JVS(553)*X(141)-JVS(554)*X(161)&
            &-JVS(555)*X(165)-JVS(556)*X(174)-JVS(557)*X(183)-JVS(558)*X(192))/(JVS(548))
  X(90) = (X(90)-JVS(544)*X(155)-JVS(545)*X(170)-JVS(546)*X(205)-JVS(547)*X(209))/(JVS(543))
  X(89) = (X(89)-JVS(541)*X(185)-JVS(542)*X(205))/(JVS(540))
  X(88) = (X(88)-JVS(535)*X(122)-JVS(536)*X(124)-JVS(537)*X(190)-JVS(538)*X(205)-JVS(539)*X(209))/(JVS(534))
  X(87) = (X(87)-JVS(530)*X(168)-JVS(531)*X(171)-JVS(532)*X(205)-JVS(533)*X(209))/(JVS(529))
  X(86) = (X(86)-JVS(525)*X(129)-JVS(526)*X(163)-JVS(527)*X(205)-JVS(528)*X(209))/(JVS(524))
  X(85) = (X(85)-JVS(521)*X(201)-JVS(522)*X(205)-JVS(523)*X(210))/(JVS(520))
  X(84) = (X(84)-JVS(517)*X(145)-JVS(518)*X(205)-JVS(519)*X(209))/(JVS(516))
  X(83) = (X(83)-JVS(513)*X(154)-JVS(514)*X(205)-JVS(515)*X(209))/(JVS(512))
  X(82) = (X(82)-JVS(508)*X(150)-JVS(509)*X(169)-JVS(510)*X(205)-JVS(511)*X(209))/(JVS(507))
  X(81) = (X(81)-JVS(503)*X(125)-JVS(504)*X(200)-JVS(505)*X(202)-JVS(506)*X(205))/(JVS(502))
  X(80) = (X(80)-JVS(498)*X(163)-JVS(499)*X(165)-JVS(500)*X(183)-JVS(501)*X(205))/(JVS(497))
  X(79) = (X(79)-JVS(492)*X(165)-JVS(493)*X(183)-JVS(494)*X(204)-JVS(495)*X(205)-JVS(496)*X(210))/(JVS(491))
  X(78) = (X(78)-JVS(488)*X(160)-JVS(489)*X(202))/(JVS(487))
  X(77) = (X(77)-JVS(485)*X(205)-JVS(486)*X(210))/(JVS(484))
  X(76) = (X(76)-JVS(481)*X(202)-JVS(482)*X(205)-JVS(483)*X(209))/(JVS(480))
  X(75) = (X(75)-JVS(477)*X(92)-JVS(478)*X(192)-JVS(479)*X(205))/(JVS(476))
  X(74) = (X(74)-JVS(474)*X(201)-JVS(475)*X(205))/(JVS(473))
  X(73) = (X(73)-JVS(470)*X(156)-JVS(471)*X(205)-JVS(472)*X(209))/(JVS(469))
  X(72) = (X(72)-JVS(466)*X(148)-JVS(467)*X(205)-JVS(468)*X(209))/(JVS(465))
  X(71) = (X(71)-JVS(463)*X(201)-JVS(464)*X(205))/(JVS(462))
  X(70) = (X(70)-JVS(459)*X(163)-JVS(460)*X(165)-JVS(461)*X(203))/(JVS(458))
  X(69) = (X(69)-JVS(451)*X(78)-JVS(452)*X(202)-JVS(453)*X(203)-JVS(454)*X(205))/(JVS(450))
  X(68) = (X(68)-JVS(447)*X(193)-JVS(448)*X(205)-JVS(449)*X(209))/(JVS(446))
  X(67) = (X(67)-JVS(444)*X(205)-JVS(445)*X(210))/(JVS(443))
  X(66) = (X(66)-JVS(441)*X(205)-JVS(442)*X(210))/(JVS(440))
  X(65) = (X(65)-JVS(438)*X(202)-JVS(439)*X(204))/(JVS(437))
  X(64) = (X(64)-JVS(432)*X(125)-JVS(433)*X(195)-JVS(434)*X(201)-JVS(435)*X(202)-JVS(436)*X(205))/(JVS(431))
  X(63) = (X(63)-JVS(426)*X(78)-JVS(427)*X(86)-JVS(428)*X(121)-JVS(429)*X(163)-JVS(430)*X(183))/(JVS(425))
  X(62) = (X(62)-JVS(423)*X(183)-JVS(424)*X(205))/(JVS(422))
  X(61) = (X(61)-JVS(419)*X(200)-JVS(420)*X(205)-JVS(421)*X(209))/(JVS(418))
  X(60) = (X(60)-JVS(414)*X(74)-JVS(415)*X(203)-JVS(416)*X(205)-JVS(417)*X(209))/(JVS(413))
  X(59) = (X(59)-JVS(405)*X(136)-JVS(406)*X(142)-JVS(407)*X(157)-JVS(408)*X(162)-JVS(409)*X(173)-JVS(410)*X(176)&
            &-JVS(411)*X(191)-JVS(412)*X(203))/(JVS(404))
  X(58) = (X(58)-JVS(399)*X(99)-JVS(400)*X(107)-JVS(401)*X(136)-JVS(402)*X(205))/(JVS(398))
  X(57) = (X(57)-JVS(394)*X(99)-JVS(395)*X(107)-JVS(396)*X(136)-JVS(397)*X(205))/(JVS(393))
  X(56) = (X(56)-JVS(390)*X(203)-JVS(391)*X(205)-JVS(392)*X(209))/(JVS(389))
  X(55) = (X(55)-JVS(385)*X(203)-JVS(386)*X(205)-JVS(387)*X(209))/(JVS(384))
  X(54) = (X(54)-JVS(381)*X(160)-JVS(382)*X(203))/(JVS(380))
  X(53) = (X(53)-JVS(377)*X(108)-JVS(378)*X(176)-JVS(379)*X(205))/(JVS(376))
  X(52) = (X(52)-JVS(373)*X(78)-JVS(374)*X(86)-JVS(375)*X(121))/(JVS(372))
  X(51) = (X(51)-JVS(369)*X(160)-JVS(370)*X(205)-JVS(371)*X(209))/(JVS(368))
  X(50) = (X(50)-JVS(367)*X(205))/(JVS(366))
  X(49) = (X(49)-JVS(364)*X(199)-JVS(365)*X(202))/(JVS(363))
  X(48) = (X(48)-JVS(362)*X(205))/(JVS(361))
  X(47) = (X(47)-JVS(359)*X(169)-JVS(360)*X(202))/(JVS(358))
  X(46) = (X(46)-JVS(356)*X(131)-JVS(357)*X(202))/(JVS(355))
  X(45) = (X(45)-JVS(353)*X(70)-JVS(354)*X(163))/(JVS(352))
  X(44) = (X(44)-JVS(351)*X(205))/(JVS(350))
  X(43) = (X(43)-JVS(349)*X(205))/(JVS(348))
  X(42) = (X(42)-JVS(345)*X(105)-JVS(346)*X(133)-JVS(347)*X(146))/(JVS(344))
  X(41) = (X(41)-JVS(343)*X(163))/(JVS(342))
  X(40) = (X(40)-JVS(341)*X(94))/(JVS(340))
  X(39) = (X(39)-JVS(337)*X(157)-JVS(338)*X(173)-JVS(339)*X(203))/(JVS(336))
  X(38) = (X(38)-JVS(335)*X(205))/(JVS(334))
  X(37) = (X(37)-JVS(333)*X(205))/(JVS(332))
  X(36) = (X(36)-JVS(331)*X(70))/(JVS(330))
  X(35) = (X(35)-JVS(321)*X(123)-JVS(322)*X(127)-JVS(323)*X(128)-JVS(324)*X(130)-JVS(325)*X(134)-JVS(326)*X(135)&
            &-JVS(327)*X(147)-JVS(328)*X(205)-JVS(329)*X(207))/(JVS(320))
  X(34) = (X(34)-JVS(312)*X(123)-JVS(313)*X(127)-JVS(314)*X(128)-JVS(315)*X(130)-JVS(316)*X(134)-JVS(317)*X(147)&
            &-JVS(318)*X(205)-JVS(319)*X(206))/(JVS(311))
  X(33) = (X(33)-JVS(264)*X(66)-JVS(265)*X(67)-JVS(266)*X(77)-JVS(267)*X(89)-JVS(268)*X(94)-JVS(269)*X(96)-JVS(270)&
            &*X(97)-JVS(271)*X(101)-JVS(272)*X(106)-JVS(273)*X(114)-JVS(274)*X(117)-JVS(275)*X(118)-JVS(276)*X(119)-JVS(277)&
            &*X(125)-JVS(278)*X(126)-JVS(279)*X(136)-JVS(280)*X(143)-JVS(281)*X(144)-JVS(282)*X(149)-JVS(283)*X(150)&
            &-JVS(284)*X(152)-JVS(285)*X(153)-JVS(286)*X(162)-JVS(287)*X(175)-JVS(288)*X(177)-JVS(289)*X(179)-JVS(290)&
            &*X(180)-JVS(291)*X(182)-JVS(292)*X(184)-JVS(293)*X(185)-JVS(294)*X(186)-JVS(295)*X(187)-JVS(296)*X(189)&
            &-JVS(297)*X(194)-JVS(298)*X(195)-JVS(299)*X(197)-JVS(300)*X(198)-JVS(301)*X(199)-JVS(302)*X(200)-JVS(303)&
            &*X(201)-JVS(304)*X(203)-JVS(305)*X(204)-JVS(306)*X(205)-JVS(307)*X(208)-JVS(308)*X(209)-JVS(309)*X(210)&
            &-JVS(310)*X(211))/(JVS(263))
  X(32) = (X(32)-JVS(199)*X(36)-JVS(200)*X(41)-JVS(201)*X(45)-JVS(202)*X(62)-JVS(203)*X(70)-JVS(204)*X(71)-JVS(205)&
            &*X(74)-JVS(206)*X(78)-JVS(207)*X(80)-JVS(208)*X(85)-JVS(209)*X(86)-JVS(210)*X(92)-JVS(211)*X(104)-JVS(212)&
            &*X(109)-JVS(213)*X(110)-JVS(214)*X(111)-JVS(215)*X(115)-JVS(216)*X(117)-JVS(217)*X(118)-JVS(218)*X(120)&
            &-JVS(219)*X(121)-JVS(220)*X(126)-JVS(221)*X(131)-JVS(222)*X(133)-JVS(223)*X(136)-JVS(224)*X(138)-JVS(225)&
            &*X(139)-JVS(226)*X(140)-JVS(227)*X(141)-JVS(228)*X(142)-JVS(229)*X(144)-JVS(230)*X(146)-JVS(231)*X(150)&
            &-JVS(232)*X(152)-JVS(233)*X(161)-JVS(234)*X(162)-JVS(235)*X(163)-JVS(236)*X(165)-JVS(237)*X(166)-JVS(238)&
            &*X(168)-JVS(239)*X(171)-JVS(240)*X(174)-JVS(241)*X(176)-JVS(242)*X(180)-JVS(243)*X(181)-JVS(244)*X(182)&
            &-JVS(245)*X(183)-JVS(246)*X(187)-JVS(247)*X(188)-JVS(248)*X(191)-JVS(249)*X(192)-JVS(250)*X(194)-JVS(251)&
            &*X(195)-JVS(252)*X(196)-JVS(253)*X(197)-JVS(254)*X(198)-JVS(255)*X(201)-JVS(256)*X(202)-JVS(257)*X(203)&
            &-JVS(258)*X(204)-JVS(259)*X(205)-JVS(260)*X(208)-JVS(261)*X(209)-JVS(262)*X(211))/(JVS(198))
  X(31) = (X(31)-JVS(133)*X(42)-JVS(134)*X(46)-JVS(135)*X(59)-JVS(136)*X(65)-JVS(137)*X(69)-JVS(138)*X(75)-JVS(139)&
            &*X(76)-JVS(140)*X(79)-JVS(141)*X(81)-JVS(142)*X(94)-JVS(143)*X(98)-JVS(144)*X(102)-JVS(145)*X(103)-JVS(146)&
            &*X(105)-JVS(147)*X(122)-JVS(148)*X(123)-JVS(149)*X(124)-JVS(150)*X(125)-JVS(151)*X(127)-JVS(152)*X(128)&
            &-JVS(153)*X(129)-JVS(154)*X(130)-JVS(155)*X(131)-JVS(156)*X(133)-JVS(157)*X(134)-JVS(158)*X(135)-JVS(159)&
            &*X(139)-JVS(160)*X(142)-JVS(161)*X(143)-JVS(162)*X(145)-JVS(163)*X(146)-JVS(164)*X(147)-JVS(165)*X(148)&
            &-JVS(166)*X(150)-JVS(167)*X(153)-JVS(168)*X(154)-JVS(169)*X(155)-JVS(170)*X(156)-JVS(171)*X(157)-JVS(172)&
            &*X(158)-JVS(173)*X(159)-JVS(174)*X(161)-JVS(175)*X(164)-JVS(176)*X(166)-JVS(177)*X(167)-JVS(178)*X(168)&
            &-JVS(179)*X(169)-JVS(180)*X(170)-JVS(181)*X(171)-JVS(182)*X(173)-JVS(183)*X(177)-JVS(184)*X(178)-JVS(185)&
            &*X(179)-JVS(186)*X(185)-JVS(187)*X(186)-JVS(188)*X(188)-JVS(189)*X(190)-JVS(190)*X(193)-JVS(191)*X(200)&
            &-JVS(192)*X(202)-JVS(193)*X(203)-JVS(194)*X(204)-JVS(195)*X(205)-JVS(196)*X(209)-JVS(197)*X(210))/(JVS(132))
  X(30) = (X(30)-JVS(131)*X(180))/(JVS(130))
  X(29) = (X(29)-JVS(128)*X(125)-JVS(129)*X(205))/(JVS(127))
  X(28) = (X(28)-JVS(126)*X(29))/(JVS(125))
  X(27) = (X(27)-JVS(122)*X(53)-JVS(123)*X(57)-JVS(124)*X(58))/(JVS(121))
  X(26) = (X(26)-JVS(120)*X(144))/(JVS(119))
  X(25) = (X(25)-JVS(118)*X(140))/(JVS(117))
  X(24) = (X(24)-JVS(116)*X(140))/(JVS(115))
  X(23) = (X(23)-JVS(106)*X(123)-JVS(107)*X(127)-JVS(108)*X(128)-JVS(109)*X(130)-JVS(110)*X(134)-JVS(111)*X(135)&
            &-JVS(112)*X(147)-JVS(113)*X(205)-JVS(114)*X(207))/(JVS(105))
  X(22) = (X(22)-JVS(103)*X(142)-JVS(104)*X(205))/(JVS(102))
  X(21) = (X(21)-JVS(100)*X(71)-JVS(101)*X(205))/(JVS(99))
  X(20) = (X(20)-JVS(97)*X(60)-JVS(98)*X(203))/(JVS(96))
  X(19) = (X(19)-JVS(94)*X(60)-JVS(95)*X(209))/(JVS(93))
  X(18) = (X(18)-JVS(89)*X(99)-JVS(90)*X(107)-JVS(91)*X(108)-JVS(92)*X(205))/(JVS(88))
  X(17) = (X(17)-JVS(87)*X(18))/(JVS(86))
  X(16) = (X(16)-JVS(84)*X(55)-JVS(85)*X(203))/(JVS(83))
  X(15) = (X(15)-JVS(81)*X(55)-JVS(82)*X(209))/(JVS(80))
  X(14) = (X(14)-JVS(78)*X(152)-JVS(79)*X(201))/(JVS(77))
  X(13) = (X(13)-JVS(75)*X(152)-JVS(76)*X(205))/(JVS(74))
  X(12) = (X(12)-JVS(72)*X(56)-JVS(73)*X(203))/(JVS(71))
  X(11) = (X(11)-JVS(69)*X(56)-JVS(70)*X(209))/(JVS(68))
  X(10) = (X(10)-JVS(60)*X(138)-JVS(61)*X(139)-JVS(62)*X(150)-JVS(63)*X(201)-JVS(64)*X(202)-JVS(65)*X(203)-JVS(66)&
            &*X(204)-JVS(67)*X(209))/(JVS(59))
  X(9) = (X(9)-JVS(58)*X(10))/(JVS(57))
  X(8) = (X(8)-JVS(50)*X(36)-JVS(51)*X(41)-JVS(52)*X(45)-JVS(53)*X(51)-JVS(54)*X(78)-JVS(55)*X(86)-JVS(56)*X(121))&
           &/(JVS(49))
  X(7) = (X(7)-JVS(42)*X(36)-JVS(43)*X(41)-JVS(44)*X(45)-JVS(45)*X(51)-JVS(46)*X(78)-JVS(47)*X(86)-JVS(48)*X(121))&
           &/(JVS(41))
  X(6) = (X(6)-JVS(39)*X(42)-JVS(40)*X(59))/(JVS(38))
  X(5) = (X(5)-JVS(10)*X(74)-JVS(11)*X(89)-JVS(12)*X(96)-JVS(13)*X(104)-JVS(14)*X(114)-JVS(15)*X(122)-JVS(16)*X(125)&
           &-JVS(17)*X(131)-JVS(18)*X(136)-JVS(19)*X(143)-JVS(20)*X(151)-JVS(21)*X(153)-JVS(22)*X(159)-JVS(23)*X(172)&
           &-JVS(24)*X(175)-JVS(25)*X(176)-JVS(26)*X(179)-JVS(27)*X(185)-JVS(28)*X(189)-JVS(29)*X(200)-JVS(30)*X(201)&
           &-JVS(31)*X(203)-JVS(32)*X(204)-JVS(33)*X(205)-JVS(34)*X(206)-JVS(35)*X(208)-JVS(36)*X(209)-JVS(37)*X(210))&
           &/(JVS(9))
  X(4) = (X(4)-JVS(5)*X(36)-JVS(6)*X(41)-JVS(7)*X(45)-JVS(8)*X(51))/(JVS(4))
  X(3) = X(3)/JVS(3)
  X(2) = X(2)/JVS(2)
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(3)
  XX(4) = X(4)/JVS(4)
  XX(5) = X(5)/JVS(9)
  XX(6) = X(6)/JVS(38)
  XX(7) = X(7)/JVS(41)
  XX(8) = X(8)/JVS(49)
  XX(9) = X(9)/JVS(57)
  XX(10) = (X(10)-JVS(58)*XX(9))/(JVS(59))
  XX(11) = X(11)/JVS(68)
  XX(12) = X(12)/JVS(71)
  XX(13) = X(13)/JVS(74)
  XX(14) = X(14)/JVS(77)
  XX(15) = X(15)/JVS(80)
  XX(16) = X(16)/JVS(83)
  XX(17) = X(17)/JVS(86)
  XX(18) = (X(18)-JVS(87)*XX(17))/(JVS(88))
  XX(19) = X(19)/JVS(93)
  XX(20) = X(20)/JVS(96)
  XX(21) = X(21)/JVS(99)
  XX(22) = X(22)/JVS(102)
  XX(23) = X(23)/JVS(105)
  XX(24) = X(24)/JVS(115)
  XX(25) = X(25)/JVS(117)
  XX(26) = X(26)/JVS(119)
  XX(27) = X(27)/JVS(121)
  XX(28) = X(28)/JVS(125)
  XX(29) = (X(29)-JVS(126)*XX(28))/(JVS(127))
  XX(30) = X(30)/JVS(130)
  XX(31) = X(31)/JVS(132)
  XX(32) = X(32)/JVS(198)
  XX(33) = X(33)/JVS(263)
  XX(34) = X(34)/JVS(311)
  XX(35) = X(35)/JVS(320)
  XX(36) = (X(36)-JVS(5)*XX(4)-JVS(42)*XX(7)-JVS(50)*XX(8)-JVS(199)*XX(32))/(JVS(330))
  XX(37) = X(37)/JVS(332)
  XX(38) = X(38)/JVS(334)
  XX(39) = X(39)/JVS(336)
  XX(40) = X(40)/JVS(340)
  XX(41) = (X(41)-JVS(6)*XX(4)-JVS(43)*XX(7)-JVS(51)*XX(8)-JVS(200)*XX(32))/(JVS(342))
  XX(42) = (X(42)-JVS(39)*XX(6)-JVS(133)*XX(31))/(JVS(344))
  XX(43) = X(43)/JVS(348)
  XX(44) = X(44)/JVS(350)
  XX(45) = (X(45)-JVS(7)*XX(4)-JVS(44)*XX(7)-JVS(52)*XX(8)-JVS(201)*XX(32))/(JVS(352))
  XX(46) = (X(46)-JVS(134)*XX(31))/(JVS(355))
  XX(47) = X(47)/JVS(358)
  XX(48) = X(48)/JVS(361)
  XX(49) = X(49)/JVS(363)
  XX(50) = X(50)/JVS(366)
  XX(51) = (X(51)-JVS(8)*XX(4)-JVS(45)*XX(7)-JVS(53)*XX(8))/(JVS(368))
  XX(52) = X(52)/JVS(372)
  XX(53) = (X(53)-JVS(122)*XX(27))/(JVS(376))
  XX(54) = X(54)/JVS(380)
  XX(55) = (X(55)-JVS(81)*XX(15)-JVS(84)*XX(16))/(JVS(384))
  XX(56) = (X(56)-JVS(69)*XX(11)-JVS(72)*XX(12))/(JVS(389))
  XX(57) = (X(57)-JVS(123)*XX(27))/(JVS(393))
  XX(58) = (X(58)-JVS(124)*XX(27))/(JVS(398))
  XX(59) = (X(59)-JVS(40)*XX(6)-JVS(135)*XX(31))/(JVS(404))
  XX(60) = (X(60)-JVS(94)*XX(19)-JVS(97)*XX(20))/(JVS(413))
  XX(61) = X(61)/JVS(418)
  XX(62) = (X(62)-JVS(202)*XX(32))/(JVS(422))
  XX(63) = X(63)/JVS(425)
  XX(64) = X(64)/JVS(431)
  XX(65) = (X(65)-JVS(136)*XX(31))/(JVS(437))
  XX(66) = (X(66)-JVS(264)*XX(33))/(JVS(440))
  XX(67) = (X(67)-JVS(265)*XX(33))/(JVS(443))
  XX(68) = X(68)/JVS(446)
  XX(69) = (X(69)-JVS(137)*XX(31))/(JVS(450))
  XX(70) = (X(70)-JVS(203)*XX(32)-JVS(331)*XX(36)-JVS(353)*XX(45))/(JVS(458))
  XX(71) = (X(71)-JVS(100)*XX(21)-JVS(204)*XX(32))/(JVS(462))
  XX(72) = X(72)/JVS(465)
  XX(73) = X(73)/JVS(469)
  XX(74) = (X(74)-JVS(10)*XX(5)-JVS(205)*XX(32)-JVS(414)*XX(60))/(JVS(473))
  XX(75) = (X(75)-JVS(138)*XX(31))/(JVS(476))
  XX(76) = (X(76)-JVS(139)*XX(31))/(JVS(480))
  XX(77) = (X(77)-JVS(266)*XX(33))/(JVS(484))
  XX(78) = (X(78)-JVS(46)*XX(7)-JVS(54)*XX(8)-JVS(206)*XX(32)-JVS(373)*XX(52)-JVS(426)*XX(63)-JVS(451)*XX(69))&
             &/(JVS(487))
  XX(79) = (X(79)-JVS(140)*XX(31))/(JVS(491))
  XX(80) = (X(80)-JVS(207)*XX(32))/(JVS(497))
  XX(81) = (X(81)-JVS(141)*XX(31))/(JVS(502))
  XX(82) = X(82)/JVS(507)
  XX(83) = X(83)/JVS(512)
  XX(84) = X(84)/JVS(516)
  XX(85) = (X(85)-JVS(208)*XX(32))/(JVS(520))
  XX(86) = (X(86)-JVS(47)*XX(7)-JVS(55)*XX(8)-JVS(209)*XX(32)-JVS(374)*XX(52)-JVS(427)*XX(63))/(JVS(524))
  XX(87) = X(87)/JVS(529)
  XX(88) = X(88)/JVS(534)
  XX(89) = (X(89)-JVS(11)*XX(5)-JVS(267)*XX(33))/(JVS(540))
  XX(90) = X(90)/JVS(543)
  XX(91) = X(91)/JVS(548)
  XX(92) = (X(92)-JVS(210)*XX(32)-JVS(477)*XX(75))/(JVS(559))
  XX(93) = X(93)/JVS(563)
  XX(94) = (X(94)-JVS(142)*XX(31)-JVS(268)*XX(33)-JVS(341)*XX(40))/(JVS(567))
  XX(95) = X(95)/JVS(571)
  XX(96) = (X(96)-JVS(12)*XX(5)-JVS(269)*XX(33))/(JVS(576))
  XX(97) = (X(97)-JVS(270)*XX(33))/(JVS(581))
  XX(98) = (X(98)-JVS(143)*XX(31))/(JVS(587))
  XX(99) = (X(99)-JVS(89)*XX(18)-JVS(394)*XX(57)-JVS(399)*XX(58))/(JVS(592))
  XX(100) = X(100)/JVS(596)
  XX(101) = (X(101)-JVS(271)*XX(33))/(JVS(600))
  XX(102) = (X(102)-JVS(144)*XX(31))/(JVS(604))
  XX(103) = (X(103)-JVS(145)*XX(31))/(JVS(614))
  XX(104) = (X(104)-JVS(13)*XX(5)-JVS(211)*XX(32))/(JVS(623))
  XX(105) = (X(105)-JVS(146)*XX(31)-JVS(345)*XX(42))/(JVS(629))
  XX(106) = (X(106)-JVS(272)*XX(33))/(JVS(636))
  XX(107) = (X(107)-JVS(90)*XX(18)-JVS(395)*XX(57)-JVS(400)*XX(58))/(JVS(642))
  XX(108) = (X(108)-JVS(91)*XX(18)-JVS(377)*XX(53))/(JVS(646))
  XX(109) = (X(109)-JVS(212)*XX(32)-JVS(549)*XX(91)-JVS(605)*XX(102))/(JVS(650))
  XX(110) = (X(110)-JVS(213)*XX(32))/(JVS(655))
  XX(111) = (X(111)-JVS(214)*XX(32)-JVS(550)*XX(91)-JVS(606)*XX(102))/(JVS(660))
  XX(112) = X(112)/JVS(665)
  XX(113) = X(113)/JVS(672)
  XX(114) = (X(114)-JVS(14)*XX(5)-JVS(273)*XX(33))/(JVS(679))
  XX(115) = (X(115)-JVS(215)*XX(32))/(JVS(686))
  XX(116) = X(116)/JVS(691)
  XX(117) = (X(117)-JVS(216)*XX(32)-JVS(274)*XX(33))/(JVS(697))
  XX(118) = (X(118)-JVS(217)*XX(32)-JVS(275)*XX(33))/(JVS(701))
  XX(119) = (X(119)-JVS(276)*XX(33))/(JVS(705))
  XX(120) = (X(120)-JVS(218)*XX(32)-JVS(551)*XX(91)-JVS(607)*XX(102))/(JVS(710))
  XX(121) = (X(121)-JVS(48)*XX(7)-JVS(56)*XX(8)-JVS(219)*XX(32)-JVS(375)*XX(52)-JVS(428)*XX(63))/(JVS(715))
  XX(122) = (X(122)-JVS(15)*XX(5)-JVS(147)*XX(31)-JVS(535)*XX(88))/(JVS(722))
  XX(123) = (X(123)-JVS(106)*XX(23)-JVS(148)*XX(31)-JVS(312)*XX(34)-JVS(321)*XX(35))/(JVS(729))
  XX(124) = (X(124)-JVS(149)*XX(31)-JVS(536)*XX(88))/(JVS(736))
  XX(125) = (X(125)-JVS(16)*XX(5)-JVS(128)*XX(29)-JVS(150)*XX(31)-JVS(277)*XX(33)-JVS(432)*XX(64)-JVS(503)*XX(81))&
              &/(JVS(742))
  XX(126) = (X(126)-JVS(220)*XX(32)-JVS(278)*XX(33))/(JVS(748))
  XX(127) = (X(127)-JVS(107)*XX(23)-JVS(151)*XX(31)-JVS(313)*XX(34)-JVS(322)*XX(35))/(JVS(752))
  XX(128) = (X(128)-JVS(108)*XX(23)-JVS(152)*XX(31)-JVS(314)*XX(34)-JVS(323)*XX(35))/(JVS(759))
  XX(129) = (X(129)-JVS(153)*XX(31)-JVS(525)*XX(86)-JVS(716)*XX(121))/(JVS(769))
  XX(130) = (X(130)-JVS(109)*XX(23)-JVS(154)*XX(31)-JVS(315)*XX(34)-JVS(324)*XX(35))/(JVS(776))
  XX(131) = (X(131)-JVS(17)*XX(5)-JVS(155)*XX(31)-JVS(221)*XX(32)-JVS(356)*XX(46))/(JVS(785))
  XX(132) = X(132)/JVS(791)
  XX(133) = (X(133)-JVS(156)*XX(31)-JVS(222)*XX(32)-JVS(346)*XX(42)-JVS(630)*XX(105))/(JVS(809))
  XX(134) = (X(134)-JVS(110)*XX(23)-JVS(157)*XX(31)-JVS(316)*XX(34)-JVS(325)*XX(35))/(JVS(819))
  XX(135) = (X(135)-JVS(111)*XX(23)-JVS(158)*XX(31)-JVS(326)*XX(35))/(JVS(826))
  XX(136) = (X(136)-JVS(18)*XX(5)-JVS(223)*XX(32)-JVS(279)*XX(33)-JVS(396)*XX(57)-JVS(401)*XX(58)-JVS(405)*XX(59))&
              &/(JVS(835))
  XX(137) = X(137)/JVS(849)
  XX(138) = (X(138)-JVS(60)*XX(10)-JVS(224)*XX(32)-JVS(692)*XX(116))/(JVS(865))
  XX(139) = (X(139)-JVS(61)*XX(10)-JVS(159)*XX(31)-JVS(225)*XX(32)-JVS(693)*XX(116))/(JVS(871))
  XX(140) = (X(140)-JVS(116)*XX(24)-JVS(118)*XX(25)-JVS(226)*XX(32)-JVS(552)*XX(91)-JVS(608)*XX(102)-JVS(651)*XX(109)&
              &-JVS(661)*XX(111))/(JVS(881))
  XX(141) = (X(141)-JVS(227)*XX(32)-JVS(553)*XX(91)-JVS(615)*XX(103))/(JVS(896))
  XX(142) = (X(142)-JVS(103)*XX(22)-JVS(160)*XX(31)-JVS(228)*XX(32)-JVS(406)*XX(59))/(JVS(910))
  XX(143) = (X(143)-JVS(19)*XX(5)-JVS(161)*XX(31)-JVS(280)*XX(33)-JVS(582)*XX(97))/(JVS(926))
  XX(144) = (X(144)-JVS(120)*XX(26)-JVS(229)*XX(32)-JVS(281)*XX(33))/(JVS(944))
  XX(145) = (X(145)-JVS(162)*XX(31)-JVS(517)*XX(84)-JVS(792)*XX(132))/(JVS(958))
  XX(146) = (X(146)-JVS(163)*XX(31)-JVS(230)*XX(32)-JVS(347)*XX(42)-JVS(631)*XX(105))/(JVS(966))
  XX(147) = (X(147)-JVS(112)*XX(23)-JVS(164)*XX(31)-JVS(317)*XX(34)-JVS(327)*XX(35)-JVS(577)*XX(96)-JVS(850)*XX(137))&
              &/(JVS(978))
  XX(148) = (X(148)-JVS(165)*XX(31)-JVS(466)*XX(72)-JVS(793)*XX(132))/(JVS(987))
  XX(149) = (X(149)-JVS(282)*XX(33))/(JVS(1002))
  XX(150) = (X(150)-JVS(62)*XX(10)-JVS(166)*XX(31)-JVS(231)*XX(32)-JVS(283)*XX(33)-JVS(508)*XX(82)-JVS(743)*XX(125)&
              &-JVS(1003)*XX(149))/(JVS(1017))
  XX(151) = (X(151)-JVS(20)*XX(5))/(JVS(1030))
  XX(152) = (X(152)-JVS(75)*XX(13)-JVS(78)*XX(14)-JVS(232)*XX(32)-JVS(284)*XX(33)-JVS(730)*XX(123)-JVS(827)*XX(135)&
              &-JVS(851)*XX(137)-JVS(979)*XX(147)-JVS(1031)*XX(151))/(JVS(1052))
  XX(153) = (X(153)-JVS(21)*XX(5)-JVS(167)*XX(31)-JVS(285)*XX(33)-JVS(666)*XX(112)-JVS(1004)*XX(149))/(JVS(1057))
  XX(154) = (X(154)-JVS(168)*XX(31)-JVS(513)*XX(83)-JVS(794)*XX(132))/(JVS(1065))
  XX(155) = (X(155)-JVS(169)*XX(31)-JVS(544)*XX(90))/(JVS(1075))
  XX(156) = (X(156)-JVS(170)*XX(31)-JVS(470)*XX(73)-JVS(795)*XX(132))/(JVS(1087))
  XX(157) = (X(157)-JVS(171)*XX(31)-JVS(337)*XX(39)-JVS(407)*XX(59)-JVS(656)*XX(110)-JVS(680)*XX(114)-JVS(911)*XX(142)&
              &-JVS(1005)*XX(149)-JVS(1032)*XX(151))/(JVS(1098))
  XX(158) = (X(158)-JVS(172)*XX(31)-JVS(796)*XX(132))/(JVS(1106))
  XX(159) = (X(159)-JVS(22)*XX(5)-JVS(173)*XX(31)-JVS(797)*XX(132))/(JVS(1117))
  XX(160) = (X(160)-JVS(369)*XX(51)-JVS(381)*XX(54)-JVS(488)*XX(78)-JVS(717)*XX(121)-JVS(770)*XX(129))/(JVS(1140))
  XX(161) = (X(161)-JVS(174)*XX(31)-JVS(233)*XX(32)-JVS(554)*XX(91)-JVS(616)*XX(103)-JVS(652)*XX(109)-JVS(662)*XX(111)&
              &-JVS(882)*XX(140)-JVS(897)*XX(141))/(JVS(1153))
  XX(162) = (X(162)-JVS(234)*XX(32)-JVS(286)*XX(33)-JVS(408)*XX(59)-JVS(786)*XX(131)-JVS(1033)*XX(151))/(JVS(1166))
  XX(163) = (X(163)-JVS(235)*XX(32)-JVS(343)*XX(41)-JVS(354)*XX(45)-JVS(429)*XX(63)-JVS(459)*XX(70)-JVS(498)*XX(80)&
              &-JVS(526)*XX(86)-JVS(718)*XX(121)-JVS(771)*XX(129)-JVS(898)*XX(141)-JVS(1141)*XX(160))/(JVS(1182))
  XX(164) = (X(164)-JVS(175)*XX(31))/(JVS(1217))
  XX(165) = (X(165)-JVS(236)*XX(32)-JVS(460)*XX(70)-JVS(492)*XX(79)-JVS(499)*XX(80)-JVS(555)*XX(91)-JVS(609)*XX(102)&
              &-JVS(617)*XX(103)-JVS(711)*XX(120)-JVS(883)*XX(140)-JVS(899)*XX(141)-JVS(1142)*XX(160)-JVS(1154)*XX(161)&
              &-JVS(1183)*XX(163)-JVS(1218)*XX(164))/(JVS(1255))
  XX(166) = (X(166)-JVS(176)*XX(31)-JVS(237)*XX(32)-JVS(810)*XX(133)-JVS(967)*XX(146)-JVS(1219)*XX(164))/(JVS(1268))
  XX(167) = (X(167)-JVS(177)*XX(31)-JVS(798)*XX(132)-JVS(811)*XX(133)-JVS(968)*XX(146)-JVS(1220)*XX(164)-JVS(1269)&
              &*XX(166))/(JVS(1281))
  XX(168) = (X(168)-JVS(178)*XX(31)-JVS(238)*XX(32)-JVS(530)*XX(87)-JVS(799)*XX(132)-JVS(969)*XX(146)-JVS(1221)*XX(164))&
              &/(JVS(1290))
  XX(169) = (X(169)-JVS(179)*XX(31)-JVS(359)*XX(47)-JVS(509)*XX(82))/(JVS(1301))
  XX(170) = (X(170)-JVS(180)*XX(31)-JVS(545)*XX(90)-JVS(800)*XX(132)-JVS(1076)*XX(155))/(JVS(1316))
  XX(171) = (X(171)-JVS(181)*XX(31)-JVS(239)*XX(32)-JVS(531)*XX(87)-JVS(801)*XX(132)-JVS(812)*XX(133)-JVS(970)*XX(146)&
              &-JVS(1034)*XX(151)-JVS(1222)*XX(164))/(JVS(1327))
  XX(172) = (X(172)-JVS(23)*XX(5))/(JVS(1347))
  XX(173) = (X(173)-JVS(182)*XX(31)-JVS(338)*XX(39)-JVS(409)*XX(59)-JVS(657)*XX(110)-JVS(912)*XX(142)-JVS(1035)*XX(151)&
              &-JVS(1099)*XX(157)-JVS(1107)*XX(158)-JVS(1167)*XX(162)-JVS(1223)*XX(164)-JVS(1348)*XX(172))/(JVS(1379))
  XX(174) = (X(174)-JVS(240)*XX(32)-JVS(556)*XX(91)-JVS(610)*XX(102)-JVS(653)*XX(109)-JVS(663)*XX(111)-JVS(884)*XX(140)&
              &-JVS(900)*XX(141)-JVS(1155)*XX(161)-JVS(1224)*XX(164))/(JVS(1393))
  XX(175) = (X(175)-JVS(24)*XX(5)-JVS(287)*XX(33)-JVS(945)*XX(144)-JVS(1036)*XX(151)-JVS(1225)*XX(164))/(JVS(1418))
  XX(176) = (X(176)-JVS(25)*XX(5)-JVS(241)*XX(32)-JVS(378)*XX(53)-JVS(410)*XX(59)-JVS(673)*XX(113)-JVS(681)*XX(114)&
              &-JVS(927)*XX(143)-JVS(946)*XX(144)-JVS(1006)*XX(149)-JVS(1037)*XX(151)-JVS(1100)*XX(157)-JVS(1108)*XX(158)&
              &-JVS(1168)*XX(162)-JVS(1226)*XX(164)-JVS(1349)*XX(172)-JVS(1380)*XX(173)-JVS(1419)*XX(175))/(JVS(1434))
  XX(177) = (X(177)-JVS(183)*XX(31)-JVS(288)*XX(33)-JVS(601)*XX(101)-JVS(624)*XX(104)-JVS(637)*XX(106)-JVS(723)*XX(122)&
              &-JVS(802)*XX(132)-JVS(947)*XX(144)-JVS(1227)*XX(164)-JVS(1350)*XX(172)-JVS(1420)*XX(175))/(JVS(1444))
  XX(178) = (X(178)-JVS(184)*XX(31)-JVS(597)*XX(100)-JVS(803)*XX(132)-JVS(913)*XX(142)-JVS(1038)*XX(151)-JVS(1228)&
              &*XX(164)-JVS(1351)*XX(172)-JVS(1421)*XX(175))/(JVS(1454))
  XX(179) = (X(179)-JVS(26)*XX(5)-JVS(185)*XX(31)-JVS(289)*XX(33)-JVS(667)*XX(112)-JVS(706)*XX(119)-JVS(1118)*XX(159)&
              &-JVS(1229)*XX(164)-JVS(1352)*XX(172))/(JVS(1467))
  XX(180) = (X(180)-JVS(131)*XX(30)-JVS(242)*XX(32)-JVS(290)*XX(33)-JVS(1230)*XX(164))/(JVS(1504))
  XX(181) = (X(181)-JVS(243)*XX(32)-JVS(866)*XX(138)-JVS(872)*XX(139)-JVS(948)*XX(144)-JVS(1007)*XX(149)-JVS(1018)&
              &*XX(150)-JVS(1231)*XX(164)-JVS(1302)*XX(169)-JVS(1422)*XX(175)-JVS(1505)*XX(180))/(JVS(1528))
  XX(182) = (X(182)-JVS(244)*XX(32)-JVS(291)*XX(33)-JVS(753)*XX(127)-JVS(777)*XX(130)-JVS(852)*XX(137)-JVS(1423)*XX(175)&
              &-JVS(1445)*XX(177)-JVS(1506)*XX(180))/(JVS(1541))
  XX(183) = (X(183)-JVS(245)*XX(32)-JVS(423)*XX(62)-JVS(430)*XX(63)-JVS(493)*XX(79)-JVS(500)*XX(80)-JVS(557)*XX(91)&
              &-JVS(618)*XX(103)-JVS(901)*XX(141)-JVS(1143)*XX(160)-JVS(1156)*XX(161)-JVS(1184)*XX(163)-JVS(1232)*XX(164)&
              &-JVS(1256)*XX(165)-JVS(1394)*XX(174))/(JVS(1559))
  XX(184) = (X(184)-JVS(292)*XX(33)-JVS(1077)*XX(155)-JVS(1353)*XX(172)-JVS(1395)*XX(174)-JVS(1507)*XX(180)-JVS(1560)&
              &*XX(183))/(JVS(1578))
  XX(185) = (X(185)-JVS(27)*XX(5)-JVS(186)*XX(31)-JVS(293)*XX(33)-JVS(541)*XX(89)-JVS(568)*XX(94)-JVS(588)*XX(98)&
              &-JVS(593)*XX(99)-JVS(643)*XX(107)-JVS(647)*XX(108)-JVS(737)*XX(124)-JVS(804)*XX(132)-JVS(836)*XX(136)&
              &-JVS(914)*XX(142)-JVS(928)*XX(143)-JVS(949)*XX(144)-JVS(1008)*XX(149)-JVS(1039)*XX(151)-JVS(1169)*XX(162)&
              &-JVS(1233)*XX(164)-JVS(1354)*XX(172)-JVS(1381)*XX(173)-JVS(1424)*XX(175)-JVS(1435)*XX(176)-JVS(1446)*XX(177)&
              &-JVS(1508)*XX(180)-JVS(1542)*XX(182))/(JVS(1594))
  XX(186) = (X(186)-JVS(187)*XX(31)-JVS(294)*XX(33)-JVS(578)*XX(96)-JVS(805)*XX(132)-JVS(1170)*XX(162)-JVS(1234)*XX(164)&
              &-JVS(1355)*XX(172)-JVS(1509)*XX(180))/(JVS(1606))
  XX(187) = (X(187)-JVS(246)*XX(32)-JVS(295)*XX(33)-JVS(760)*XX(128)-JVS(828)*XX(135)-JVS(853)*XX(137)-JVS(959)*XX(145)&
              &-JVS(1009)*XX(149)-JVS(1040)*XX(151)-JVS(1066)*XX(154)-JVS(1356)*XX(172)-JVS(1396)*XX(174)-JVS(1510)*XX(180)&
              &-JVS(1561)*XX(183))/(JVS(1622))
  XX(188) = (X(188)-JVS(188)*XX(31)-JVS(247)*XX(32)-JVS(694)*XX(116)-JVS(1357)*XX(172)-JVS(1436)*XX(176)-JVS(1511)&
              &*XX(180)-JVS(1529)*XX(181)-JVS(1543)*XX(182))/(JVS(1638))
  XX(189) = (X(189)-JVS(28)*XX(5)-JVS(296)*XX(33)-JVS(1041)*XX(151)-JVS(1358)*XX(172)-JVS(1512)*XX(180))/(JVS(1685))
  XX(190) = (X(190)-JVS(189)*XX(31)-JVS(537)*XX(88)-JVS(806)*XX(132)-JVS(988)*XX(148)-JVS(1088)*XX(156)-JVS(1359)&
              &*XX(172)-JVS(1579)*XX(184)-JVS(1686)*XX(189))/(JVS(1717))
  XX(191) = (X(191)-JVS(248)*XX(32)-JVS(411)*XX(59)-JVS(989)*XX(148)-JVS(1089)*XX(156)-JVS(1109)*XX(158)-JVS(1235)&
              &*XX(164)-JVS(1360)*XX(172)-JVS(1580)*XX(184)-JVS(1687)*XX(189)-JVS(1718)*XX(190))/(JVS(1739))
  XX(192) = (X(192)-JVS(249)*XX(32)-JVS(478)*XX(75)-JVS(558)*XX(91)-JVS(560)*XX(92)-JVS(619)*XX(103)-JVS(712)*XX(120)&
              &-JVS(885)*XX(140)-JVS(902)*XX(141)-JVS(1157)*XX(161)-JVS(1236)*XX(164)-JVS(1257)*XX(165)-JVS(1397)*XX(174)&
              &-JVS(1562)*XX(183))/(JVS(1791))
  XX(193) = (X(193)-JVS(190)*XX(31)-JVS(447)*XX(68)-JVS(674)*XX(113)-JVS(1361)*XX(172)-JVS(1563)*XX(183)-JVS(1792)&
              &*XX(192))/(JVS(1818))
  XX(194) = (X(194)-JVS(250)*XX(32)-JVS(297)*XX(33)-JVS(1237)*XX(164)-JVS(1398)*XX(174)-JVS(1564)*XX(183)-JVS(1793)&
              &*XX(192))/(JVS(1900))
  XX(195) = (X(195)-JVS(251)*XX(32)-JVS(298)*XX(33)-JVS(433)*XX(64)-JVS(668)*XX(112)-JVS(744)*XX(125)-JVS(778)*XX(130)&
              &-JVS(829)*XX(135)-JVS(854)*XX(137)-JVS(1042)*XX(151)-JVS(1058)*XX(153)-JVS(1119)*XX(159)-JVS(1238)*XX(164)&
              &-JVS(1362)*XX(172)-JVS(1468)*XX(179)-JVS(1513)*XX(180)-JVS(1607)*XX(186)-JVS(1688)*XX(189)-JVS(1740)*XX(191)&
              &-JVS(1794)*XX(192)-JVS(1819)*XX(193)-JVS(1901)*XX(194))/(JVS(1927))
  XX(196) = (X(196)-JVS(252)*XX(32)-JVS(1239)*XX(164)-JVS(1303)*XX(169)-JVS(1317)*XX(170)-JVS(1363)*XX(172)-JVS(1514)&
              &*XX(180)-JVS(1689)*XX(189)-JVS(1741)*XX(191)-JVS(1795)*XX(192)-JVS(1820)*XX(193)-JVS(1902)*XX(194))&
              &/(JVS(1966))
  XX(197) = (X(197)-JVS(253)*XX(32)-JVS(299)*XX(33)-JVS(1240)*XX(164)-JVS(1399)*XX(174)-JVS(1565)*XX(183)-JVS(1796)&
              &*XX(192)-JVS(1903)*XX(194))/(JVS(2001))
  XX(198) = (X(198)-JVS(254)*XX(32)-JVS(300)*XX(33)-JVS(1241)*XX(164)-JVS(1304)*XX(169)-JVS(1821)*XX(193)-JVS(1904)&
              &*XX(194)-JVS(2002)*XX(197))/(JVS(2058))
  XX(199) = (X(199)-JVS(301)*XX(33)-JVS(364)*XX(49)-JVS(564)*XX(93)-JVS(611)*XX(102)-JVS(687)*XX(115)-JVS(713)*XX(120)&
              &-JVS(886)*XX(140)-JVS(990)*XX(148)-JVS(1067)*XX(154)-JVS(1078)*XX(155)-JVS(1090)*XX(156)-JVS(1158)*XX(161)&
              &-JVS(1242)*XX(164)-JVS(1258)*XX(165)-JVS(1364)*XX(172)-JVS(1400)*XX(174)-JVS(1515)*XX(180)-JVS(1566)*XX(183)&
              &-JVS(1581)*XX(184)-JVS(1623)*XX(187)-JVS(1690)*XX(189)-JVS(1797)*XX(192)-JVS(1822)*XX(193)-JVS(1905)*XX(194)&
              &-JVS(2003)*XX(197)-JVS(2059)*XX(198))/(JVS(2108))
  XX(200) = (X(200)-JVS(29)*XX(5)-JVS(191)*XX(31)-JVS(302)*XX(33)-JVS(419)*XX(61)-JVS(504)*XX(81)-JVS(625)*XX(104)&
              &-JVS(638)*XX(106)-JVS(724)*XX(122)-JVS(738)*XX(124)-JVS(813)*XX(133)-JVS(950)*XX(144)-JVS(960)*XX(145)&
              &-JVS(971)*XX(146)-JVS(991)*XX(148)-JVS(1010)*XX(149)-JVS(1059)*XX(153)-JVS(1068)*XX(154)-JVS(1079)*XX(155)&
              &-JVS(1091)*XX(156)-JVS(1110)*XX(158)-JVS(1120)*XX(159)-JVS(1243)*XX(164)-JVS(1270)*XX(166)-JVS(1282)*XX(167)&
              &-JVS(1291)*XX(168)-JVS(1305)*XX(169)-JVS(1318)*XX(170)-JVS(1328)*XX(171)-JVS(1365)*XX(172)-JVS(1425)*XX(175)&
              &-JVS(1447)*XX(177)-JVS(1455)*XX(178)-JVS(1469)*XX(179)-JVS(1516)*XX(180)-JVS(1530)*XX(181)-JVS(1544)*XX(182)&
              &-JVS(1582)*XX(184)-JVS(1595)*XX(185)-JVS(1608)*XX(186)-JVS(1624)*XX(187)-JVS(1639)*XX(188)-JVS(1691)*XX(189)&
              &-JVS(1719)*XX(190)-JVS(1742)*XX(191)-JVS(1798)*XX(192)-JVS(1823)*XX(193)-JVS(1906)*XX(194)-JVS(1928)*XX(195)&
              &-JVS(1967)*XX(196)-JVS(2004)*XX(197)-JVS(2060)*XX(198)-JVS(2109)*XX(199))/(JVS(2172))
  XX(201) = (X(201)-JVS(30)*XX(5)-JVS(63)*XX(10)-JVS(79)*XX(14)-JVS(255)*XX(32)-JVS(303)*XX(33)-JVS(434)*XX(64)-JVS(463)&
              &*XX(71)-JVS(474)*XX(74)-JVS(521)*XX(85)-JVS(561)*XX(92)-JVS(632)*XX(105)-JVS(669)*XX(112)-JVS(688)*XX(115)&
              &-JVS(698)*XX(117)-JVS(702)*XX(118)-JVS(719)*XX(121)-JVS(745)*XX(125)-JVS(749)*XX(126)-JVS(772)*XX(129)&
              &-JVS(814)*XX(133)-JVS(855)*XX(137)-JVS(873)*XX(139)-JVS(903)*XX(141)-JVS(951)*XX(144)-JVS(961)*XX(145)&
              &-JVS(972)*XX(146)-JVS(1011)*XX(149)-JVS(1019)*XX(150)-JVS(1043)*XX(151)-JVS(1053)*XX(152)-JVS(1060)*XX(153)&
              &-JVS(1121)*XX(159)-JVS(1144)*XX(160)-JVS(1185)*XX(163)-JVS(1244)*XX(164)-JVS(1259)*XX(165)-JVS(1271)*XX(166)&
              &-JVS(1283)*XX(167)-JVS(1292)*XX(168)-JVS(1306)*XX(169)-JVS(1319)*XX(170)-JVS(1329)*XX(171)-JVS(1366)*XX(172)&
              &-JVS(1401)*XX(174)-JVS(1456)*XX(178)-JVS(1470)*XX(179)-JVS(1517)*XX(180)-JVS(1531)*XX(181)-JVS(1545)*XX(182)&
              &-JVS(1567)*XX(183)-JVS(1583)*XX(184)-JVS(1596)*XX(185)-JVS(1609)*XX(186)-JVS(1625)*XX(187)-JVS(1640)*XX(188)&
              &-JVS(1692)*XX(189)-JVS(1720)*XX(190)-JVS(1743)*XX(191)-JVS(1799)*XX(192)-JVS(1824)*XX(193)-JVS(1907)*XX(194)&
              &-JVS(1929)*XX(195)-JVS(1968)*XX(196)-JVS(2005)*XX(197)-JVS(2061)*XX(198)-JVS(2110)*XX(199)-JVS(2173)*XX(200))&
              &/(JVS(2255))
  XX(202) = (X(202)-JVS(64)*XX(10)-JVS(192)*XX(31)-JVS(256)*XX(32)-JVS(357)*XX(46)-JVS(360)*XX(47)-JVS(365)*XX(49)&
              &-JVS(435)*XX(64)-JVS(438)*XX(65)-JVS(452)*XX(69)-JVS(481)*XX(76)-JVS(489)*XX(78)-JVS(505)*XX(81)-JVS(562)&
              &*XX(92)-JVS(707)*XX(119)-JVS(714)*XX(120)-JVS(720)*XX(121)-JVS(731)*XX(123)-JVS(746)*XX(125)-JVS(754)*XX(127)&
              &-JVS(761)*XX(128)-JVS(773)*XX(129)-JVS(779)*XX(130)-JVS(787)*XX(131)-JVS(820)*XX(134)-JVS(830)*XX(135)&
              &-JVS(856)*XX(137)-JVS(887)*XX(140)-JVS(904)*XX(141)-JVS(980)*XX(147)-JVS(1020)*XX(150)-JVS(1044)*XX(151)&
              &-JVS(1145)*XX(160)-JVS(1159)*XX(161)-JVS(1186)*XX(163)-JVS(1245)*XX(164)-JVS(1260)*XX(165)-JVS(1307)*XX(169)&
              &-JVS(1367)*XX(172)-JVS(1402)*XX(174)-JVS(1426)*XX(175)-JVS(1471)*XX(179)-JVS(1518)*XX(180)-JVS(1568)*XX(183)&
              &-JVS(1610)*XX(186)-JVS(1693)*XX(189)-JVS(1800)*XX(192)-JVS(1825)*XX(193)-JVS(1908)*XX(194)-JVS(1930)*XX(195)&
              &-JVS(1969)*XX(196)-JVS(2006)*XX(197)-JVS(2062)*XX(198)-JVS(2111)*XX(199)-JVS(2174)*XX(200)-JVS(2256)*XX(201))&
              &/(JVS(2360))
  XX(203) = (X(203)-JVS(31)*XX(5)-JVS(65)*XX(10)-JVS(73)*XX(12)-JVS(85)*XX(16)-JVS(98)*XX(20)-JVS(193)*XX(31)-JVS(257)&
              &*XX(32)-JVS(304)*XX(33)-JVS(339)*XX(39)-JVS(382)*XX(54)-JVS(385)*XX(55)-JVS(390)*XX(56)-JVS(412)*XX(59)&
              &-JVS(415)*XX(60)-JVS(453)*XX(69)-JVS(461)*XX(70)-JVS(569)*XX(94)-JVS(583)*XX(97)-JVS(589)*XX(98)-JVS(626)&
              &*XX(104)-JVS(639)*XX(106)-JVS(682)*XX(114)-JVS(725)*XX(122)-JVS(732)*XX(123)-JVS(739)*XX(124)-JVS(755)&
              &*XX(127)-JVS(762)*XX(128)-JVS(774)*XX(129)-JVS(780)*XX(130)-JVS(788)*XX(131)-JVS(815)*XX(133)-JVS(821)&
              &*XX(134)-JVS(831)*XX(135)-JVS(837)*XX(136)-JVS(857)*XX(137)-JVS(867)*XX(138)-JVS(874)*XX(139)-JVS(915)&
              &*XX(142)-JVS(929)*XX(143)-JVS(952)*XX(144)-JVS(962)*XX(145)-JVS(973)*XX(146)-JVS(981)*XX(147)-JVS(992)&
              &*XX(148)-JVS(1012)*XX(149)-JVS(1021)*XX(150)-JVS(1045)*XX(151)-JVS(1061)*XX(153)-JVS(1069)*XX(154)-JVS(1080)&
              &*XX(155)-JVS(1092)*XX(156)-JVS(1101)*XX(157)-JVS(1111)*XX(158)-JVS(1122)*XX(159)-JVS(1146)*XX(160)-JVS(1171)&
              &*XX(162)-JVS(1187)*XX(163)-JVS(1246)*XX(164)-JVS(1261)*XX(165)-JVS(1272)*XX(166)-JVS(1284)*XX(167)-JVS(1293)&
              &*XX(168)-JVS(1308)*XX(169)-JVS(1320)*XX(170)-JVS(1330)*XX(171)-JVS(1368)*XX(172)-JVS(1382)*XX(173)-JVS(1403)&
              &*XX(174)-JVS(1427)*XX(175)-JVS(1437)*XX(176)-JVS(1448)*XX(177)-JVS(1457)*XX(178)-JVS(1472)*XX(179)-JVS(1519)&
              &*XX(180)-JVS(1532)*XX(181)-JVS(1546)*XX(182)-JVS(1569)*XX(183)-JVS(1584)*XX(184)-JVS(1597)*XX(185)-JVS(1611)&
              &*XX(186)-JVS(1626)*XX(187)-JVS(1641)*XX(188)-JVS(1694)*XX(189)-JVS(1721)*XX(190)-JVS(1744)*XX(191)-JVS(1801)&
              &*XX(192)-JVS(1826)*XX(193)-JVS(1909)*XX(194)-JVS(1931)*XX(195)-JVS(1970)*XX(196)-JVS(2007)*XX(197)-JVS(2063)&
              &*XX(198)-JVS(2112)*XX(199)-JVS(2175)*XX(200)-JVS(2257)*XX(201)-JVS(2361)*XX(202))/(JVS(2440))
  XX(204) = (X(204)-JVS(32)*XX(5)-JVS(66)*XX(10)-JVS(194)*XX(31)-JVS(258)*XX(32)-JVS(305)*XX(33)-JVS(439)*XX(65)&
              &-JVS(494)*XX(79)-JVS(572)*XX(95)-JVS(620)*XX(103)-JVS(675)*XX(113)-JVS(807)*XX(132)-JVS(816)*XX(133)-JVS(868)&
              &*XX(138)-JVS(875)*XX(139)-JVS(905)*XX(141)-JVS(953)*XX(144)-JVS(963)*XX(145)-JVS(974)*XX(146)-JVS(993)&
              &*XX(148)-JVS(1013)*XX(149)-JVS(1062)*XX(153)-JVS(1070)*XX(154)-JVS(1081)*XX(155)-JVS(1093)*XX(156)-JVS(1112)&
              &*XX(158)-JVS(1123)*XX(159)-JVS(1247)*XX(164)-JVS(1273)*XX(166)-JVS(1285)*XX(167)-JVS(1294)*XX(168)-JVS(1309)&
              &*XX(169)-JVS(1321)*XX(170)-JVS(1331)*XX(171)-JVS(1369)*XX(172)-JVS(1404)*XX(174)-JVS(1428)*XX(175)-JVS(1438)&
              &*XX(176)-JVS(1449)*XX(177)-JVS(1458)*XX(178)-JVS(1473)*XX(179)-JVS(1520)*XX(180)-JVS(1533)*XX(181)-JVS(1547)&
              &*XX(182)-JVS(1570)*XX(183)-JVS(1585)*XX(184)-JVS(1598)*XX(185)-JVS(1612)*XX(186)-JVS(1627)*XX(187)-JVS(1642)&
              &*XX(188)-JVS(1695)*XX(189)-JVS(1722)*XX(190)-JVS(1745)*XX(191)-JVS(1802)*XX(192)-JVS(1827)*XX(193)-JVS(1910)&
              &*XX(194)-JVS(1932)*XX(195)-JVS(1971)*XX(196)-JVS(2008)*XX(197)-JVS(2064)*XX(198)-JVS(2113)*XX(199)-JVS(2176)&
              &*XX(200)-JVS(2258)*XX(201)-JVS(2362)*XX(202)-JVS(2441)*XX(203))/(JVS(2508))
  XX(205) = (X(205)-JVS(33)*XX(5)-JVS(76)*XX(13)-JVS(92)*XX(18)-JVS(101)*XX(21)-JVS(104)*XX(22)-JVS(113)*XX(23)-JVS(129)&
              &*XX(29)-JVS(195)*XX(31)-JVS(259)*XX(32)-JVS(306)*XX(33)-JVS(318)*XX(34)-JVS(328)*XX(35)-JVS(333)*XX(37)&
              &-JVS(335)*XX(38)-JVS(349)*XX(43)-JVS(351)*XX(44)-JVS(362)*XX(48)-JVS(367)*XX(50)-JVS(370)*XX(51)-JVS(379)&
              &*XX(53)-JVS(386)*XX(55)-JVS(391)*XX(56)-JVS(397)*XX(57)-JVS(402)*XX(58)-JVS(416)*XX(60)-JVS(420)*XX(61)&
              &-JVS(424)*XX(62)-JVS(436)*XX(64)-JVS(441)*XX(66)-JVS(444)*XX(67)-JVS(448)*XX(68)-JVS(454)*XX(69)-JVS(464)&
              &*XX(71)-JVS(467)*XX(72)-JVS(471)*XX(73)-JVS(475)*XX(74)-JVS(479)*XX(75)-JVS(482)*XX(76)-JVS(485)*XX(77)&
              &-JVS(495)*XX(79)-JVS(501)*XX(80)-JVS(506)*XX(81)-JVS(510)*XX(82)-JVS(514)*XX(83)-JVS(518)*XX(84)-JVS(522)&
              &*XX(85)-JVS(527)*XX(86)-JVS(532)*XX(87)-JVS(538)*XX(88)-JVS(542)*XX(89)-JVS(546)*XX(90)-JVS(565)*XX(93)&
              &-JVS(573)*XX(95)-JVS(579)*XX(96)-JVS(584)*XX(97)-JVS(590)*XX(98)-JVS(594)*XX(99)-JVS(598)*XX(100)-JVS(602)&
              &*XX(101)-JVS(612)*XX(102)-JVS(621)*XX(103)-JVS(627)*XX(104)-JVS(633)*XX(105)-JVS(640)*XX(106)-JVS(644)&
              &*XX(107)-JVS(648)*XX(108)-JVS(658)*XX(110)-JVS(670)*XX(112)-JVS(676)*XX(113)-JVS(683)*XX(114)-JVS(689)&
              &*XX(115)-JVS(695)*XX(116)-JVS(699)*XX(117)-JVS(703)*XX(118)-JVS(708)*XX(119)-JVS(726)*XX(122)-JVS(747)&
              &*XX(125)-JVS(750)*XX(126)-JVS(775)*XX(129)-JVS(789)*XX(131)-JVS(808)*XX(132)-JVS(817)*XX(133)-JVS(838)&
              &*XX(136)-JVS(858)*XX(137)-JVS(869)*XX(138)-JVS(888)*XX(140)-JVS(906)*XX(141)-JVS(916)*XX(142)-JVS(930)&
              &*XX(143)-JVS(954)*XX(144)-JVS(964)*XX(145)-JVS(975)*XX(146)-JVS(994)*XX(148)-JVS(1014)*XX(149)-JVS(1022)&
              &*XX(150)-JVS(1046)*XX(151)-JVS(1054)*XX(152)-JVS(1071)*XX(154)-JVS(1082)*XX(155)-JVS(1094)*XX(156)-JVS(1102)&
              &*XX(157)-JVS(1113)*XX(158)-JVS(1124)*XX(159)-JVS(1147)*XX(160)-JVS(1160)*XX(161)-JVS(1172)*XX(162)-JVS(1188)&
              &*XX(163)-JVS(1248)*XX(164)-JVS(1262)*XX(165)-JVS(1274)*XX(166)-JVS(1286)*XX(167)-JVS(1295)*XX(168)-JVS(1310)&
              &*XX(169)-JVS(1322)*XX(170)-JVS(1332)*XX(171)-JVS(1370)*XX(172)-JVS(1383)*XX(173)-JVS(1405)*XX(174)-JVS(1429)&
              &*XX(175)-JVS(1439)*XX(176)-JVS(1450)*XX(177)-JVS(1459)*XX(178)-JVS(1474)*XX(179)-JVS(1521)*XX(180)-JVS(1534)&
              &*XX(181)-JVS(1548)*XX(182)-JVS(1571)*XX(183)-JVS(1586)*XX(184)-JVS(1599)*XX(185)-JVS(1613)*XX(186)-JVS(1628)&
              &*XX(187)-JVS(1643)*XX(188)-JVS(1696)*XX(189)-JVS(1723)*XX(190)-JVS(1746)*XX(191)-JVS(1803)*XX(192)-JVS(1828)&
              &*XX(193)-JVS(1911)*XX(194)-JVS(1933)*XX(195)-JVS(1972)*XX(196)-JVS(2009)*XX(197)-JVS(2065)*XX(198)-JVS(2114)&
              &*XX(199)-JVS(2177)*XX(200)-JVS(2259)*XX(201)-JVS(2363)*XX(202)-JVS(2442)*XX(203)-JVS(2509)*XX(204))&
              &/(JVS(2654))
  XX(206) = (X(206)-JVS(34)*XX(5)-JVS(319)*XX(34)-JVS(733)*XX(123)-JVS(756)*XX(127)-JVS(763)*XX(128)-JVS(781)*XX(130)&
              &-JVS(822)*XX(134)-JVS(859)*XX(137)-JVS(982)*XX(147)-JVS(1371)*XX(172)-JVS(1430)*XX(175)-JVS(1522)*XX(180)&
              &-JVS(1614)*XX(186)-JVS(1697)*XX(189)-JVS(1804)*XX(192)-JVS(1912)*XX(194)-JVS(1934)*XX(195)-JVS(1973)*XX(196)&
              &-JVS(2010)*XX(197)-JVS(2066)*XX(198)-JVS(2115)*XX(199)-JVS(2178)*XX(200)-JVS(2260)*XX(201)-JVS(2364)*XX(202)&
              &-JVS(2443)*XX(203)-JVS(2510)*XX(204)-JVS(2655)*XX(205))/(JVS(2720))
  XX(207) = (X(207)-JVS(114)*XX(23)-JVS(329)*XX(35)-JVS(734)*XX(123)-JVS(757)*XX(127)-JVS(764)*XX(128)-JVS(782)*XX(130)&
              &-JVS(823)*XX(134)-JVS(832)*XX(135)-JVS(860)*XX(137)-JVS(983)*XX(147)-JVS(1047)*XX(151)-JVS(1372)*XX(172)&
              &-JVS(1431)*XX(175)-JVS(1523)*XX(180)-JVS(1615)*XX(186)-JVS(1698)*XX(189)-JVS(1805)*XX(192)-JVS(1913)*XX(194)&
              &-JVS(1935)*XX(195)-JVS(1974)*XX(196)-JVS(2011)*XX(197)-JVS(2067)*XX(198)-JVS(2116)*XX(199)-JVS(2179)*XX(200)&
              &-JVS(2261)*XX(201)-JVS(2365)*XX(202)-JVS(2444)*XX(203)-JVS(2511)*XX(204)-JVS(2656)*XX(205)-JVS(2721)*XX(206))&
              &/(JVS(2748))
  XX(208) = (X(208)-JVS(35)*XX(5)-JVS(260)*XX(32)-JVS(307)*XX(33)-JVS(628)*XX(104)-JVS(634)*XX(105)-JVS(654)*XX(109)&
              &-JVS(664)*XX(111)-JVS(677)*XX(113)-JVS(684)*XX(114)-JVS(700)*XX(117)-JVS(704)*XX(118)-JVS(709)*XX(119)&
              &-JVS(727)*XX(122)-JVS(735)*XX(123)-JVS(751)*XX(126)-JVS(758)*XX(127)-JVS(765)*XX(128)-JVS(783)*XX(130)&
              &-JVS(824)*XX(134)-JVS(833)*XX(135)-JVS(839)*XX(136)-JVS(861)*XX(137)-JVS(889)*XX(140)-JVS(917)*XX(142)&
              &-JVS(931)*XX(143)-JVS(955)*XX(144)-JVS(976)*XX(146)-JVS(984)*XX(147)-JVS(1015)*XX(149)-JVS(1048)*XX(151)&
              &-JVS(1055)*XX(152)-JVS(1148)*XX(160)-JVS(1161)*XX(161)-JVS(1173)*XX(162)-JVS(1189)*XX(163)-JVS(1249)*XX(164)&
              &-JVS(1263)*XX(165)-JVS(1275)*XX(166)-JVS(1287)*XX(167)-JVS(1296)*XX(168)-JVS(1323)*XX(170)-JVS(1333)*XX(171)&
              &-JVS(1373)*XX(172)-JVS(1384)*XX(173)-JVS(1406)*XX(174)-JVS(1432)*XX(175)-JVS(1440)*XX(176)-JVS(1460)*XX(178)&
              &-JVS(1475)*XX(179)-JVS(1524)*XX(180)-JVS(1535)*XX(181)-JVS(1549)*XX(182)-JVS(1572)*XX(183)-JVS(1587)*XX(184)&
              &-JVS(1600)*XX(185)-JVS(1616)*XX(186)-JVS(1629)*XX(187)-JVS(1644)*XX(188)-JVS(1699)*XX(189)-JVS(1724)*XX(190)&
              &-JVS(1747)*XX(191)-JVS(1806)*XX(192)-JVS(1829)*XX(193)-JVS(1914)*XX(194)-JVS(1936)*XX(195)-JVS(1975)*XX(196)&
              &-JVS(2012)*XX(197)-JVS(2068)*XX(198)-JVS(2117)*XX(199)-JVS(2180)*XX(200)-JVS(2262)*XX(201)-JVS(2366)*XX(202)&
              &-JVS(2445)*XX(203)-JVS(2512)*XX(204)-JVS(2657)*XX(205)-JVS(2722)*XX(206)-JVS(2749)*XX(207))/(JVS(2804))
  XX(209) = (X(209)-JVS(36)*XX(5)-JVS(67)*XX(10)-JVS(70)*XX(11)-JVS(82)*XX(15)-JVS(95)*XX(19)-JVS(196)*XX(31)-JVS(261)&
              &*XX(32)-JVS(308)*XX(33)-JVS(371)*XX(51)-JVS(387)*XX(55)-JVS(392)*XX(56)-JVS(417)*XX(60)-JVS(421)*XX(61)&
              &-JVS(449)*XX(68)-JVS(468)*XX(72)-JVS(472)*XX(73)-JVS(483)*XX(76)-JVS(511)*XX(82)-JVS(515)*XX(83)-JVS(519)&
              &*XX(84)-JVS(528)*XX(86)-JVS(533)*XX(87)-JVS(539)*XX(88)-JVS(547)*XX(90)-JVS(570)*XX(94)-JVS(574)*XX(95)&
              &-JVS(580)*XX(96)-JVS(585)*XX(97)-JVS(591)*XX(98)-JVS(595)*XX(99)-JVS(599)*XX(100)-JVS(603)*XX(101)-JVS(641)&
              &*XX(106)-JVS(645)*XX(107)-JVS(649)*XX(108)-JVS(659)*XX(110)-JVS(671)*XX(112)-JVS(685)*XX(114)-JVS(696)&
              &*XX(116)-JVS(728)*XX(122)-JVS(740)*XX(124)-JVS(790)*XX(131)-JVS(818)*XX(133)-JVS(862)*XX(137)-JVS(870)&
              &*XX(138)-JVS(876)*XX(139)-JVS(890)*XX(140)-JVS(907)*XX(141)-JVS(918)*XX(142)-JVS(932)*XX(143)-JVS(956)&
              &*XX(144)-JVS(965)*XX(145)-JVS(977)*XX(146)-JVS(995)*XX(148)-JVS(1016)*XX(149)-JVS(1023)*XX(150)-JVS(1049)&
              &*XX(151)-JVS(1063)*XX(153)-JVS(1072)*XX(154)-JVS(1083)*XX(155)-JVS(1095)*XX(156)-JVS(1103)*XX(157)-JVS(1114)&
              &*XX(158)-JVS(1125)*XX(159)-JVS(1149)*XX(160)-JVS(1162)*XX(161)-JVS(1174)*XX(162)-JVS(1190)*XX(163)-JVS(1250)&
              &*XX(164)-JVS(1264)*XX(165)-JVS(1276)*XX(166)-JVS(1288)*XX(167)-JVS(1297)*XX(168)-JVS(1311)*XX(169)-JVS(1324)&
              &*XX(170)-JVS(1334)*XX(171)-JVS(1374)*XX(172)-JVS(1385)*XX(173)-JVS(1407)*XX(174)-JVS(1433)*XX(175)-JVS(1451)&
              &*XX(177)-JVS(1461)*XX(178)-JVS(1476)*XX(179)-JVS(1525)*XX(180)-JVS(1550)*XX(182)-JVS(1573)*XX(183)-JVS(1588)&
              &*XX(184)-JVS(1601)*XX(185)-JVS(1617)*XX(186)-JVS(1630)*XX(187)-JVS(1645)*XX(188)-JVS(1700)*XX(189)-JVS(1725)&
              &*XX(190)-JVS(1748)*XX(191)-JVS(1807)*XX(192)-JVS(1830)*XX(193)-JVS(1915)*XX(194)-JVS(1937)*XX(195)-JVS(1976)&
              &*XX(196)-JVS(2013)*XX(197)-JVS(2069)*XX(198)-JVS(2118)*XX(199)-JVS(2181)*XX(200)-JVS(2263)*XX(201)-JVS(2367)&
              &*XX(202)-JVS(2446)*XX(203)-JVS(2513)*XX(204)-JVS(2658)*XX(205)-JVS(2723)*XX(206)-JVS(2750)*XX(207)-JVS(2805)&
              &*XX(208))/(JVS(2915))
  XX(210) = (X(210)-JVS(37)*XX(5)-JVS(197)*XX(31)-JVS(309)*XX(33)-JVS(442)*XX(66)-JVS(445)*XX(67)-JVS(486)*XX(77)&
              &-JVS(496)*XX(79)-JVS(523)*XX(85)-JVS(566)*XX(93)-JVS(575)*XX(95)-JVS(622)*XX(103)-JVS(678)*XX(113)-JVS(690)&
              &*XX(115)-JVS(863)*XX(137)-JVS(908)*XX(141)-JVS(996)*XX(148)-JVS(1050)*XX(151)-JVS(1056)*XX(152)-JVS(1073)&
              &*XX(154)-JVS(1084)*XX(155)-JVS(1096)*XX(156)-JVS(1163)*XX(161)-JVS(1251)*XX(164)-JVS(1375)*XX(172)-JVS(1408)&
              &*XX(174)-JVS(1462)*XX(178)-JVS(1526)*XX(180)-JVS(1574)*XX(183)-JVS(1589)*XX(184)-JVS(1602)*XX(185)-JVS(1618)&
              &*XX(186)-JVS(1631)*XX(187)-JVS(1646)*XX(188)-JVS(1701)*XX(189)-JVS(1726)*XX(190)-JVS(1749)*XX(191)-JVS(1808)&
              &*XX(192)-JVS(1831)*XX(193)-JVS(1916)*XX(194)-JVS(1938)*XX(195)-JVS(1977)*XX(196)-JVS(2014)*XX(197)-JVS(2070)&
              &*XX(198)-JVS(2119)*XX(199)-JVS(2182)*XX(200)-JVS(2264)*XX(201)-JVS(2368)*XX(202)-JVS(2447)*XX(203)-JVS(2514)&
              &*XX(204)-JVS(2659)*XX(205)-JVS(2724)*XX(206)-JVS(2751)*XX(207)-JVS(2806)*XX(208)-JVS(2916)*XX(209))&
              &/(JVS(2991))
  XX(211) = (X(211)-JVS(262)*XX(32)-JVS(310)*XX(33)-JVS(825)*XX(134)-JVS(834)*XX(135)-JVS(864)*XX(137)-JVS(1051)*XX(151)&
              &-JVS(1312)*XX(169)-JVS(1463)*XX(178)-JVS(1527)*XX(180)-JVS(1632)*XX(187)-JVS(1702)*XX(189)-JVS(1809)*XX(192)&
              &-JVS(1832)*XX(193)-JVS(1917)*XX(194)-JVS(1978)*XX(196)-JVS(2015)*XX(197)-JVS(2071)*XX(198)-JVS(2120)*XX(199)&
              &-JVS(2183)*XX(200)-JVS(2265)*XX(201)-JVS(2369)*XX(202)-JVS(2448)*XX(203)-JVS(2515)*XX(204)-JVS(2660)*XX(205)&
              &-JVS(2725)*XX(206)-JVS(2752)*XX(207)-JVS(2807)*XX(208)-JVS(2917)*XX(209)-JVS(2992)*XX(210))/(JVS(3011))
  XX(211) = XX(211)
  XX(210) = XX(210)-JVS(3010)*XX(211)
  XX(209) = XX(209)-JVS(2990)*XX(210)-JVS(3009)*XX(211)
  XX(208) = XX(208)-JVS(2914)*XX(209)-JVS(2989)*XX(210)-JVS(3008)*XX(211)
  XX(207) = XX(207)-JVS(2803)*XX(208)-JVS(2913)*XX(209)-JVS(2988)*XX(210)-JVS(3007)*XX(211)
  XX(206) = XX(206)-JVS(2747)*XX(207)-JVS(2802)*XX(208)-JVS(2912)*XX(209)-JVS(2987)*XX(210)-JVS(3006)*XX(211)
  XX(205) = XX(205)-JVS(2719)*XX(206)-JVS(2746)*XX(207)-JVS(2801)*XX(208)-JVS(2911)*XX(209)-JVS(2986)*XX(210)-JVS(3005)&
              &*XX(211)
  XX(204) = XX(204)-JVS(2653)*XX(205)-JVS(2718)*XX(206)-JVS(2745)*XX(207)-JVS(2800)*XX(208)-JVS(2910)*XX(209)-JVS(2985)&
              &*XX(210)-JVS(3004)*XX(211)
  XX(203) = XX(203)-JVS(2507)*XX(204)-JVS(2652)*XX(205)-JVS(2717)*XX(206)-JVS(2744)*XX(207)-JVS(2799)*XX(208)-JVS(2909)&
              &*XX(209)-JVS(2984)*XX(210)-JVS(3003)*XX(211)
  XX(202) = XX(202)-JVS(2439)*XX(203)-JVS(2506)*XX(204)-JVS(2651)*XX(205)-JVS(2716)*XX(206)-JVS(2743)*XX(207)-JVS(2798)&
              &*XX(208)-JVS(2908)*XX(209)-JVS(2983)*XX(210)-JVS(3002)*XX(211)
  XX(201) = XX(201)-JVS(2359)*XX(202)-JVS(2438)*XX(203)-JVS(2505)*XX(204)-JVS(2650)*XX(205)-JVS(2715)*XX(206)-JVS(2742)&
              &*XX(207)-JVS(2797)*XX(208)-JVS(2907)*XX(209)-JVS(2982)*XX(210)-JVS(3001)*XX(211)
  XX(200) = XX(200)-JVS(2254)*XX(201)-JVS(2358)*XX(202)-JVS(2437)*XX(203)-JVS(2504)*XX(204)-JVS(2649)*XX(205)-JVS(2714)&
              &*XX(206)-JVS(2741)*XX(207)-JVS(2796)*XX(208)-JVS(2906)*XX(209)-JVS(2981)*XX(210)-JVS(3000)*XX(211)
  XX(199) = XX(199)-JVS(2171)*XX(200)-JVS(2253)*XX(201)-JVS(2357)*XX(202)-JVS(2436)*XX(203)-JVS(2503)*XX(204)-JVS(2648)&
              &*XX(205)-JVS(2713)*XX(206)-JVS(2740)*XX(207)-JVS(2795)*XX(208)-JVS(2905)*XX(209)-JVS(2980)*XX(210)
  XX(198) = XX(198)-JVS(2107)*XX(199)-JVS(2170)*XX(200)-JVS(2252)*XX(201)-JVS(2356)*XX(202)-JVS(2435)*XX(203)-JVS(2502)&
              &*XX(204)-JVS(2647)*XX(205)-JVS(2712)*XX(206)-JVS(2794)*XX(208)-JVS(2904)*XX(209)-JVS(2979)*XX(210)
  XX(197) = XX(197)-JVS(2106)*XX(199)-JVS(2169)*XX(200)-JVS(2251)*XX(201)-JVS(2355)*XX(202)-JVS(2434)*XX(203)-JVS(2501)&
              &*XX(204)-JVS(2646)*XX(205)-JVS(2711)*XX(206)-JVS(2793)*XX(208)-JVS(2903)*XX(209)-JVS(2978)*XX(210)
  XX(196) = XX(196)-JVS(2000)*XX(197)-JVS(2057)*XX(198)-JVS(2105)*XX(199)-JVS(2168)*XX(200)-JVS(2250)*XX(201)-JVS(2354)&
              &*XX(202)-JVS(2433)*XX(203)-JVS(2500)*XX(204)-JVS(2645)*XX(205)-JVS(2710)*XX(206)-JVS(2792)*XX(208)-JVS(2902)&
              &*XX(209)-JVS(2977)*XX(210)
  XX(195) = XX(195)-JVS(1965)*XX(196)-JVS(1999)*XX(197)-JVS(2056)*XX(198)-JVS(2104)*XX(199)-JVS(2167)*XX(200)-JVS(2249)&
              &*XX(201)-JVS(2353)*XX(202)-JVS(2432)*XX(203)-JVS(2499)*XX(204)-JVS(2644)*XX(205)-JVS(2709)*XX(206)-JVS(2739)&
              &*XX(207)-JVS(2791)*XX(208)-JVS(2901)*XX(209)-JVS(2976)*XX(210)
  XX(194) = XX(194)-JVS(2103)*XX(199)-JVS(2248)*XX(201)-JVS(2352)*XX(202)-JVS(2431)*XX(203)-JVS(2498)*XX(204)-JVS(2643)&
              &*XX(205)-JVS(2708)*XX(206)-JVS(2790)*XX(208)-JVS(2900)*XX(209)-JVS(2975)*XX(210)
  XX(193) = XX(193)-JVS(1899)*XX(194)-JVS(1998)*XX(197)-JVS(2102)*XX(199)-JVS(2166)*XX(200)-JVS(2247)*XX(201)-JVS(2351)&
              &*XX(202)-JVS(2430)*XX(203)-JVS(2497)*XX(204)-JVS(2642)*XX(205)-JVS(2789)*XX(208)-JVS(2899)*XX(209)-JVS(2974)&
              &*XX(210)
  XX(192) = XX(192)-JVS(1898)*XX(194)-JVS(2101)*XX(199)-JVS(2246)*XX(201)-JVS(2350)*XX(202)-JVS(2429)*XX(203)-JVS(2496)&
              &*XX(204)-JVS(2641)*XX(205)-JVS(2788)*XX(208)-JVS(2898)*XX(209)-JVS(2973)*XX(210)
  XX(191) = XX(191)-JVS(1790)*XX(192)-JVS(1817)*XX(193)-JVS(1897)*XX(194)-JVS(1964)*XX(196)-JVS(1997)*XX(197)-JVS(2055)&
              &*XX(198)-JVS(2100)*XX(199)-JVS(2165)*XX(200)-JVS(2245)*XX(201)-JVS(2349)*XX(202)-JVS(2428)*XX(203)-JVS(2495)&
              &*XX(204)-JVS(2640)*XX(205)-JVS(2707)*XX(206)-JVS(2787)*XX(208)-JVS(2897)*XX(209)-JVS(2972)*XX(210)
  XX(190) = XX(190)-JVS(1738)*XX(191)-JVS(1789)*XX(192)-JVS(1816)*XX(193)-JVS(1896)*XX(194)-JVS(1963)*XX(196)-JVS(1996)&
              &*XX(197)-JVS(2054)*XX(198)-JVS(2099)*XX(199)-JVS(2164)*XX(200)-JVS(2244)*XX(201)-JVS(2348)*XX(202)-JVS(2427)&
              &*XX(203)-JVS(2494)*XX(204)-JVS(2639)*XX(205)-JVS(2706)*XX(206)-JVS(2786)*XX(208)-JVS(2896)*XX(209)-JVS(2971)&
              &*XX(210)
  XX(189) = XX(189)-JVS(1788)*XX(192)-JVS(1895)*XX(194)-JVS(2163)*XX(200)-JVS(2243)*XX(201)-JVS(2347)*XX(202)-JVS(2493)&
              &*XX(204)-JVS(2638)*XX(205)-JVS(2705)*XX(206)-JVS(2895)*XX(209)-JVS(2970)*XX(210)
  XX(188) = XX(188)-JVS(1684)*XX(189)-JVS(1716)*XX(190)-JVS(1737)*XX(191)-JVS(1787)*XX(192)-JVS(1815)*XX(193)-JVS(1894)&
              &*XX(194)-JVS(1926)*XX(195)-JVS(1962)*XX(196)-JVS(1995)*XX(197)-JVS(2053)*XX(198)-JVS(2162)*XX(200)-JVS(2242)&
              &*XX(201)-JVS(2346)*XX(202)-JVS(2426)*XX(203)-JVS(2492)*XX(204)-JVS(2637)*XX(205)-JVS(2704)*XX(206)-JVS(2738)&
              &*XX(207)-JVS(2785)*XX(208)-JVS(2894)*XX(209)-JVS(2969)*XX(210)-JVS(2999)*XX(211)
  XX(187) = XX(187)-JVS(1683)*XX(189)-JVS(1786)*XX(192)-JVS(1893)*XX(194)-JVS(1994)*XX(197)-JVS(2052)*XX(198)-JVS(2098)&
              &*XX(199)-JVS(2161)*XX(200)-JVS(2241)*XX(201)-JVS(2345)*XX(202)-JVS(2425)*XX(203)-JVS(2491)*XX(204)-JVS(2636)&
              &*XX(205)-JVS(2703)*XX(206)-JVS(2737)*XX(207)-JVS(2784)*XX(208)-JVS(2893)*XX(209)-JVS(2968)*XX(210)
  XX(186) = XX(186)-JVS(1682)*XX(189)-JVS(1785)*XX(192)-JVS(1892)*XX(194)-JVS(1961)*XX(196)-JVS(2051)*XX(198)-JVS(2160)&
              &*XX(200)-JVS(2240)*XX(201)-JVS(2344)*XX(202)-JVS(2424)*XX(203)-JVS(2490)*XX(204)-JVS(2635)*XX(205)-JVS(2702)&
              &*XX(206)-JVS(2892)*XX(209)-JVS(2967)*XX(210)
  XX(185) = XX(185)-JVS(1681)*XX(189)-JVS(1715)*XX(190)-JVS(1736)*XX(191)-JVS(1784)*XX(192)-JVS(1891)*XX(194)-JVS(1925)&
              &*XX(195)-JVS(1960)*XX(196)-JVS(1993)*XX(197)-JVS(2050)*XX(198)-JVS(2159)*XX(200)-JVS(2239)*XX(201)-JVS(2343)&
              &*XX(202)-JVS(2423)*XX(203)-JVS(2489)*XX(204)-JVS(2634)*XX(205)-JVS(2701)*XX(206)-JVS(2736)*XX(207)-JVS(2783)&
              &*XX(208)-JVS(2891)*XX(209)-JVS(2966)*XX(210)-JVS(2998)*XX(211)
  XX(184) = XX(184)-JVS(1680)*XX(189)-JVS(1783)*XX(192)-JVS(1890)*XX(194)-JVS(2097)*XX(199)-JVS(2158)*XX(200)-JVS(2238)&
              &*XX(201)-JVS(2342)*XX(202)-JVS(2422)*XX(203)-JVS(2488)*XX(204)-JVS(2633)*XX(205)-JVS(2700)*XX(206)-JVS(2782)&
              &*XX(208)-JVS(2890)*XX(209)-JVS(2965)*XX(210)
  XX(183) = XX(183)-JVS(1782)*XX(192)-JVS(1889)*XX(194)-JVS(2096)*XX(199)-JVS(2237)*XX(201)-JVS(2341)*XX(202)-JVS(2421)&
              &*XX(203)-JVS(2487)*XX(204)-JVS(2632)*XX(205)-JVS(2781)*XX(208)-JVS(2889)*XX(209)-JVS(2964)*XX(210)
  XX(182) = XX(182)-JVS(1679)*XX(189)-JVS(1714)*XX(190)-JVS(1781)*XX(192)-JVS(1888)*XX(194)-JVS(1959)*XX(196)-JVS(2049)&
              &*XX(198)-JVS(2157)*XX(200)-JVS(2236)*XX(201)-JVS(2340)*XX(202)-JVS(2420)*XX(203)-JVS(2486)*XX(204)-JVS(2631)&
              &*XX(205)-JVS(2699)*XX(206)-JVS(2735)*XX(207)-JVS(2780)*XX(208)-JVS(2888)*XX(209)-JVS(2963)*XX(210)
  XX(181) = XX(181)-JVS(1637)*XX(188)-JVS(1678)*XX(189)-JVS(1735)*XX(191)-JVS(1780)*XX(192)-JVS(1814)*XX(193)-JVS(1887)&
              &*XX(194)-JVS(1958)*XX(196)-JVS(1992)*XX(197)-JVS(2048)*XX(198)-JVS(2156)*XX(200)-JVS(2235)*XX(201)-JVS(2339)&
              &*XX(202)-JVS(2419)*XX(203)-JVS(2485)*XX(204)-JVS(2630)*XX(205)-JVS(2698)*XX(206)-JVS(2779)*XX(208)-JVS(2887)&
              &*XX(209)-JVS(2962)*XX(210)
  XX(180) = XX(180)-JVS(2155)*XX(200)-JVS(2234)*XX(201)-JVS(2338)*XX(202)-JVS(2629)*XX(205)-JVS(2697)*XX(206)-JVS(2886)&
              &*XX(209)
  XX(179) = XX(179)-JVS(1677)*XX(189)-JVS(1779)*XX(192)-JVS(1886)*XX(194)-JVS(1957)*XX(196)-JVS(2047)*XX(198)-JVS(2154)&
              &*XX(200)-JVS(2233)*XX(201)-JVS(2337)*XX(202)-JVS(2418)*XX(203)-JVS(2484)*XX(204)-JVS(2628)*XX(205)-JVS(2696)&
              &*XX(206)-JVS(2778)*XX(208)-JVS(2885)*XX(209)-JVS(2961)*XX(210)
  XX(178) = XX(178)-JVS(1503)*XX(180)-JVS(1778)*XX(192)-JVS(1885)*XX(194)-JVS(1956)*XX(196)-JVS(2046)*XX(198)-JVS(2153)&
              &*XX(200)-JVS(2232)*XX(201)-JVS(2336)*XX(202)-JVS(2417)*XX(203)-JVS(2483)*XX(204)-JVS(2627)*XX(205)-JVS(2695)&
              &*XX(206)-JVS(2884)*XX(209)-JVS(2960)*XX(210)
  XX(177) = XX(177)-JVS(1502)*XX(180)-JVS(1676)*XX(189)-JVS(1713)*XX(190)-JVS(1777)*XX(192)-JVS(1884)*XX(194)-JVS(1955)&
              &*XX(196)-JVS(2045)*XX(198)-JVS(2152)*XX(200)-JVS(2231)*XX(201)-JVS(2335)*XX(202)-JVS(2416)*XX(203)-JVS(2482)&
              &*XX(204)-JVS(2626)*XX(205)-JVS(2694)*XX(206)-JVS(2777)*XX(208)-JVS(2883)*XX(209)-JVS(2959)*XX(210)
  XX(176) = XX(176)-JVS(1501)*XX(180)-JVS(1540)*XX(182)-JVS(1675)*XX(189)-JVS(1712)*XX(190)-JVS(1734)*XX(191)-JVS(1776)&
              &*XX(192)-JVS(1883)*XX(194)-JVS(1991)*XX(197)-JVS(2044)*XX(198)-JVS(2151)*XX(200)-JVS(2230)*XX(201)-JVS(2334)&
              &*XX(202)-JVS(2415)*XX(203)-JVS(2481)*XX(204)-JVS(2625)*XX(205)-JVS(2693)*XX(206)-JVS(2776)*XX(208)-JVS(2882)&
              &*XX(209)-JVS(2958)*XX(210)
  XX(175) = XX(175)-JVS(1775)*XX(192)-JVS(1882)*XX(194)-JVS(2229)*XX(201)-JVS(2333)*XX(202)-JVS(2624)*XX(205)-JVS(2692)&
              &*XX(206)-JVS(2881)*XX(209)-JVS(2957)*XX(210)
  XX(174) = XX(174)-JVS(1558)*XX(183)-JVS(1774)*XX(192)-JVS(2095)*XX(199)-JVS(2228)*XX(201)-JVS(2332)*XX(202)-JVS(2623)&
              &*XX(205)-JVS(2775)*XX(208)-JVS(2956)*XX(210)
  XX(173) = XX(173)-JVS(1417)*XX(175)-JVS(1500)*XX(180)-JVS(1674)*XX(189)-JVS(1711)*XX(190)-JVS(1733)*XX(191)-JVS(1773)&
              &*XX(192)-JVS(1881)*XX(194)-JVS(1990)*XX(197)-JVS(2043)*XX(198)-JVS(2150)*XX(200)-JVS(2227)*XX(201)-JVS(2331)&
              &*XX(202)-JVS(2414)*XX(203)-JVS(2480)*XX(204)-JVS(2622)*XX(205)-JVS(2691)*XX(206)-JVS(2880)*XX(209)-JVS(2955)&
              &*XX(210)
  XX(172) = XX(172)-JVS(1772)*XX(192)-JVS(2479)*XX(204)-JVS(2621)*XX(205)-JVS(2954)*XX(210)
  XX(171) = XX(171)-JVS(1577)*XX(184)-JVS(1673)*XX(189)-JVS(1710)*XX(190)-JVS(1771)*XX(192)-JVS(1880)*XX(194)-JVS(1954)&
              &*XX(196)-JVS(2042)*XX(198)-JVS(2149)*XX(200)-JVS(2226)*XX(201)-JVS(2330)*XX(202)-JVS(2413)*XX(203)-JVS(2478)&
              &*XX(204)-JVS(2620)*XX(205)-JVS(2774)*XX(208)-JVS(2879)*XX(209)-JVS(2953)*XX(210)
  XX(170) = XX(170)-JVS(1346)*XX(172)-JVS(1499)*XX(180)-JVS(1672)*XX(189)-JVS(1732)*XX(191)-JVS(1879)*XX(194)-JVS(1953)&
              &*XX(196)-JVS(1989)*XX(197)-JVS(2041)*XX(198)-JVS(2148)*XX(200)-JVS(2329)*XX(202)-JVS(2412)*XX(203)-JVS(2477)&
              &*XX(204)-JVS(2619)*XX(205)-JVS(2878)*XX(209)
  XX(169) = XX(169)-JVS(1813)*XX(193)-JVS(1878)*XX(194)-JVS(1988)*XX(197)-JVS(2147)*XX(200)-JVS(2328)*XX(202)-JVS(2411)&
              &*XX(203)-JVS(2476)*XX(204)-JVS(2618)*XX(205)-JVS(2773)*XX(208)-JVS(2877)*XX(209)
  XX(168) = XX(168)-JVS(1621)*XX(187)-JVS(1671)*XX(189)-JVS(1709)*XX(190)-JVS(1877)*XX(194)-JVS(1924)*XX(195)-JVS(1952)&
              &*XX(196)-JVS(2040)*XX(198)-JVS(2146)*XX(200)-JVS(2225)*XX(201)-JVS(2327)*XX(202)-JVS(2410)*XX(203)-JVS(2475)&
              &*XX(204)-JVS(2617)*XX(205)-JVS(2772)*XX(208)-JVS(2876)*XX(209)
  XX(167) = XX(167)-JVS(1670)*XX(189)-JVS(1876)*XX(194)-JVS(1951)*XX(196)-JVS(2039)*XX(198)-JVS(2145)*XX(200)-JVS(2224)&
              &*XX(201)-JVS(2326)*XX(202)-JVS(2409)*XX(203)-JVS(2474)*XX(204)-JVS(2616)*XX(205)-JVS(2771)*XX(208)-JVS(2875)&
              &*XX(209)
  XX(166) = XX(166)-JVS(1280)*XX(167)-JVS(1669)*XX(189)-JVS(1875)*XX(194)-JVS(1950)*XX(196)-JVS(2038)*XX(198)-JVS(2144)&
              &*XX(200)-JVS(2223)*XX(201)-JVS(2325)*XX(202)-JVS(2408)*XX(203)-JVS(2473)*XX(204)-JVS(2615)*XX(205)-JVS(2770)&
              &*XX(208)-JVS(2874)*XX(209)
  XX(165) = XX(165)-JVS(1392)*XX(174)-JVS(1557)*XX(183)-JVS(1770)*XX(192)-JVS(2094)*XX(199)-JVS(2222)*XX(201)-JVS(2324)&
              &*XX(202)-JVS(2407)*XX(203)-JVS(2614)*XX(205)-JVS(2769)*XX(208)-JVS(2873)*XX(209)-JVS(2952)*XX(210)
  XX(164) = XX(164)-JVS(2221)*XX(201)-JVS(2323)*XX(202)-JVS(2613)*XX(205)
  XX(163) = XX(163)-JVS(1216)*XX(164)-JVS(1254)*XX(165)-JVS(1391)*XX(174)-JVS(1556)*XX(183)-JVS(1769)*XX(192)-JVS(2093)&
              &*XX(199)-JVS(2220)*XX(201)-JVS(2322)*XX(202)-JVS(2406)*XX(203)-JVS(2612)*XX(205)-JVS(2768)*XX(208)-JVS(2872)&
              &*XX(209)-JVS(2951)*XX(210)
  XX(162) = XX(162)-JVS(1215)*XX(164)-JVS(1345)*XX(172)-JVS(1498)*XX(180)-JVS(1668)*XX(189)-JVS(1768)*XX(192)-JVS(1874)&
              &*XX(194)-JVS(2219)*XX(201)-JVS(2321)*XX(202)-JVS(2405)*XX(203)-JVS(2611)*XX(205)-JVS(2690)*XX(206)-JVS(2871)&
              &*XX(209)-JVS(2950)*XX(210)
  XX(161) = XX(161)-JVS(1214)*XX(164)-JVS(1390)*XX(174)-JVS(1555)*XX(183)-JVS(1767)*XX(192)-JVS(2092)*XX(199)-JVS(2218)&
              &*XX(201)-JVS(2320)*XX(202)-JVS(2610)*XX(205)-JVS(2767)*XX(208)-JVS(2949)*XX(210)
  XX(160) = XX(160)-JVS(1181)*XX(163)-JVS(1213)*XX(164)-JVS(1253)*XX(165)-JVS(2091)*XX(199)-JVS(2217)*XX(201)-JVS(2319)&
              &*XX(202)-JVS(2404)*XX(203)-JVS(2609)*XX(205)-JVS(2766)*XX(208)-JVS(2870)*XX(209)-JVS(2948)*XX(210)
  XX(159) = XX(159)-JVS(1212)*XX(164)-JVS(1344)*XX(172)-JVS(1667)*XX(189)-JVS(1873)*XX(194)-JVS(1949)*XX(196)-JVS(2037)&
              &*XX(198)-JVS(2143)*XX(200)-JVS(2318)*XX(202)-JVS(2403)*XX(203)-JVS(2472)*XX(204)-JVS(2608)*XX(205)-JVS(2869)&
              &*XX(209)
  XX(158) = XX(158)-JVS(1343)*XX(172)-JVS(1708)*XX(190)-JVS(1731)*XX(191)-JVS(1872)*XX(194)-JVS(1987)*XX(197)-JVS(2036)&
              &*XX(198)-JVS(2142)*XX(200)-JVS(2317)*XX(202)-JVS(2402)*XX(203)-JVS(2471)*XX(204)-JVS(2607)*XX(205)-JVS(2868)&
              &*XX(209)
  XX(157) = XX(157)-JVS(1105)*XX(158)-JVS(1165)*XX(162)-JVS(1211)*XX(164)-JVS(1378)*XX(173)-JVS(1416)*XX(175)-JVS(1497)&
              &*XX(180)-JVS(1666)*XX(189)-JVS(1766)*XX(192)-JVS(1871)*XX(194)-JVS(2035)*XX(198)-JVS(2141)*XX(200)-JVS(2216)&
              &*XX(201)-JVS(2316)*XX(202)-JVS(2401)*XX(203)-JVS(2470)*XX(204)-JVS(2606)*XX(205)-JVS(2689)*XX(206)-JVS(2867)&
              &*XX(209)-JVS(2947)*XX(210)
  XX(156) = XX(156)-JVS(1342)*XX(172)-JVS(1576)*XX(184)-JVS(1870)*XX(194)-JVS(2034)*XX(198)-JVS(2140)*XX(200)-JVS(2315)&
              &*XX(202)-JVS(2400)*XX(203)-JVS(2469)*XX(204)-JVS(2605)*XX(205)-JVS(2866)*XX(209)
  XX(155) = XX(155)-JVS(1341)*XX(172)-JVS(1496)*XX(180)-JVS(1665)*XX(189)-JVS(1869)*XX(194)-JVS(2139)*XX(200)-JVS(2314)&
              &*XX(202)-JVS(2399)*XX(203)-JVS(2468)*XX(204)-JVS(2604)*XX(205)-JVS(2865)*XX(209)
  XX(154) = XX(154)-JVS(1340)*XX(172)-JVS(1664)*XX(189)-JVS(1868)*XX(194)-JVS(1986)*XX(197)-JVS(2033)*XX(198)-JVS(2138)&
              &*XX(200)-JVS(2313)*XX(202)-JVS(2398)*XX(203)-JVS(2467)*XX(204)-JVS(2603)*XX(205)-JVS(2864)*XX(209)
  XX(153) = XX(153)-JVS(1116)*XX(159)-JVS(1339)*XX(172)-JVS(1466)*XX(179)-JVS(1495)*XX(180)-JVS(1730)*XX(191)-JVS(1867)&
              &*XX(194)-JVS(2032)*XX(198)-JVS(2137)*XX(200)-JVS(2312)*XX(202)-JVS(2397)*XX(203)-JVS(2466)*XX(204)-JVS(2602)&
              &*XX(205)-JVS(2688)*XX(206)-JVS(2863)*XX(209)
  XX(152) = XX(152)-JVS(1453)*XX(178)-JVS(1593)*XX(185)-JVS(1605)*XX(186)-JVS(1620)*XX(187)-JVS(1636)*XX(188)-JVS(1663)&
              &*XX(189)-JVS(1765)*XX(192)-JVS(1866)*XX(194)-JVS(1923)*XX(195)-JVS(2136)*XX(200)-JVS(2215)*XX(201)-JVS(2311)&
              &*XX(202)-JVS(2396)*XX(203)-JVS(2465)*XX(204)-JVS(2601)*XX(205)-JVS(2687)*XX(206)-JVS(2734)*XX(207)-JVS(2765)&
              &*XX(208)-JVS(2862)*XX(209)-JVS(2946)*XX(210)-JVS(2997)*XX(211)
  XX(151) = XX(151)-JVS(1764)*XX(192)-JVS(2600)*XX(205)-JVS(2861)*XX(209)-JVS(2945)*XX(210)
  XX(150) = XX(150)-JVS(1300)*XX(169)-JVS(1494)*XX(180)-JVS(1662)*XX(189)-JVS(1865)*XX(194)-JVS(1985)*XX(197)-JVS(2135)&
              &*XX(200)-JVS(2214)*XX(201)-JVS(2310)*XX(202)-JVS(2395)*XX(203)-JVS(2464)*XX(204)-JVS(2599)*XX(205)-JVS(2686)&
              &*XX(206)-JVS(2764)*XX(208)-JVS(2860)*XX(209)
  XX(149) = XX(149)-JVS(1493)*XX(180)-JVS(1864)*XX(194)-JVS(2309)*XX(202)-JVS(2463)*XX(204)-JVS(2598)*XX(205)-JVS(2685)&
              &*XX(206)
  XX(148) = XX(148)-JVS(1338)*XX(172)-JVS(1863)*XX(194)-JVS(2031)*XX(198)-JVS(2134)*XX(200)-JVS(2308)*XX(202)-JVS(2394)&
              &*XX(203)-JVS(2462)*XX(204)-JVS(2597)*XX(205)-JVS(2859)*XX(209)
  XX(147) = XX(147)-JVS(1604)*XX(186)-JVS(1661)*XX(189)-JVS(1763)*XX(192)-JVS(1862)*XX(194)-JVS(1922)*XX(195)-JVS(2213)&
              &*XX(201)-JVS(2307)*XX(202)-JVS(2393)*XX(203)-JVS(2596)*XX(205)-JVS(2684)*XX(206)-JVS(2733)*XX(207)-JVS(2858)&
              &*XX(209)-JVS(2944)*XX(210)
  XX(146) = XX(146)-JVS(1210)*XX(164)-JVS(1660)*XX(189)-JVS(2030)*XX(198)-JVS(2212)*XX(201)-JVS(2306)*XX(202)-JVS(2595)&
              &*XX(205)-JVS(2763)*XX(208)
  XX(145) = XX(145)-JVS(1001)*XX(149)-JVS(1337)*XX(172)-JVS(1861)*XX(194)-JVS(1984)*XX(197)-JVS(2029)*XX(198)-JVS(2133)&
              &*XX(200)-JVS(2305)*XX(202)-JVS(2392)*XX(203)-JVS(2461)*XX(204)-JVS(2594)*XX(205)-JVS(2857)*XX(209)
  XX(144) = XX(144)-JVS(1209)*XX(164)-JVS(1860)*XX(194)-JVS(2211)*XX(201)-JVS(2593)*XX(205)-JVS(2683)*XX(206)-JVS(2856)&
              &*XX(209)
  XX(143) = XX(143)-JVS(943)*XX(144)-JVS(1029)*XX(151)-JVS(1415)*XX(175)-JVS(1492)*XX(180)-JVS(1659)*XX(189)-JVS(1859)&
              &*XX(194)-JVS(2132)*XX(200)-JVS(2304)*XX(202)-JVS(2391)*XX(203)-JVS(2592)*XX(205)-JVS(2682)*XX(206)-JVS(2855)&
              &*XX(209)
  XX(142) = XX(142)-JVS(1028)*XX(151)-JVS(1208)*XX(164)-JVS(1414)*XX(175)-JVS(1491)*XX(180)-JVS(1858)*XX(194)-JVS(2131)&
              &*XX(200)-JVS(2210)*XX(201)-JVS(2303)*XX(202)-JVS(2591)*XX(205)
  XX(141) = XX(141)-JVS(1389)*XX(174)-JVS(1554)*XX(183)-JVS(1762)*XX(192)-JVS(2090)*XX(199)-JVS(2590)*XX(205)-JVS(2943)&
              &*XX(210)
  XX(140) = XX(140)-JVS(1152)*XX(161)-JVS(1207)*XX(164)-JVS(1388)*XX(174)-JVS(1761)*XX(192)-JVS(2089)*XX(199)-JVS(2589)&
              &*XX(205)-JVS(2762)*XX(208)-JVS(2942)*XX(210)
  XX(139) = XX(139)-JVS(942)*XX(144)-JVS(1000)*XX(149)-JVS(1635)*XX(188)-JVS(1729)*XX(191)-JVS(1857)*XX(194)-JVS(1948)&
              &*XX(196)-JVS(2028)*XX(198)-JVS(2209)*XX(201)-JVS(2302)*XX(202)-JVS(2390)*XX(203)-JVS(2460)*XX(204)-JVS(2588)&
              &*XX(205)-JVS(2854)*XX(209)
  XX(138) = XX(138)-JVS(941)*XX(144)-JVS(999)*XX(149)-JVS(1634)*XX(188)-JVS(1728)*XX(191)-JVS(1856)*XX(194)-JVS(1947)&
              &*XX(196)-JVS(2027)*XX(198)-JVS(2301)*XX(202)-JVS(2389)*XX(203)-JVS(2459)*XX(204)-JVS(2587)*XX(205)-JVS(2853)&
              &*XX(209)
  XX(137) = XX(137)-JVS(1760)*XX(192)-JVS(2586)*XX(205)-JVS(2852)*XX(209)-JVS(2941)*XX(210)
  XX(136) = XX(136)-JVS(909)*XX(142)-JVS(925)*XX(143)-JVS(998)*XX(149)-JVS(1027)*XX(151)-JVS(1164)*XX(162)-JVS(1206)&
              &*XX(164)-JVS(1377)*XX(173)-JVS(1539)*XX(182)-JVS(1855)*XX(194)-JVS(2300)*XX(202)-JVS(2585)*XX(205)-JVS(2681)&
              &*XX(206)-JVS(2761)*XX(208)-JVS(2851)*XX(209)
  XX(135) = XX(135)-JVS(848)*XX(137)-JVS(1026)*XX(151)-JVS(1854)*XX(194)-JVS(2208)*XX(201)-JVS(2299)*XX(202)-JVS(2388)&
              &*XX(203)-JVS(2732)*XX(207)
  XX(134) = XX(134)-JVS(847)*XX(137)-JVS(1490)*XX(180)-JVS(2130)*XX(200)-JVS(2207)*XX(201)-JVS(2298)*XX(202)-JVS(2387)&
              &*XX(203)-JVS(2458)*XX(204)-JVS(2680)*XX(206)-JVS(2731)*XX(207)
  XX(133) = XX(133)-JVS(1205)*XX(164)-JVS(1658)*XX(189)-JVS(1946)*XX(196)-JVS(2206)*XX(201)-JVS(2297)*XX(202)-JVS(2584)&
              &*XX(205)
  XX(132) = XX(132)-JVS(2026)*XX(198)-JVS(2583)*XX(205)-JVS(2850)*XX(209)
  XX(131) = XX(131)-JVS(1025)*XX(151)-JVS(1336)*XX(172)-JVS(1489)*XX(180)-JVS(1657)*XX(189)-JVS(1853)*XX(194)-JVS(2205)&
              &*XX(201)-JVS(2296)*XX(202)-JVS(2386)*XX(203)-JVS(2582)*XX(205)-JVS(2849)*XX(209)
  XX(130) = XX(130)-JVS(846)*XX(137)-JVS(1488)*XX(180)-JVS(2204)*XX(201)-JVS(2295)*XX(202)-JVS(2385)*XX(203)-JVS(2679)&
              &*XX(206)-JVS(2730)*XX(207)
  XX(129) = XX(129)-JVS(1139)*XX(160)-JVS(1180)*XX(163)-JVS(1204)*XX(164)-JVS(2088)*XX(199)-JVS(2203)*XX(201)-JVS(2294)&
              &*XX(202)-JVS(2581)*XX(205)-JVS(2940)*XX(210)
  XX(128) = XX(128)-JVS(845)*XX(137)-JVS(1335)*XX(172)-JVS(1983)*XX(197)-JVS(2202)*XX(201)-JVS(2293)*XX(202)-JVS(2384)&
              &*XX(203)-JVS(2678)*XX(206)-JVS(2729)*XX(207)
  XX(127) = XX(127)-JVS(844)*XX(137)-JVS(1413)*XX(175)-JVS(1656)*XX(189)-JVS(2201)*XX(201)-JVS(2292)*XX(202)-JVS(2383)&
              &*XX(203)-JVS(2677)*XX(206)-JVS(2728)*XX(207)
  XX(126) = XX(126)-JVS(843)*XX(137)-JVS(1024)*XX(151)-JVS(1267)*XX(166)-JVS(1279)*XX(167)-JVS(1289)*XX(168)-JVS(1315)&
              &*XX(170)-JVS(1619)*XX(187)-JVS(1812)*XX(193)-JVS(1852)*XX(194)-JVS(1921)*XX(195)-JVS(2200)*XX(201)-JVS(2580)&
              &*XX(205)-JVS(2676)*XX(206)-JVS(2760)*XX(208)-JVS(2848)*XX(209)
  XX(125) = XX(125)-JVS(1655)*XX(189)-JVS(1851)*XX(194)-JVS(2129)*XX(200)-JVS(2199)*XX(201)-JVS(2291)*XX(202)-JVS(2457)&
              &*XX(204)-JVS(2579)*XX(205)-JVS(2675)*XX(206)-JVS(2847)*XX(209)
  XX(124) = XX(124)-JVS(940)*XX(144)-JVS(1203)*XX(164)-JVS(1412)*XX(175)-JVS(1487)*XX(180)-JVS(1654)*XX(189)-JVS(1707)&
              &*XX(190)-JVS(2025)*XX(198)-JVS(2290)*XX(202)-JVS(2382)*XX(203)-JVS(2578)*XX(205)-JVS(2846)*XX(209)
  XX(123) = XX(123)-JVS(842)*XX(137)-JVS(2198)*XX(201)-JVS(2289)*XX(202)-JVS(2381)*XX(203)-JVS(2674)*XX(206)-JVS(2727)&
              &*XX(207)-JVS(2996)*XX(211)
  XX(122) = XX(122)-JVS(1202)*XX(164)-JVS(1706)*XX(190)-JVS(2024)*XX(198)-JVS(2288)*XX(202)-JVS(2380)*XX(203)-JVS(2577)&
              &*XX(205)-JVS(2845)*XX(209)
  XX(121) = XX(121)-JVS(768)*XX(129)-JVS(1138)*XX(160)-JVS(1179)*XX(163)-JVS(1201)*XX(164)-JVS(2087)*XX(199)-JVS(2197)&
              &*XX(201)-JVS(2287)*XX(202)-JVS(2939)*XX(210)
  XX(120) = XX(120)-JVS(880)*XX(140)-JVS(1200)*XX(164)-JVS(1252)*XX(165)-JVS(1759)*XX(192)-JVS(2086)*XX(199)-JVS(2196)&
              &*XX(201)-JVS(2286)*XX(202)-JVS(2576)*XX(205)-JVS(2938)*XX(210)
  XX(119) = XX(119)-JVS(1465)*XX(179)-JVS(1653)*XX(189)-JVS(1850)*XX(194)-JVS(2128)*XX(200)-JVS(2195)*XX(201)-JVS(2285)&
              &*XX(202)-JVS(2575)*XX(205)-JVS(2673)*XX(206)-JVS(2759)*XX(208)
  XX(118) = XX(118)-JVS(841)*XX(137)-JVS(1266)*XX(166)-JVS(1278)*XX(167)-JVS(1314)*XX(170)-JVS(1326)*XX(171)-JVS(1945)&
              &*XX(196)-JVS(2023)*XX(198)-JVS(2194)*XX(201)-JVS(2574)*XX(205)-JVS(2672)*XX(206)-JVS(2758)*XX(208)-JVS(2844)&
              &*XX(209)
  XX(117) = XX(117)-JVS(840)*XX(137)-JVS(1265)*XX(166)-JVS(1277)*XX(167)-JVS(1313)*XX(170)-JVS(1325)*XX(171)-JVS(1944)&
              &*XX(196)-JVS(2022)*XX(198)-JVS(2193)*XX(201)-JVS(2573)*XX(205)-JVS(2671)*XX(206)-JVS(2757)*XX(208)-JVS(2843)&
              &*XX(209)
  XX(116) = XX(116)-JVS(1633)*XX(188)-JVS(1727)*XX(191)-JVS(1943)*XX(196)-JVS(2021)*XX(198)-JVS(2284)*XX(202)-JVS(2572)&
              &*XX(205)-JVS(2842)*XX(209)
  XX(115) = XX(115)-JVS(1199)*XX(164)-JVS(1387)*XX(174)-JVS(1758)*XX(192)-JVS(1811)*XX(193)-JVS(2085)*XX(199)-JVS(2192)&
              &*XX(201)-JVS(2571)*XX(205)-JVS(2937)*XX(210)
  XX(114) = XX(114)-JVS(1849)*XX(194)-JVS(2283)*XX(202)-JVS(2570)*XX(205)-JVS(2670)*XX(206)-JVS(2841)*XX(209)
  XX(113) = XX(113)-JVS(1757)*XX(192)-JVS(1982)*XX(197)-JVS(2569)*XX(205)-JVS(2840)*XX(209)-JVS(2936)*XX(210)
  XX(112) = XX(112)-JVS(1115)*XX(159)-JVS(1464)*XX(179)-JVS(1848)*XX(194)-JVS(2127)*XX(200)-JVS(2568)*XX(205)
  XX(111) = XX(111)-JVS(879)*XX(140)-JVS(1151)*XX(161)-JVS(1198)*XX(164)-JVS(2084)*XX(199)-JVS(2567)*XX(205)-JVS(2756)&
              &*XX(208)-JVS(2935)*XX(210)
  XX(110) = XX(110)-JVS(1097)*XX(157)-JVS(1104)*XX(158)-JVS(1376)*XX(173)-JVS(2020)*XX(198)-JVS(2282)*XX(202)-JVS(2566)&
              &*XX(205)-JVS(2839)*XX(209)
  XX(109) = XX(109)-JVS(878)*XX(140)-JVS(1150)*XX(161)-JVS(1197)*XX(164)-JVS(2083)*XX(199)-JVS(2565)*XX(205)-JVS(2755)&
              &*XX(208)-JVS(2934)*XX(210)
  XX(108) = XX(108)-JVS(924)*XX(143)-JVS(1443)*XX(177)-JVS(1538)*XX(182)-JVS(1592)*XX(185)-JVS(1847)*XX(194)-JVS(1920)&
              &*XX(195)-JVS(2564)*XX(205)-JVS(2838)*XX(209)-JVS(2995)*XX(211)
  XX(107) = XX(107)-JVS(923)*XX(143)-JVS(1442)*XX(177)-JVS(1537)*XX(182)-JVS(1591)*XX(185)-JVS(1846)*XX(194)-JVS(1919)&
              &*XX(195)-JVS(2563)*XX(205)-JVS(2837)*XX(209)-JVS(2994)*XX(211)
  XX(106) = XX(106)-JVS(1652)*XX(189)-JVS(1942)*XX(196)-JVS(2562)*XX(205)-JVS(2669)*XX(206)-JVS(2836)*XX(209)
  XX(105) = XX(105)-JVS(1196)*XX(164)-JVS(1651)*XX(189)-JVS(2191)*XX(201)-JVS(2281)*XX(202)-JVS(2561)*XX(205)
  XX(104) = XX(104)-JVS(721)*XX(122)-JVS(1941)*XX(196)-JVS(2560)*XX(205)-JVS(2754)*XX(208)-JVS(2835)*XX(209)
  XX(103) = XX(103)-JVS(895)*XX(141)-JVS(2559)*XX(205)-JVS(2933)*XX(210)
  XX(102) = XX(102)-JVS(877)*XX(140)-JVS(2082)*XX(199)-JVS(2558)*XX(205)
  XX(101) = XX(101)-JVS(635)*XX(106)-JVS(1411)*XX(175)-JVS(1441)*XX(177)-JVS(1486)*XX(180)-JVS(1650)*XX(189)-JVS(2557)&
              &*XX(205)-JVS(2668)*XX(206)-JVS(2834)*XX(209)
  XX(100) = XX(100)-JVS(1410)*XX(175)-JVS(1452)*XX(178)-JVS(1485)*XX(180)-JVS(1845)*XX(194)-JVS(1940)*XX(196)-JVS(2126)&
              &*XX(200)-JVS(2556)*XX(205)-JVS(2833)*XX(209)
  XX(99) = XX(99)-JVS(922)*XX(143)-JVS(1536)*XX(182)-JVS(1590)*XX(185)-JVS(1844)*XX(194)-JVS(1918)*XX(195)-JVS(2555)&
             &*XX(205)-JVS(2832)*XX(209)-JVS(2993)*XX(211)
  XX(98) = XX(98)-JVS(939)*XX(144)-JVS(1484)*XX(180)-JVS(2280)*XX(202)-JVS(2379)*XX(203)-JVS(2554)*XX(205)-JVS(2831)&
             &*XX(209)
  XX(97) = XX(97)-JVS(1483)*XX(180)-JVS(1843)*XX(194)-JVS(2125)*XX(200)-JVS(2553)*XX(205)-JVS(2667)*XX(206)-JVS(2830)&
             &*XX(209)
  XX(96) = XX(96)-JVS(1603)*XX(186)-JVS(1649)*XX(189)-JVS(1842)*XX(194)-JVS(2552)*XX(205)-JVS(2666)*XX(206)-JVS(2829)&
             &*XX(209)
  XX(95) = XX(95)-JVS(1756)*XX(192)-JVS(1841)*XX(194)-JVS(2456)*XX(204)-JVS(2551)*XX(205)-JVS(2828)*XX(209)-JVS(2932)&
             &*XX(210)
  XX(94) = XX(94)-JVS(938)*XX(144)-JVS(1482)*XX(180)-JVS(2279)*XX(202)-JVS(2378)*XX(203)-JVS(2550)*XX(205)-JVS(2665)&
             &*XX(206)-JVS(2827)*XX(209)
  XX(93) = XX(93)-JVS(986)*XX(148)-JVS(1086)*XX(156)-JVS(1386)*XX(174)-JVS(1755)*XX(192)-JVS(2081)*XX(199)-JVS(2549)&
             &*XX(205)-JVS(2931)*XX(210)
  XX(92) = XX(92)-JVS(894)*XX(141)-JVS(1195)*XX(164)-JVS(1754)*XX(192)-JVS(2190)*XX(201)-JVS(2278)*XX(202)-JVS(2548)&
             &*XX(205)-JVS(2930)*XX(210)
  XX(91) = XX(91)-JVS(2080)*XX(199)-JVS(2929)*XX(210)
  XX(90) = XX(90)-JVS(1074)*XX(155)-JVS(1481)*XX(180)-JVS(1840)*XX(194)-JVS(2124)*XX(200)-JVS(2547)*XX(205)
  XX(89) = XX(89)-JVS(586)*XX(98)-JVS(937)*XX(144)-JVS(1409)*XX(175)-JVS(1480)*XX(180)-JVS(1648)*XX(189)-JVS(1839)&
             &*XX(194)-JVS(2123)*XX(200)-JVS(2546)*XX(205)-JVS(2664)*XX(206)-JVS(2826)*XX(209)
  XX(88) = XX(88)-JVS(1705)*XX(190)-JVS(2019)*XX(198)-JVS(2545)*XX(205)-JVS(2825)*XX(209)
  XX(87) = XX(87)-JVS(1704)*XX(190)-JVS(1939)*XX(196)-JVS(2018)*XX(198)-JVS(2544)*XX(205)-JVS(2824)*XX(209)
  XX(86) = XX(86)-JVS(1137)*XX(160)-JVS(1178)*XX(163)-JVS(2079)*XX(199)-JVS(2543)*XX(205)-JVS(2928)*XX(210)
  XX(85) = XX(85)-JVS(1194)*XX(164)-JVS(1703)*XX(190)-JVS(1753)*XX(192)-JVS(2189)*XX(201)-JVS(2542)*XX(205)-JVS(2927)&
             &*XX(210)
  XX(84) = XX(84)-JVS(957)*XX(145)-JVS(997)*XX(149)-JVS(2017)*XX(198)-JVS(2277)*XX(202)-JVS(2541)*XX(205)-JVS(2823)&
             &*XX(209)
  XX(83) = XX(83)-JVS(1064)*XX(154)-JVS(1647)*XX(189)-JVS(1838)*XX(194)-JVS(1981)*XX(197)-JVS(2540)*XX(205)-JVS(2822)&
             &*XX(209)
  XX(82) = XX(82)-JVS(1299)*XX(169)-JVS(1980)*XX(197)-JVS(2539)*XX(205)-JVS(2821)*XX(209)
  XX(81) = XX(81)-JVS(2122)*XX(200)-JVS(2188)*XX(201)-JVS(2276)*XX(202)-JVS(2455)*XX(204)
  XX(80) = XX(80)-JVS(893)*XX(141)-JVS(1553)*XX(183)-JVS(2538)*XX(205)-JVS(2753)*XX(208)
  XX(79) = XX(79)-JVS(613)*XX(103)-JVS(1552)*XX(183)-JVS(2926)*XX(210)
  XX(78) = XX(78)-JVS(767)*XX(129)-JVS(1136)*XX(160)-JVS(2078)*XX(199)-JVS(2275)*XX(202)-JVS(2377)*XX(203)-JVS(2537)&
             &*XX(205)-JVS(2925)*XX(210)
  XX(77) = XX(77)-JVS(1752)*XX(192)-JVS(2454)*XX(204)-JVS(2536)*XX(205)-JVS(2663)*XX(206)-JVS(2820)*XX(209)-JVS(2924)&
             &*XX(210)
  XX(76) = XX(76)-JVS(2187)*XX(201)-JVS(2274)*XX(202)-JVS(2535)*XX(205)-JVS(2819)*XX(209)
  XX(75) = XX(75)-JVS(892)*XX(141)-JVS(2273)*XX(202)-JVS(2534)*XX(205)-JVS(2923)*XX(210)
  XX(74) = XX(74)-JVS(936)*XX(144)-JVS(1479)*XX(180)-JVS(1837)*XX(194)-JVS(2186)*XX(201)-JVS(2376)*XX(203)-JVS(2818)&
             &*XX(209)
  XX(73) = XX(73)-JVS(1085)*XX(156)-JVS(1575)*XX(184)-JVS(2533)*XX(205)-JVS(2817)*XX(209)
  XX(72) = XX(72)-JVS(985)*XX(148)-JVS(2016)*XX(198)-JVS(2532)*XX(205)-JVS(2816)*XX(209)
  XX(71) = XX(71)-JVS(1193)*XX(164)-JVS(1836)*XX(194)-JVS(2185)*XX(201)-JVS(2453)*XX(204)-JVS(2531)*XX(205)-JVS(2726)&
             &*XX(207)
  XX(70) = XX(70)-JVS(1135)*XX(160)-JVS(1177)*XX(163)-JVS(2272)*XX(202)-JVS(2375)*XX(203)
  XX(69) = XX(69)-JVS(2271)*XX(202)-JVS(2374)*XX(203)-JVS(2530)*XX(205)
  XX(68) = XX(68)-JVS(1810)*XX(193)-JVS(1979)*XX(197)-JVS(2529)*XX(205)-JVS(2815)*XX(209)
  XX(67) = XX(67)-JVS(1751)*XX(192)-JVS(2528)*XX(205)-JVS(2662)*XX(206)-JVS(2814)*XX(209)-JVS(2922)*XX(210)
  XX(66) = XX(66)-JVS(1750)*XX(192)-JVS(2527)*XX(205)-JVS(2661)*XX(206)-JVS(2813)*XX(209)-JVS(2921)*XX(210)
  XX(65) = XX(65)-JVS(1835)*XX(194)-JVS(2184)*XX(201)-JVS(2270)*XX(202)-JVS(2452)*XX(204)-JVS(2812)*XX(209)
  XX(64) = XX(64)-JVS(741)*XX(125)-JVS(2269)*XX(202)
  XX(63) = XX(63)-JVS(1134)*XX(160)-JVS(2920)*XX(210)
  XX(62) = XX(62)-JVS(490)*XX(79)-JVS(891)*XX(141)-JVS(1551)*XX(183)-JVS(2526)*XX(205)-JVS(2919)*XX(210)
  XX(61) = XX(61)-JVS(2121)*XX(200)-JVS(2451)*XX(204)-JVS(2525)*XX(205)
  XX(60) = XX(60)-JVS(2373)*XX(203)-JVS(2811)*XX(209)
  XX(59) = XX(59)-JVS(1192)*XX(164)
  XX(58) = XX(58)-JVS(921)*XX(143)-JVS(2524)*XX(205)
  XX(57) = XX(57)-JVS(920)*XX(143)-JVS(2523)*XX(205)
  XX(56) = XX(56)-JVS(2372)*XX(203)-JVS(2810)*XX(209)
  XX(55) = XX(55)-JVS(2371)*XX(203)-JVS(2809)*XX(209)
  XX(54) = XX(54)-JVS(766)*XX(129)-JVS(1133)*XX(160)-JVS(2370)*XX(203)
  XX(53) = XX(53)-JVS(919)*XX(143)-JVS(2522)*XX(205)
  XX(52) = XX(52)-JVS(1132)*XX(160)-JVS(2077)*XX(199)
  XX(51) = XX(51)-JVS(1131)*XX(160)-JVS(2521)*XX(205)
  XX(50) = XX(50)-JVS(2076)*XX(199)-JVS(2450)*XX(204)-JVS(2520)*XX(205)-JVS(2808)*XX(209)
  XX(49) = XX(49)-JVS(2075)*XX(199)-JVS(2268)*XX(202)
  XX(48) = XX(48)-JVS(383)*XX(55)-JVS(935)*XX(144)-JVS(1478)*XX(180)-JVS(1834)*XX(194)
  XX(47) = XX(47)-JVS(1298)*XX(169)-JVS(2267)*XX(202)
  XX(46) = XX(46)-JVS(784)*XX(131)-JVS(2266)*XX(202)
  XX(45) = XX(45)-JVS(457)*XX(70)-JVS(1176)*XX(163)
  XX(44) = XX(44)-JVS(1130)*XX(160)-JVS(2449)*XX(204)-JVS(2519)*XX(205)
  XX(43) = XX(43)-JVS(388)*XX(56)-JVS(934)*XX(144)-JVS(1833)*XX(194)
  XX(42) = XX(42)-JVS(1191)*XX(164)
  XX(41) = XX(41)-JVS(456)*XX(70)-JVS(1129)*XX(160)-JVS(1175)*XX(163)
  XX(40) = XX(40)-JVS(933)*XX(144)-JVS(1477)*XX(180)-JVS(2518)*XX(205)
  XX(39) = XX(39)-JVS(403)*XX(59)
  XX(38) = XX(38)-JVS(2074)*XX(199)-JVS(2517)*XX(205)
  XX(37) = XX(37)-JVS(2073)*XX(199)-JVS(2516)*XX(205)
  XX(36) = XX(36)-JVS(455)*XX(70)
  XX(35) = XX(35)
  XX(34) = XX(34)
  XX(33) = XX(33)
  XX(32) = XX(32)
  XX(31) = XX(31)
  XX(30) = XX(30)
  XX(29) = XX(29)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)
  XX(4) = XX(4)
  XX(3) = XX(3)-JVS(1128)*XX(160)-JVS(2072)*XX(199)
  XX(2) = XX(2)-JVS(1127)*XX(160)-JVS(2918)*XX(210)
  XX(1) = XX(1)-JVS(1126)*XX(160)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

